# IO.Swagger.Api.TableManagementApi

All URIs are relative to *https://h.app.wdesk.com/s/wdata/prep*

Method | HTTP request | Description
------------- | ------------- | -------------
[**CreateTableUsingPOST**](TableManagementApi.md#createtableusingpost) | **POST** /api/v1/table | Create a new table
[**DeleteTableUsingDELETE**](TableManagementApi.md#deletetableusingdelete) | **DELETE** /api/v1/table/{tableId} | Delete a single table
[**GetDependentsUsingGET**](TableManagementApi.md#getdependentsusingget) | **GET** /api/v1/table/{tableId}/dependents | Retrieve a list of dependents
[**GetImportInfoUsingGET**](TableManagementApi.md#getimportinfousingget) | **GET** /api/v1/table/{tableId}/importInfo | Retrieve import information
[**GetTableUsingGET**](TableManagementApi.md#gettableusingget) | **GET** /api/v1/table/{tableId} | Retrieve a single table
[**GetTablesUsingGET**](TableManagementApi.md#gettablesusingget) | **GET** /api/v1/table | Retrieve a list of tables
[**ImportFileUsingPOST**](TableManagementApi.md#importfileusingpost) | **POST** /api/v1/table/{tableId}/import | Import a single file
[**ImportFromSpreadsheetsUsingPOST**](TableManagementApi.md#importfromspreadsheetsusingpost) | **POST** /api/v1/table/{tableId}/spreadsheet/import | Import from spreadsheets
[**UnimportFileUsingDELETE**](TableManagementApi.md#unimportfileusingdelete) | **DELETE** /api/v1/table/{tableId}/import/{fileId} | Unimport a single file
[**UpdateTableUsingPUT**](TableManagementApi.md#updatetableusingput) | **PUT** /api/v1/table/{tableId} | Update a single table


<a name="createtableusingpost"></a>
# **CreateTableUsingPOST**
> BaseResponseOfTableDto CreateTableUsingPOST (TableDto body)

Create a new table

Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class CreateTableUsingPOSTExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var body = new TableDto(); // TableDto | The representation of the table to create

            try
            {
                // Create a new table
                BaseResponseOfTableDto result = apiInstance.CreateTableUsingPOST(body);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.CreateTableUsingPOST: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**TableDto**](TableDto.md)| The representation of the table to create | 

### Return type

[**BaseResponseOfTableDto**](BaseResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletetableusingdelete"></a>
# **DeleteTableUsingDELETE**
> BaseResponseOfstring DeleteTableUsingDELETE (string tableId)

Delete a single table

Soft-deletes the table with the provided ID.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class DeleteTableUsingDELETEExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableId = tableId_example;  // string | The unique identifier of the table

            try
            {
                // Delete a single table
                BaseResponseOfstring result = apiInstance.DeleteTableUsingDELETE(tableId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.DeleteTableUsingDELETE: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **string**| The unique identifier of the table | 

### Return type

[**BaseResponseOfstring**](BaseResponseOfstring.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getdependentsusingget"></a>
# **GetDependentsUsingGET**
> PagedResponseOfQueryDto GetDependentsUsingGET (string tableId, int? limit = null, string cursor = null, long? offset = null)

Retrieve a list of dependents

Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetDependentsUsingGETExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableId = tableId_example;  // string | The unique identifier of the table
            var limit = 56;  // int? | The number of folders to return, from 1 to 1000; by default, 1000 (optional) 
            var cursor = cursor_example;  // string | A paging cursor; if included, `limit` is ignored (optional) 
            var offset = 789;  // long? | The item to start with on the page, greater than or equal to 0; by default, 0 (optional) 

            try
            {
                // Retrieve a list of dependents
                PagedResponseOfQueryDto result = apiInstance.GetDependentsUsingGET(tableId, limit, cursor, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.GetDependentsUsingGET: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **string**| The unique identifier of the table | 
 **limit** | **int?**| The number of folders to return, from 1 to 1000; by default, 1000 | [optional] 
 **cursor** | **string**| A paging cursor; if included, &#x60;limit&#x60; is ignored | [optional] 
 **offset** | **long?**| The item to start with on the page, greater than or equal to 0; by default, 0 | [optional] 

### Return type

[**PagedResponseOfQueryDto**](PagedResponseOfQueryDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getimportinfousingget"></a>
# **GetImportInfoUsingGET**
> BaseResponseOfImportInfoDto GetImportInfoUsingGET (string tableId)

Retrieve import information

Returns information around imported files for a table.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetImportInfoUsingGETExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableId = tableId_example;  // string | The unique identifier of the table

            try
            {
                // Retrieve import information
                BaseResponseOfImportInfoDto result = apiInstance.GetImportInfoUsingGET(tableId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.GetImportInfoUsingGET: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **string**| The unique identifier of the table | 

### Return type

[**BaseResponseOfImportInfoDto**](BaseResponseOfImportInfoDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="gettableusingget"></a>
# **GetTableUsingGET**
> BaseResponseOfTableDto GetTableUsingGET (string tableId)

Retrieve a single table

Returns a table with the provided ID, or a 404 if no such table is found.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetTableUsingGETExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableId = tableId_example;  // string | The unique identifier of the table

            try
            {
                // Retrieve a single table
                BaseResponseOfTableDto result = apiInstance.GetTableUsingGET(tableId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.GetTableUsingGET: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **string**| The unique identifier of the table | 

### Return type

[**BaseResponseOfTableDto**](BaseResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="gettablesusingget"></a>
# **GetTablesUsingGET**
> PagedResponseOfTableDto GetTablesUsingGET (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null)

Retrieve a list of tables

Returns all tables available in the workspace.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class GetTablesUsingGETExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var includeShared = true;  // bool? | If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional)  (default to false)
            var limit = 56;  // int? | the number of folders to return, from 1 to 1000; by default, 1000 (optional) 
            var cursor = cursor_example;  // string | a paging cursor; if included the limit is ignored (optional) 
            var offset = 789;  // long? | The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional) 

            try
            {
                // Retrieve a list of tables
                PagedResponseOfTableDto result = apiInstance.GetTablesUsingGET(includeShared, limit, cursor, offset);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.GetTablesUsingGET: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **includeShared** | **bool?**| If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. | [optional] [default to false]
 **limit** | **int?**| the number of folders to return, from 1 to 1000; by default, 1000 | [optional] 
 **cursor** | **string**| a paging cursor; if included the limit is ignored | [optional] 
 **offset** | **long?**| The item to start with on the page, must be greater than or equal to 0, will default to 0 | [optional] 

### Return type

[**PagedResponseOfTableDto**](PagedResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="importfileusingpost"></a>
# **ImportFileUsingPOST**
> BaseResponseOfFileMetaDto ImportFileUsingPOST (string tableId, ImportDto importDto)

Import a single file

Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ImportFileUsingPOSTExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableId = tableId_example;  // string | The unique identifier of the table
            var importDto = new ImportDto(); // ImportDto | The representation of the table to import

            try
            {
                // Import a single file
                BaseResponseOfFileMetaDto result = apiInstance.ImportFileUsingPOST(tableId, importDto);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.ImportFileUsingPOST: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **string**| The unique identifier of the table | 
 **importDto** | [**ImportDto**](ImportDto.md)| The representation of the table to import | 

### Return type

[**BaseResponseOfFileMetaDto**](BaseResponseOfFileMetaDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="importfromspreadsheetsusingpost"></a>
# **ImportFromSpreadsheetsUsingPOST**
> BaseResponseOfFileMetaDto ImportFromSpreadsheetsUsingPOST (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto)

Import from spreadsheets

Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class ImportFromSpreadsheetsUsingPOSTExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableId = tableId_example;  // string | The unique identifier of the table
            var importFromSpreadsheetDto = new ImportFromSpreadsheetDto(); // ImportFromSpreadsheetDto | The representation of the table to update

            try
            {
                // Import from spreadsheets
                BaseResponseOfFileMetaDto result = apiInstance.ImportFromSpreadsheetsUsingPOST(tableId, importFromSpreadsheetDto);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.ImportFromSpreadsheetsUsingPOST: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **string**| The unique identifier of the table | 
 **importFromSpreadsheetDto** | [**ImportFromSpreadsheetDto**](ImportFromSpreadsheetDto.md)| The representation of the table to update | 

### Return type

[**BaseResponseOfFileMetaDto**](BaseResponseOfFileMetaDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="unimportfileusingdelete"></a>
# **UnimportFileUsingDELETE**
> BaseResponseOfFileMetaDto UnimportFileUsingDELETE (string tableId, string fileId, string force = null)

Unimport a single file

Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can't be found.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class UnimportFileUsingDELETEExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableId = tableId_example;  // string | The unique identifier of the table
            var fileId = fileId_example;  // string | The unique identifier of the file
            var force = force_example;  // string | If true, unimports and deletes file from the table (optional)  (default to false)

            try
            {
                // Unimport a single file
                BaseResponseOfFileMetaDto result = apiInstance.UnimportFileUsingDELETE(tableId, fileId, force);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.UnimportFileUsingDELETE: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableId** | **string**| The unique identifier of the table | 
 **fileId** | **string**| The unique identifier of the file | 
 **force** | **string**| If true, unimports and deletes file from the table | [optional] [default to false]

### Return type

[**BaseResponseOfFileMetaDto**](BaseResponseOfFileMetaDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="updatetableusingput"></a>
# **UpdateTableUsingPUT**
> BaseResponseOfTableDto UpdateTableUsingPUT (TableDto tableDto, string tableId)

Update a single table

Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with `_`.

### Example
```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class UpdateTableUsingPUTExample
    {
        public void main()
        {
            
            // Configure OAuth2 access token for authorization: oauth
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new TableManagementApi();
            var tableDto = new TableDto(); // TableDto | The representation of the table to update
            var tableId = tableId_example;  // string | The unique identifier of the table

            try
            {
                // Update a single table
                BaseResponseOfTableDto result = apiInstance.UpdateTableUsingPUT(tableDto, tableId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling TableManagementApi.UpdateTableUsingPUT: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **tableDto** | [**TableDto**](TableDto.md)| The representation of the table to update | 
 **tableId** | **string**| The unique identifier of the table | 

### Return type

[**BaseResponseOfTableDto**](BaseResponseOfTableDto.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

