/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IAdministrativeTasksApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Delete a single workspace
        /// </summary>
        /// <remarks>
        /// Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteWorkspaceUsingDELETE ();

        /// <summary>
        /// Delete a single workspace
        /// </summary>
        /// <remarks>
        /// Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteWorkspaceUsingDELETEWithHttpInfo ();
        /// <summary>
        /// Export a single workspace
        /// </summary>
        /// <remarks>
        /// Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>BaseResponseOfTokenDto</returns>
        BaseResponseOfTokenDto ExportWorkspaceUsingGET ();

        /// <summary>
        /// Export a single workspace
        /// </summary>
        /// <remarks>
        /// Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of BaseResponseOfTokenDto</returns>
        ApiResponse<BaseResponseOfTokenDto> ExportWorkspaceUsingGETWithHttpInfo ();
        /// <summary>
        /// Retrieve workspace files by size
        /// </summary>
        /// <remarks>
        /// Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFileMetaDto</returns>
        PagedResponseOfFileMetaDto FindWorkspaceFilesBySizeUsingGET (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve workspace files by size
        /// </summary>
        /// <remarks>
        /// Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFileMetaDto</returns>
        ApiResponse<PagedResponseOfFileMetaDto> FindWorkspaceFilesBySizeUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve workspace query usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>BaseResponseOflong</returns>
        BaseResponseOflong GetWorkspaceQueryUsageUsingGET (string startDate = null, string stopDate = null);

        /// <summary>
        /// Retrieve workspace query usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>ApiResponse of BaseResponseOflong</returns>
        ApiResponse<BaseResponseOflong> GetWorkspaceQueryUsageUsingGETWithHttpInfo (string startDate = null, string stopDate = null);
        /// <summary>
        /// Retrieve workspace upload usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>BaseResponseOflong</returns>
        BaseResponseOflong GetWorkspaceUploadUsageUsingGET (string startDate = null, string stopDate = null);

        /// <summary>
        /// Retrieve workspace upload usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>ApiResponse of BaseResponseOflong</returns>
        ApiResponse<BaseResponseOflong> GetWorkspaceUploadUsageUsingGETWithHttpInfo (string startDate = null, string stopDate = null);
        /// <summary>
        /// Import data
        /// </summary>
        /// <remarks>
        /// By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring ImportDataUsingPOST (System.IO.Stream file = null, bool? wipe = null);

        /// <summary>
        /// Import data
        /// </summary>
        /// <remarks>
        /// By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> ImportDataUsingPOSTWithHttpInfo (System.IO.Stream file = null, bool? wipe = null);
        /// <summary>
        /// Validate files
        /// </summary>
        /// <remarks>
        /// Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>BaseResponseOfValidateFilesDto</returns>
        BaseResponseOfValidateFilesDto ValidateFilesUsingPOST (StartValidateFilesDto validateFilesDto);

        /// <summary>
        /// Validate files
        /// </summary>
        /// <remarks>
        /// Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>ApiResponse of BaseResponseOfValidateFilesDto</returns>
        ApiResponse<BaseResponseOfValidateFilesDto> ValidateFilesUsingPOSTWithHttpInfo (StartValidateFilesDto validateFilesDto);
        /// <summary>
        /// Validate tables
        /// </summary>
        /// <remarks>
        /// Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>BaseResponseOfValidateTablesDto</returns>
        BaseResponseOfValidateTablesDto ValidateTablesUsingPOST ();

        /// <summary>
        /// Validate tables
        /// </summary>
        /// <remarks>
        /// Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of BaseResponseOfValidateTablesDto</returns>
        ApiResponse<BaseResponseOfValidateTablesDto> ValidateTablesUsingPOSTWithHttpInfo ();
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Delete a single workspace
        /// </summary>
        /// <remarks>
        /// Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteWorkspaceUsingDELETEAsync ();

        /// <summary>
        /// Delete a single workspace
        /// </summary>
        /// <remarks>
        /// Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteWorkspaceUsingDELETEAsyncWithHttpInfo ();
        /// <summary>
        /// Export a single workspace
        /// </summary>
        /// <remarks>
        /// Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of BaseResponseOfTokenDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTokenDto> ExportWorkspaceUsingGETAsync ();

        /// <summary>
        /// Export a single workspace
        /// </summary>
        /// <remarks>
        /// Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (BaseResponseOfTokenDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTokenDto>> ExportWorkspaceUsingGETAsyncWithHttpInfo ();
        /// <summary>
        /// Retrieve workspace files by size
        /// </summary>
        /// <remarks>
        /// Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFileMetaDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfFileMetaDto> FindWorkspaceFilesBySizeUsingGETAsync (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve workspace files by size
        /// </summary>
        /// <remarks>
        /// Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFileMetaDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFileMetaDto>> FindWorkspaceFilesBySizeUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve workspace query usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>Task of BaseResponseOflong</returns>
        System.Threading.Tasks.Task<BaseResponseOflong> GetWorkspaceQueryUsageUsingGETAsync (string startDate = null, string stopDate = null);

        /// <summary>
        /// Retrieve workspace query usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>Task of ApiResponse (BaseResponseOflong)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOflong>> GetWorkspaceQueryUsageUsingGETAsyncWithHttpInfo (string startDate = null, string stopDate = null);
        /// <summary>
        /// Retrieve workspace upload usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>Task of BaseResponseOflong</returns>
        System.Threading.Tasks.Task<BaseResponseOflong> GetWorkspaceUploadUsageUsingGETAsync (string startDate = null, string stopDate = null);

        /// <summary>
        /// Retrieve workspace upload usage
        /// </summary>
        /// <remarks>
        /// Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>Task of ApiResponse (BaseResponseOflong)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOflong>> GetWorkspaceUploadUsageUsingGETAsyncWithHttpInfo (string startDate = null, string stopDate = null);
        /// <summary>
        /// Import data
        /// </summary>
        /// <remarks>
        /// By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> ImportDataUsingPOSTAsync (System.IO.Stream file = null, bool? wipe = null);

        /// <summary>
        /// Import data
        /// </summary>
        /// <remarks>
        /// By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ImportDataUsingPOSTAsyncWithHttpInfo (System.IO.Stream file = null, bool? wipe = null);
        /// <summary>
        /// Validate files
        /// </summary>
        /// <remarks>
        /// Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>Task of BaseResponseOfValidateFilesDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfValidateFilesDto> ValidateFilesUsingPOSTAsync (StartValidateFilesDto validateFilesDto);

        /// <summary>
        /// Validate files
        /// </summary>
        /// <remarks>
        /// Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>Task of ApiResponse (BaseResponseOfValidateFilesDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfValidateFilesDto>> ValidateFilesUsingPOSTAsyncWithHttpInfo (StartValidateFilesDto validateFilesDto);
        /// <summary>
        /// Validate tables
        /// </summary>
        /// <remarks>
        /// Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of BaseResponseOfValidateTablesDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfValidateTablesDto> ValidateTablesUsingPOSTAsync ();

        /// <summary>
        /// Validate tables
        /// </summary>
        /// <remarks>
        /// Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (BaseResponseOfValidateTablesDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfValidateTablesDto>> ValidateTablesUsingPOSTAsyncWithHttpInfo ();
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class AdministrativeTasksApi : IAdministrativeTasksApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="AdministrativeTasksApi"/> class.
        /// </summary>
        /// <returns></returns>
        public AdministrativeTasksApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="AdministrativeTasksApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public AdministrativeTasksApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Delete a single workspace Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteWorkspaceUsingDELETE ()
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteWorkspaceUsingDELETEWithHttpInfo();
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single workspace Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteWorkspaceUsingDELETEWithHttpInfo ()
        {

            var localVarPath = "/api/v1/admin/account";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteWorkspaceUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single workspace Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteWorkspaceUsingDELETEAsync ()
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteWorkspaceUsingDELETEAsyncWithHttpInfo();
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single workspace Deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone&lt;/b&gt;. Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteWorkspaceUsingDELETEAsyncWithHttpInfo ()
        {

            var localVarPath = "/api/v1/admin/account";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteWorkspaceUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Export a single workspace Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>BaseResponseOfTokenDto</returns>
        public BaseResponseOfTokenDto ExportWorkspaceUsingGET ()
        {
             ApiResponse<BaseResponseOfTokenDto> localVarResponse = ExportWorkspaceUsingGETWithHttpInfo();
             return localVarResponse.Data;
        }

        /// <summary>
        /// Export a single workspace Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of BaseResponseOfTokenDto</returns>
        public ApiResponse< BaseResponseOfTokenDto > ExportWorkspaceUsingGETWithHttpInfo ()
        {

            var localVarPath = "/api/v1/admin/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ExportWorkspaceUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTokenDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTokenDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTokenDto)));
            
        }

        /// <summary>
        /// Export a single workspace Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of BaseResponseOfTokenDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTokenDto> ExportWorkspaceUsingGETAsync ()
        {
             ApiResponse<BaseResponseOfTokenDto> localVarResponse = await ExportWorkspaceUsingGETAsyncWithHttpInfo();
             return localVarResponse.Data;

        }

        /// <summary>
        /// Export a single workspace Creates a file representing the entirety of the requested workspace and returns a token. Use the [&#x60;Download a single file endpoint&#x60;](ref:wdata-downloadfileusingget) to exchange the token for the file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (BaseResponseOfTokenDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTokenDto>> ExportWorkspaceUsingGETAsyncWithHttpInfo ()
        {

            var localVarPath = "/api/v1/admin/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ExportWorkspaceUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTokenDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTokenDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTokenDto)));
            
        }

        /// <summary>
        /// Retrieve workspace files by size Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFileMetaDto</returns>
        public PagedResponseOfFileMetaDto FindWorkspaceFilesBySizeUsingGET (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFileMetaDto> localVarResponse = FindWorkspaceFilesBySizeUsingGETWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve workspace files by size Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFileMetaDto</returns>
        public ApiResponse< PagedResponseOfFileMetaDto > FindWorkspaceFilesBySizeUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/admin/usage/filesBySize";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("FindWorkspaceFilesBySizeUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Retrieve workspace files by size Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFileMetaDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfFileMetaDto> FindWorkspaceFilesBySizeUsingGETAsync (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFileMetaDto> localVarResponse = await FindWorkspaceFilesBySizeUsingGETAsyncWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve workspace files by size Returns a paged collection of the file meta associated with the workspace of the request, ordered by size.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of file meta objects to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFileMetaDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFileMetaDto>> FindWorkspaceFilesBySizeUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/admin/usage/filesBySize";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("FindWorkspaceFilesBySizeUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Retrieve workspace query usage Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>BaseResponseOflong</returns>
        public BaseResponseOflong GetWorkspaceQueryUsageUsingGET (string startDate = null, string stopDate = null)
        {
             ApiResponse<BaseResponseOflong> localVarResponse = GetWorkspaceQueryUsageUsingGETWithHttpInfo(startDate, stopDate);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve workspace query usage Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>ApiResponse of BaseResponseOflong</returns>
        public ApiResponse< BaseResponseOflong > GetWorkspaceQueryUsageUsingGETWithHttpInfo (string startDate = null, string stopDate = null)
        {

            var localVarPath = "/api/v1/admin/usage/query";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (startDate != null) localVarQueryParams.Add("startDate", Configuration.ApiClient.ParameterToString(startDate)); // query parameter
            if (stopDate != null) localVarQueryParams.Add("stopDate", Configuration.ApiClient.ParameterToString(stopDate)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetWorkspaceQueryUsageUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOflong>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOflong) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOflong)));
            
        }

        /// <summary>
        /// Retrieve workspace query usage Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>Task of BaseResponseOflong</returns>
        public async System.Threading.Tasks.Task<BaseResponseOflong> GetWorkspaceQueryUsageUsingGETAsync (string startDate = null, string stopDate = null)
        {
             ApiResponse<BaseResponseOflong> localVarResponse = await GetWorkspaceQueryUsageUsingGETAsyncWithHttpInfo(startDate, stopDate);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve workspace query usage Returns a Long that represents the number of bytes queried by the workspace of the request since the start time provided.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The earliest date of usage to consider (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The end date of usage to consider (optional, default to 9999-01-01)</param>
        /// <returns>Task of ApiResponse (BaseResponseOflong)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOflong>> GetWorkspaceQueryUsageUsingGETAsyncWithHttpInfo (string startDate = null, string stopDate = null)
        {

            var localVarPath = "/api/v1/admin/usage/query";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (startDate != null) localVarQueryParams.Add("startDate", Configuration.ApiClient.ParameterToString(startDate)); // query parameter
            if (stopDate != null) localVarQueryParams.Add("stopDate", Configuration.ApiClient.ParameterToString(stopDate)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetWorkspaceQueryUsageUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOflong>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOflong) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOflong)));
            
        }

        /// <summary>
        /// Retrieve workspace upload usage Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>BaseResponseOflong</returns>
        public BaseResponseOflong GetWorkspaceUploadUsageUsingGET (string startDate = null, string stopDate = null)
        {
             ApiResponse<BaseResponseOflong> localVarResponse = GetWorkspaceUploadUsageUsingGETWithHttpInfo(startDate, stopDate);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve workspace upload usage Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>ApiResponse of BaseResponseOflong</returns>
        public ApiResponse< BaseResponseOflong > GetWorkspaceUploadUsageUsingGETWithHttpInfo (string startDate = null, string stopDate = null)
        {

            var localVarPath = "/api/v1/admin/usage/upload";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (startDate != null) localVarQueryParams.Add("startDate", Configuration.ApiClient.ParameterToString(startDate)); // query parameter
            if (stopDate != null) localVarQueryParams.Add("stopDate", Configuration.ApiClient.ParameterToString(stopDate)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetWorkspaceUploadUsageUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOflong>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOflong) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOflong)));
            
        }

        /// <summary>
        /// Retrieve workspace upload usage Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>Task of BaseResponseOflong</returns>
        public async System.Threading.Tasks.Task<BaseResponseOflong> GetWorkspaceUploadUsageUsingGETAsync (string startDate = null, string stopDate = null)
        {
             ApiResponse<BaseResponseOflong> localVarResponse = await GetWorkspaceUploadUsageUsingGETAsyncWithHttpInfo(startDate, stopDate);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve workspace upload usage Returns a Long that represents the number of bytes uploaded by the workspace associated with this request from the start time provided to now.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="startDate">The starting point to begin considering usage (optional, default to 1970-01-01)</param>
        /// <param name="stopDate">The ending point when considering usage (optional, default to 9999-01-01)</param>
        /// <returns>Task of ApiResponse (BaseResponseOflong)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOflong>> GetWorkspaceUploadUsageUsingGETAsyncWithHttpInfo (string startDate = null, string stopDate = null)
        {

            var localVarPath = "/api/v1/admin/usage/upload";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (startDate != null) localVarQueryParams.Add("startDate", Configuration.ApiClient.ParameterToString(startDate)); // query parameter
            if (stopDate != null) localVarQueryParams.Add("stopDate", Configuration.ApiClient.ParameterToString(stopDate)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetWorkspaceUploadUsageUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOflong>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOflong) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOflong)));
            
        }

        /// <summary>
        /// Import data By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring ImportDataUsingPOST (System.IO.Stream file = null, bool? wipe = null)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = ImportDataUsingPOSTWithHttpInfo(file, wipe);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Import data By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > ImportDataUsingPOSTWithHttpInfo (System.IO.Stream file = null, bool? wipe = null)
        {

            var localVarPath = "/api/v1/admin/import";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "multipart/form-data"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (wipe != null) localVarQueryParams.Add("wipe", Configuration.ApiClient.ParameterToString(wipe)); // query parameter
            if (file != null) localVarFileParams.Add("file", Configuration.ApiClient.ParameterToFile("file", file));

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ImportDataUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Import data By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> ImportDataUsingPOSTAsync (System.IO.Stream file = null, bool? wipe = null)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await ImportDataUsingPOSTAsyncWithHttpInfo(file, wipe);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Import data By default, deletes all information in the workspace of the request. &lt;b&gt;This is a final operation and can&#39;t be undone.&lt;/b&gt;  Any state left in the workspace due to an error is in an indeterminate state and shouldn&#39;t be trusted. Some non-private information may be kept for auditing and metric purposes. After the delete, it then imports the tables, tags, and queries in the provided cb file into the workspace. &lt;br&gt;&lt;br&gt;This is an asynchronous operation. Returns a 201 when the file is correctly decoded and its tables, queries, and tags are saved. Files continue to import after this call completes.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="file">The file containing workspace information to import (optional)</param>
        /// <param name="wipe">wipe (optional, default to true)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ImportDataUsingPOSTAsyncWithHttpInfo (System.IO.Stream file = null, bool? wipe = null)
        {

            var localVarPath = "/api/v1/admin/import";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "multipart/form-data"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (wipe != null) localVarQueryParams.Add("wipe", Configuration.ApiClient.ParameterToString(wipe)); // query parameter
            if (file != null) localVarFileParams.Add("file", Configuration.ApiClient.ParameterToFile("file", file));

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ImportDataUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Validate files Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>BaseResponseOfValidateFilesDto</returns>
        public BaseResponseOfValidateFilesDto ValidateFilesUsingPOST (StartValidateFilesDto validateFilesDto)
        {
             ApiResponse<BaseResponseOfValidateFilesDto> localVarResponse = ValidateFilesUsingPOSTWithHttpInfo(validateFilesDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Validate files Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>ApiResponse of BaseResponseOfValidateFilesDto</returns>
        public ApiResponse< BaseResponseOfValidateFilesDto > ValidateFilesUsingPOSTWithHttpInfo (StartValidateFilesDto validateFilesDto)
        {
            // verify the required parameter 'validateFilesDto' is set
            if (validateFilesDto == null)
                throw new ApiException(400, "Missing required parameter 'validateFilesDto' when calling AdministrativeTasksApi->ValidateFilesUsingPOST");

            var localVarPath = "/api/v1/admin/validation/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (validateFilesDto != null && validateFilesDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(validateFilesDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = validateFilesDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ValidateFilesUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfValidateFilesDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfValidateFilesDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfValidateFilesDto)));
            
        }

        /// <summary>
        /// Validate files Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>Task of BaseResponseOfValidateFilesDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfValidateFilesDto> ValidateFilesUsingPOSTAsync (StartValidateFilesDto validateFilesDto)
        {
             ApiResponse<BaseResponseOfValidateFilesDto> localVarResponse = await ValidateFilesUsingPOSTAsyncWithHttpInfo(validateFilesDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Validate files Validates files associated with the provided table ID. Validation repairs any files in an inconsistent state, and deletes those without enough state to recover. All files deleted or repaired are returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="validateFilesDto">The representation of the file to validate</param>
        /// <returns>Task of ApiResponse (BaseResponseOfValidateFilesDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfValidateFilesDto>> ValidateFilesUsingPOSTAsyncWithHttpInfo (StartValidateFilesDto validateFilesDto)
        {
            // verify the required parameter 'validateFilesDto' is set
            if (validateFilesDto == null)
                throw new ApiException(400, "Missing required parameter 'validateFilesDto' when calling AdministrativeTasksApi->ValidateFilesUsingPOST");

            var localVarPath = "/api/v1/admin/validation/files";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (validateFilesDto != null && validateFilesDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(validateFilesDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = validateFilesDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ValidateFilesUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfValidateFilesDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfValidateFilesDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfValidateFilesDto)));
            
        }

        /// <summary>
        /// Validate tables Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>BaseResponseOfValidateTablesDto</returns>
        public BaseResponseOfValidateTablesDto ValidateTablesUsingPOST ()
        {
             ApiResponse<BaseResponseOfValidateTablesDto> localVarResponse = ValidateTablesUsingPOSTWithHttpInfo();
             return localVarResponse.Data;
        }

        /// <summary>
        /// Validate tables Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>ApiResponse of BaseResponseOfValidateTablesDto</returns>
        public ApiResponse< BaseResponseOfValidateTablesDto > ValidateTablesUsingPOSTWithHttpInfo ()
        {

            var localVarPath = "/api/v1/admin/validation/tables";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ValidateTablesUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfValidateTablesDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfValidateTablesDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfValidateTablesDto)));
            
        }

        /// <summary>
        /// Validate tables Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of BaseResponseOfValidateTablesDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfValidateTablesDto> ValidateTablesUsingPOSTAsync ()
        {
             ApiResponse<BaseResponseOfValidateTablesDto> localVarResponse = await ValidateTablesUsingPOSTAsyncWithHttpInfo();
             return localVarResponse.Data;

        }

        /// <summary>
        /// Validate tables Validates the tables in the workspace associated with the request. Validation returns an entity that indicates the tables deleted due to bad state, and those with enough state and repaired.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <returns>Task of ApiResponse (BaseResponseOfValidateTablesDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfValidateTablesDto>> ValidateTablesUsingPOSTAsyncWithHttpInfo ()
        {

            var localVarPath = "/api/v1/admin/validation/tables";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ValidateTablesUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfValidateTablesDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfValidateTablesDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfValidateTablesDto)));
            
        }

    }
}
