/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IConnectionManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Get connection details
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>BaseResponseOfConnectionDto</returns>
        BaseResponseOfConnectionDto GetConnectionUsingGET (string connectionId, string workspaceId = null);

        /// <summary>
        /// Get connection details
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfConnectionDto</returns>
        ApiResponse<BaseResponseOfConnectionDto> GetConnectionUsingGETWithHttpInfo (string connectionId, string workspaceId = null);
        /// <summary>
        /// Gets the status of a batch refresh
        /// </summary>
        /// <remarks>
        /// Returns details about a specific batch refresh, based on its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>BaseResponseOfRefreshBatchDto</returns>
        BaseResponseOfRefreshBatchDto GetRefreshBatchStatusUsingGET (string batchId, string workspaceId = null);

        /// <summary>
        /// Gets the status of a batch refresh
        /// </summary>
        /// <remarks>
        /// Returns details about a specific batch refresh, based on its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfRefreshBatchDto</returns>
        ApiResponse<BaseResponseOfRefreshBatchDto> GetRefreshBatchStatusUsingGETWithHttpInfo (string batchId, string workspaceId = null);
        /// <summary>
        /// Get connection refresh status
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>BaseResponseOfConnectionRunDto</returns>
        BaseResponseOfConnectionRunDto GetRefreshStatusUsingGET (string connectionId, string workspaceId = null, string jobId = null);

        /// <summary>
        /// Get connection refresh status
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfConnectionRunDto</returns>
        ApiResponse<BaseResponseOfConnectionRunDto> GetRefreshStatusUsingGETWithHttpInfo (string connectionId, string workspaceId = null, string jobId = null);
        /// <summary>
        /// List connections
        /// </summary>
        /// <remarks>
        /// A pageable endpoint to list data connections between features of the Workiva platform
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfConnectionDto</returns>
        PagedResponseOfConnectionDto ListConnectionsUsingGET (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// List connections
        /// </summary>
        /// <remarks>
        /// A pageable endpoint to list data connections between features of the Workiva platform
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfConnectionDto</returns>
        ApiResponse<PagedResponseOfConnectionDto> ListConnectionsUsingGETWithHttpInfo (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Refresh batch of connections
        /// </summary>
        /// <remarks>
        /// Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>BaseResponseOfRefreshBatchDto</returns>
        BaseResponseOfRefreshBatchDto RefreshBatchUsingPOST (List<RefreshConnectionDto> refreshConnectionDtos);

        /// <summary>
        /// Refresh batch of connections
        /// </summary>
        /// <remarks>
        /// Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>ApiResponse of BaseResponseOfRefreshBatchDto</returns>
        ApiResponse<BaseResponseOfRefreshBatchDto> RefreshBatchUsingPOSTWithHttpInfo (List<RefreshConnectionDto> refreshConnectionDtos);
        /// <summary>
        /// Refresh connection
        /// </summary>
        /// <remarks>
        /// Refreshes a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>BaseResponseOfConnectionRunDto</returns>
        BaseResponseOfConnectionRunDto RefreshConnectionUsingPOST (string connectionId, RefreshConnectionDto refreshConnectionDto);

        /// <summary>
        /// Refresh connection
        /// </summary>
        /// <remarks>
        /// Refreshes a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>ApiResponse of BaseResponseOfConnectionRunDto</returns>
        ApiResponse<BaseResponseOfConnectionRunDto> RefreshConnectionUsingPOSTWithHttpInfo (string connectionId, RefreshConnectionDto refreshConnectionDto);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Get connection details
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of BaseResponseOfConnectionDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfConnectionDto> GetConnectionUsingGETAsync (string connectionId, string workspaceId = null);

        /// <summary>
        /// Get connection details
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfConnectionDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfConnectionDto>> GetConnectionUsingGETAsyncWithHttpInfo (string connectionId, string workspaceId = null);
        /// <summary>
        /// Gets the status of a batch refresh
        /// </summary>
        /// <remarks>
        /// Returns details about a specific batch refresh, based on its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of BaseResponseOfRefreshBatchDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfRefreshBatchDto> GetRefreshBatchStatusUsingGETAsync (string batchId, string workspaceId = null);

        /// <summary>
        /// Gets the status of a batch refresh
        /// </summary>
        /// <remarks>
        /// Returns details about a specific batch refresh, based on its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfRefreshBatchDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfRefreshBatchDto>> GetRefreshBatchStatusUsingGETAsyncWithHttpInfo (string batchId, string workspaceId = null);
        /// <summary>
        /// Get connection refresh status
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>Task of BaseResponseOfConnectionRunDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfConnectionRunDto> GetRefreshStatusUsingGETAsync (string connectionId, string workspaceId = null, string jobId = null);

        /// <summary>
        /// Get connection refresh status
        /// </summary>
        /// <remarks>
        /// Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfConnectionRunDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfConnectionRunDto>> GetRefreshStatusUsingGETAsyncWithHttpInfo (string connectionId, string workspaceId = null, string jobId = null);
        /// <summary>
        /// List connections
        /// </summary>
        /// <remarks>
        /// A pageable endpoint to list data connections between features of the Workiva platform
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfConnectionDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfConnectionDto> ListConnectionsUsingGETAsync (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// List connections
        /// </summary>
        /// <remarks>
        /// A pageable endpoint to list data connections between features of the Workiva platform
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfConnectionDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfConnectionDto>> ListConnectionsUsingGETAsyncWithHttpInfo (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Refresh batch of connections
        /// </summary>
        /// <remarks>
        /// Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>Task of BaseResponseOfRefreshBatchDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfRefreshBatchDto> RefreshBatchUsingPOSTAsync (List<RefreshConnectionDto> refreshConnectionDtos);

        /// <summary>
        /// Refresh batch of connections
        /// </summary>
        /// <remarks>
        /// Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>Task of ApiResponse (BaseResponseOfRefreshBatchDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfRefreshBatchDto>> RefreshBatchUsingPOSTAsyncWithHttpInfo (List<RefreshConnectionDto> refreshConnectionDtos);
        /// <summary>
        /// Refresh connection
        /// </summary>
        /// <remarks>
        /// Refreshes a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>Task of BaseResponseOfConnectionRunDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfConnectionRunDto> RefreshConnectionUsingPOSTAsync (string connectionId, RefreshConnectionDto refreshConnectionDto);

        /// <summary>
        /// Refresh connection
        /// </summary>
        /// <remarks>
        /// Refreshes a specific connection, based on its ID
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>Task of ApiResponse (BaseResponseOfConnectionRunDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfConnectionRunDto>> RefreshConnectionUsingPOSTAsyncWithHttpInfo (string connectionId, RefreshConnectionDto refreshConnectionDto);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class ConnectionManagementApi : IConnectionManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="ConnectionManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public ConnectionManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ConnectionManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public ConnectionManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Get connection details Returns details about a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>BaseResponseOfConnectionDto</returns>
        public BaseResponseOfConnectionDto GetConnectionUsingGET (string connectionId, string workspaceId = null)
        {
             ApiResponse<BaseResponseOfConnectionDto> localVarResponse = GetConnectionUsingGETWithHttpInfo(connectionId, workspaceId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Get connection details Returns details about a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfConnectionDto</returns>
        public ApiResponse< BaseResponseOfConnectionDto > GetConnectionUsingGETWithHttpInfo (string connectionId, string workspaceId = null)
        {
            // verify the required parameter 'connectionId' is set
            if (connectionId == null)
                throw new ApiException(400, "Missing required parameter 'connectionId' when calling ConnectionManagementApi->GetConnectionUsingGET");

            var localVarPath = "/api/v1/connections/{connectionId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (connectionId != null) localVarPathParams.Add("connectionId", Configuration.ApiClient.ParameterToString(connectionId)); // path parameter
            if (workspaceId != null) localVarQueryParams.Add("workspaceId", Configuration.ApiClient.ParameterToString(workspaceId)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetConnectionUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfConnectionDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfConnectionDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfConnectionDto)));
            
        }

        /// <summary>
        /// Get connection details Returns details about a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of BaseResponseOfConnectionDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfConnectionDto> GetConnectionUsingGETAsync (string connectionId, string workspaceId = null)
        {
             ApiResponse<BaseResponseOfConnectionDto> localVarResponse = await GetConnectionUsingGETAsyncWithHttpInfo(connectionId, workspaceId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Get connection details Returns details about a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfConnectionDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfConnectionDto>> GetConnectionUsingGETAsyncWithHttpInfo (string connectionId, string workspaceId = null)
        {
            // verify the required parameter 'connectionId' is set
            if (connectionId == null)
                throw new ApiException(400, "Missing required parameter 'connectionId' when calling ConnectionManagementApi->GetConnectionUsingGET");

            var localVarPath = "/api/v1/connections/{connectionId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (connectionId != null) localVarPathParams.Add("connectionId", Configuration.ApiClient.ParameterToString(connectionId)); // path parameter
            if (workspaceId != null) localVarQueryParams.Add("workspaceId", Configuration.ApiClient.ParameterToString(workspaceId)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetConnectionUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfConnectionDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfConnectionDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfConnectionDto)));
            
        }

        /// <summary>
        /// Gets the status of a batch refresh Returns details about a specific batch refresh, based on its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>BaseResponseOfRefreshBatchDto</returns>
        public BaseResponseOfRefreshBatchDto GetRefreshBatchStatusUsingGET (string batchId, string workspaceId = null)
        {
             ApiResponse<BaseResponseOfRefreshBatchDto> localVarResponse = GetRefreshBatchStatusUsingGETWithHttpInfo(batchId, workspaceId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Gets the status of a batch refresh Returns details about a specific batch refresh, based on its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfRefreshBatchDto</returns>
        public ApiResponse< BaseResponseOfRefreshBatchDto > GetRefreshBatchStatusUsingGETWithHttpInfo (string batchId, string workspaceId = null)
        {
            // verify the required parameter 'batchId' is set
            if (batchId == null)
                throw new ApiException(400, "Missing required parameter 'batchId' when calling ConnectionManagementApi->GetRefreshBatchStatusUsingGET");

            var localVarPath = "/api/v1/connections/batch/refresh/{batchId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (batchId != null) localVarPathParams.Add("batchId", Configuration.ApiClient.ParameterToString(batchId)); // path parameter
            if (workspaceId != null) localVarQueryParams.Add("workspaceId", Configuration.ApiClient.ParameterToString(workspaceId)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetRefreshBatchStatusUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfRefreshBatchDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfRefreshBatchDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfRefreshBatchDto)));
            
        }

        /// <summary>
        /// Gets the status of a batch refresh Returns details about a specific batch refresh, based on its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of BaseResponseOfRefreshBatchDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfRefreshBatchDto> GetRefreshBatchStatusUsingGETAsync (string batchId, string workspaceId = null)
        {
             ApiResponse<BaseResponseOfRefreshBatchDto> localVarResponse = await GetRefreshBatchStatusUsingGETAsyncWithHttpInfo(batchId, workspaceId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Gets the status of a batch refresh Returns details about a specific batch refresh, based on its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="batchId">The ID of the batch to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfRefreshBatchDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfRefreshBatchDto>> GetRefreshBatchStatusUsingGETAsyncWithHttpInfo (string batchId, string workspaceId = null)
        {
            // verify the required parameter 'batchId' is set
            if (batchId == null)
                throw new ApiException(400, "Missing required parameter 'batchId' when calling ConnectionManagementApi->GetRefreshBatchStatusUsingGET");

            var localVarPath = "/api/v1/connections/batch/refresh/{batchId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (batchId != null) localVarPathParams.Add("batchId", Configuration.ApiClient.ParameterToString(batchId)); // path parameter
            if (workspaceId != null) localVarQueryParams.Add("workspaceId", Configuration.ApiClient.ParameterToString(workspaceId)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetRefreshBatchStatusUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfRefreshBatchDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfRefreshBatchDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfRefreshBatchDto)));
            
        }

        /// <summary>
        /// Get connection refresh status Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>BaseResponseOfConnectionRunDto</returns>
        public BaseResponseOfConnectionRunDto GetRefreshStatusUsingGET (string connectionId, string workspaceId = null, string jobId = null)
        {
             ApiResponse<BaseResponseOfConnectionRunDto> localVarResponse = GetRefreshStatusUsingGETWithHttpInfo(connectionId, workspaceId, jobId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Get connection refresh status Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfConnectionRunDto</returns>
        public ApiResponse< BaseResponseOfConnectionRunDto > GetRefreshStatusUsingGETWithHttpInfo (string connectionId, string workspaceId = null, string jobId = null)
        {
            // verify the required parameter 'connectionId' is set
            if (connectionId == null)
                throw new ApiException(400, "Missing required parameter 'connectionId' when calling ConnectionManagementApi->GetRefreshStatusUsingGET");

            var localVarPath = "/api/v1/connections/{connectionId}/status";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (connectionId != null) localVarPathParams.Add("connectionId", Configuration.ApiClient.ParameterToString(connectionId)); // path parameter
            if (workspaceId != null) localVarQueryParams.Add("workspaceId", Configuration.ApiClient.ParameterToString(workspaceId)); // query parameter
            if (jobId != null) localVarQueryParams.Add("jobId", Configuration.ApiClient.ParameterToString(jobId)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetRefreshStatusUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfConnectionRunDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfConnectionRunDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfConnectionRunDto)));
            
        }

        /// <summary>
        /// Get connection refresh status Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>Task of BaseResponseOfConnectionRunDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfConnectionRunDto> GetRefreshStatusUsingGETAsync (string connectionId, string workspaceId = null, string jobId = null)
        {
             ApiResponse<BaseResponseOfConnectionRunDto> localVarResponse = await GetRefreshStatusUsingGETAsyncWithHttpInfo(connectionId, workspaceId, jobId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Get connection refresh status Returns details about a specific connection refresh status, based on its ID. To retrieve details about a specific refresh, provide its &#39;jobId&#39;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to return details about</param>
        /// <param name="workspaceId">workspaceId (optional)</param>
        /// <param name="jobId">The ID of the job running for a connection (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfConnectionRunDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfConnectionRunDto>> GetRefreshStatusUsingGETAsyncWithHttpInfo (string connectionId, string workspaceId = null, string jobId = null)
        {
            // verify the required parameter 'connectionId' is set
            if (connectionId == null)
                throw new ApiException(400, "Missing required parameter 'connectionId' when calling ConnectionManagementApi->GetRefreshStatusUsingGET");

            var localVarPath = "/api/v1/connections/{connectionId}/status";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (connectionId != null) localVarPathParams.Add("connectionId", Configuration.ApiClient.ParameterToString(connectionId)); // path parameter
            if (workspaceId != null) localVarQueryParams.Add("workspaceId", Configuration.ApiClient.ParameterToString(workspaceId)); // query parameter
            if (jobId != null) localVarQueryParams.Add("jobId", Configuration.ApiClient.ParameterToString(jobId)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetRefreshStatusUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfConnectionRunDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfConnectionRunDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfConnectionRunDto)));
            
        }

        /// <summary>
        /// List connections A pageable endpoint to list data connections between features of the Workiva platform
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfConnectionDto</returns>
        public PagedResponseOfConnectionDto ListConnectionsUsingGET (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfConnectionDto> localVarResponse = ListConnectionsUsingGETWithHttpInfo(sourceType, destinationType, sourceId, destinationId, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// List connections A pageable endpoint to list data connections between features of the Workiva platform
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfConnectionDto</returns>
        public ApiResponse< PagedResponseOfConnectionDto > ListConnectionsUsingGETWithHttpInfo (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/connections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sourceType != null) localVarQueryParams.Add("sourceType", Configuration.ApiClient.ParameterToString(sourceType)); // query parameter
            if (destinationType != null) localVarQueryParams.Add("destinationType", Configuration.ApiClient.ParameterToString(destinationType)); // query parameter
            if (sourceId != null) localVarQueryParams.Add("sourceId", Configuration.ApiClient.ParameterToString(sourceId)); // query parameter
            if (destinationId != null) localVarQueryParams.Add("destinationId", Configuration.ApiClient.ParameterToString(destinationId)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListConnectionsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfConnectionDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfConnectionDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfConnectionDto)));
            
        }

        /// <summary>
        /// List connections A pageable endpoint to list data connections between features of the Workiva platform
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfConnectionDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfConnectionDto> ListConnectionsUsingGETAsync (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfConnectionDto> localVarResponse = await ListConnectionsUsingGETAsyncWithHttpInfo(sourceType, destinationType, sourceId, destinationId, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// List connections A pageable endpoint to list data connections between features of the Workiva platform
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sourceType">The type of file or item the connection pulls data from (optional)</param>
        /// <param name="destinationType">The type of file or item the connection sends data to (optional)</param>
        /// <param name="sourceId">The ID of the file or item the connection pulls data from (optional)</param>
        /// <param name="destinationId">The ID of the file or item the connection sends data to (optional)</param>
        /// <param name="limit">The number of connections to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfConnectionDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfConnectionDto>> ListConnectionsUsingGETAsyncWithHttpInfo (string sourceType = null, string destinationType = null, string sourceId = null, string destinationId = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/connections";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sourceType != null) localVarQueryParams.Add("sourceType", Configuration.ApiClient.ParameterToString(sourceType)); // query parameter
            if (destinationType != null) localVarQueryParams.Add("destinationType", Configuration.ApiClient.ParameterToString(destinationType)); // query parameter
            if (sourceId != null) localVarQueryParams.Add("sourceId", Configuration.ApiClient.ParameterToString(sourceId)); // query parameter
            if (destinationId != null) localVarQueryParams.Add("destinationId", Configuration.ApiClient.ParameterToString(destinationId)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListConnectionsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfConnectionDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfConnectionDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfConnectionDto)));
            
        }

        /// <summary>
        /// Refresh batch of connections Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>BaseResponseOfRefreshBatchDto</returns>
        public BaseResponseOfRefreshBatchDto RefreshBatchUsingPOST (List<RefreshConnectionDto> refreshConnectionDtos)
        {
             ApiResponse<BaseResponseOfRefreshBatchDto> localVarResponse = RefreshBatchUsingPOSTWithHttpInfo(refreshConnectionDtos);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Refresh batch of connections Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>ApiResponse of BaseResponseOfRefreshBatchDto</returns>
        public ApiResponse< BaseResponseOfRefreshBatchDto > RefreshBatchUsingPOSTWithHttpInfo (List<RefreshConnectionDto> refreshConnectionDtos)
        {
            // verify the required parameter 'refreshConnectionDtos' is set
            if (refreshConnectionDtos == null)
                throw new ApiException(400, "Missing required parameter 'refreshConnectionDtos' when calling ConnectionManagementApi->RefreshBatchUsingPOST");

            var localVarPath = "/api/v1/connections/batch/refresh";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (refreshConnectionDtos != null && refreshConnectionDtos.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(refreshConnectionDtos); // http body (model) parameter
            }
            else
            {
                localVarPostBody = refreshConnectionDtos; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("RefreshBatchUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfRefreshBatchDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfRefreshBatchDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfRefreshBatchDto)));
            
        }

        /// <summary>
        /// Refresh batch of connections Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>Task of BaseResponseOfRefreshBatchDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfRefreshBatchDto> RefreshBatchUsingPOSTAsync (List<RefreshConnectionDto> refreshConnectionDtos)
        {
             ApiResponse<BaseResponseOfRefreshBatchDto> localVarResponse = await RefreshBatchUsingPOSTAsyncWithHttpInfo(refreshConnectionDtos);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Refresh batch of connections Refreshes multiple connections within the same spreadsheet, based on ID.When connecting to multiple spreadsheets, tables or other destinations, use the [&#x60;singular refresh connection&#x60;](ref:wdata-refreshconnectionusingpost) instead. &#x60;usePreviousDestinationParameters&#x60; and  &#x60;usePreviousSourceParameters&#x60; will use the exact parameters of your previous run; any new parameters you’ve provided will be ignored.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="refreshConnectionDtos">refreshConnectionDtos</param>
        /// <returns>Task of ApiResponse (BaseResponseOfRefreshBatchDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfRefreshBatchDto>> RefreshBatchUsingPOSTAsyncWithHttpInfo (List<RefreshConnectionDto> refreshConnectionDtos)
        {
            // verify the required parameter 'refreshConnectionDtos' is set
            if (refreshConnectionDtos == null)
                throw new ApiException(400, "Missing required parameter 'refreshConnectionDtos' when calling ConnectionManagementApi->RefreshBatchUsingPOST");

            var localVarPath = "/api/v1/connections/batch/refresh";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (refreshConnectionDtos != null && refreshConnectionDtos.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(refreshConnectionDtos); // http body (model) parameter
            }
            else
            {
                localVarPostBody = refreshConnectionDtos; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("RefreshBatchUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfRefreshBatchDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfRefreshBatchDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfRefreshBatchDto)));
            
        }

        /// <summary>
        /// Refresh connection Refreshes a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>BaseResponseOfConnectionRunDto</returns>
        public BaseResponseOfConnectionRunDto RefreshConnectionUsingPOST (string connectionId, RefreshConnectionDto refreshConnectionDto)
        {
             ApiResponse<BaseResponseOfConnectionRunDto> localVarResponse = RefreshConnectionUsingPOSTWithHttpInfo(connectionId, refreshConnectionDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Refresh connection Refreshes a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>ApiResponse of BaseResponseOfConnectionRunDto</returns>
        public ApiResponse< BaseResponseOfConnectionRunDto > RefreshConnectionUsingPOSTWithHttpInfo (string connectionId, RefreshConnectionDto refreshConnectionDto)
        {
            // verify the required parameter 'connectionId' is set
            if (connectionId == null)
                throw new ApiException(400, "Missing required parameter 'connectionId' when calling ConnectionManagementApi->RefreshConnectionUsingPOST");
            // verify the required parameter 'refreshConnectionDto' is set
            if (refreshConnectionDto == null)
                throw new ApiException(400, "Missing required parameter 'refreshConnectionDto' when calling ConnectionManagementApi->RefreshConnectionUsingPOST");

            var localVarPath = "/api/v1/connections/{connectionId}/refresh";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (connectionId != null) localVarPathParams.Add("connectionId", Configuration.ApiClient.ParameterToString(connectionId)); // path parameter
            if (refreshConnectionDto != null && refreshConnectionDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(refreshConnectionDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = refreshConnectionDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("RefreshConnectionUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfConnectionRunDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfConnectionRunDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfConnectionRunDto)));
            
        }

        /// <summary>
        /// Refresh connection Refreshes a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>Task of BaseResponseOfConnectionRunDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfConnectionRunDto> RefreshConnectionUsingPOSTAsync (string connectionId, RefreshConnectionDto refreshConnectionDto)
        {
             ApiResponse<BaseResponseOfConnectionRunDto> localVarResponse = await RefreshConnectionUsingPOSTAsyncWithHttpInfo(connectionId, refreshConnectionDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Refresh connection Refreshes a specific connection, based on its ID
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="connectionId">The ID of the connection to refresh</param>
        /// <param name="refreshConnectionDto">refreshConnectionDto</param>
        /// <returns>Task of ApiResponse (BaseResponseOfConnectionRunDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfConnectionRunDto>> RefreshConnectionUsingPOSTAsyncWithHttpInfo (string connectionId, RefreshConnectionDto refreshConnectionDto)
        {
            // verify the required parameter 'connectionId' is set
            if (connectionId == null)
                throw new ApiException(400, "Missing required parameter 'connectionId' when calling ConnectionManagementApi->RefreshConnectionUsingPOST");
            // verify the required parameter 'refreshConnectionDto' is set
            if (refreshConnectionDto == null)
                throw new ApiException(400, "Missing required parameter 'refreshConnectionDto' when calling ConnectionManagementApi->RefreshConnectionUsingPOST");

            var localVarPath = "/api/v1/connections/{connectionId}/refresh";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (connectionId != null) localVarPathParams.Add("connectionId", Configuration.ApiClient.ParameterToString(connectionId)); // path parameter
            if (refreshConnectionDto != null && refreshConnectionDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(refreshConnectionDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = refreshConnectionDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("RefreshConnectionUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfConnectionRunDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfConnectionRunDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfConnectionRunDto)));
            
        }

    }
}
