/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IFileManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Delete a single file
        /// </summary>
        /// <remarks>
        /// Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteFileUsingDELETE (string fileId);

        /// <summary>
        /// Delete a single file
        /// </summary>
        /// <remarks>
        /// Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteFileUsingDELETEWithHttpInfo (string fileId);
        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Returns a file with the provided ID, which points to a file meta ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>byte[]</returns>
        byte[] DownloadFileUsingGET (string fileId);

        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Returns a file with the provided ID, which points to a file meta ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>ApiResponse of byte[]</returns>
        ApiResponse<byte[]> DownloadFileUsingGETWithHttpInfo (string fileId);
        /// <summary>
        /// Export a file to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>BaseResponseOfSpreadsheetInfoDto</returns>
        BaseResponseOfSpreadsheetInfoDto ExportFileToSpreadsheetsUsingPOST (string fileId, ExportFileDto exportFileDto);

        /// <summary>
        /// Export a file to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>ApiResponse of BaseResponseOfSpreadsheetInfoDto</returns>
        ApiResponse<BaseResponseOfSpreadsheetInfoDto> ExportFileToSpreadsheetsUsingPOSTWithHttpInfo (string fileId, ExportFileDto exportFileDto);
        /// <summary>
        /// Retrieve errors
        /// </summary>
        /// <remarks>
        /// Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfImportErrorDto</returns>
        PagedResponseOfImportErrorDto GetErrorsUsingGET (string fileId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve errors
        /// </summary>
        /// <remarks>
        /// Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfImportErrorDto</returns>
        ApiResponse<PagedResponseOfImportErrorDto> GetErrorsUsingGETWithHttpInfo (string fileId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve a single file
        /// </summary>
        /// <remarks>
        /// Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        BaseResponseOfFileMetaDto GetFileUsingGET (string fileId);

        /// <summary>
        /// Retrieve a single file
        /// </summary>
        /// <remarks>
        /// Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        ApiResponse<BaseResponseOfFileMetaDto> GetFileUsingGETWithHttpInfo (string fileId);
        /// <summary>
        /// Retrieve a list of files
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>PagedResponseOfFileMetaDto</returns>
        PagedResponseOfFileMetaDto GetFilesUsingGET (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null);

        /// <summary>
        /// Retrieve a list of files
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFileMetaDto</returns>
        ApiResponse<PagedResponseOfFileMetaDto> GetFilesUsingGETWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null);
        /// <summary>
        /// Upload a single file
        /// </summary>
        /// <remarks>
        /// Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        BaseResponseOfFileMetaDto UploadFileUsingPOST (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null);

        /// <summary>
        /// Upload a single file
        /// </summary>
        /// <remarks>
        /// Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        ApiResponse<BaseResponseOfFileMetaDto> UploadFileUsingPOSTWithHttpInfo (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null);
        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table
        /// </summary>
        /// <remarks>
        /// If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring ValidateFilenameUsingGET (string tableId, string filename);

        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table
        /// </summary>
        /// <remarks>
        /// If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> ValidateFilenameUsingGETWithHttpInfo (string tableId, string filename);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Delete a single file
        /// </summary>
        /// <remarks>
        /// Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteFileUsingDELETEAsync (string fileId);

        /// <summary>
        /// Delete a single file
        /// </summary>
        /// <remarks>
        /// Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteFileUsingDELETEAsyncWithHttpInfo (string fileId);
        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Returns a file with the provided ID, which points to a file meta ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of byte[]</returns>
        System.Threading.Tasks.Task<byte[]> DownloadFileUsingGETAsync (string fileId);

        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Returns a file with the provided ID, which points to a file meta ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadFileUsingGETAsyncWithHttpInfo (string fileId);
        /// <summary>
        /// Export a file to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>Task of BaseResponseOfSpreadsheetInfoDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfSpreadsheetInfoDto> ExportFileToSpreadsheetsUsingPOSTAsync (string fileId, ExportFileDto exportFileDto);

        /// <summary>
        /// Export a file to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSpreadsheetInfoDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSpreadsheetInfoDto>> ExportFileToSpreadsheetsUsingPOSTAsyncWithHttpInfo (string fileId, ExportFileDto exportFileDto);
        /// <summary>
        /// Retrieve errors
        /// </summary>
        /// <remarks>
        /// Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfImportErrorDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfImportErrorDto> GetErrorsUsingGETAsync (string fileId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve errors
        /// </summary>
        /// <remarks>
        /// Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfImportErrorDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfImportErrorDto>> GetErrorsUsingGETAsyncWithHttpInfo (string fileId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve a single file
        /// </summary>
        /// <remarks>
        /// Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> GetFileUsingGETAsync (string fileId);

        /// <summary>
        /// Retrieve a single file
        /// </summary>
        /// <remarks>
        /// Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> GetFileUsingGETAsyncWithHttpInfo (string fileId);
        /// <summary>
        /// Retrieve a list of files
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>Task of PagedResponseOfFileMetaDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfFileMetaDto> GetFilesUsingGETAsync (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null);

        /// <summary>
        /// Retrieve a list of files
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFileMetaDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFileMetaDto>> GetFilesUsingGETAsyncWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null);
        /// <summary>
        /// Upload a single file
        /// </summary>
        /// <remarks>
        /// Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> UploadFileUsingPOSTAsync (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null);

        /// <summary>
        /// Upload a single file
        /// </summary>
        /// <remarks>
        /// Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> UploadFileUsingPOSTAsyncWithHttpInfo (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null);
        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table
        /// </summary>
        /// <remarks>
        /// If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> ValidateFilenameUsingGETAsync (string tableId, string filename);

        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table
        /// </summary>
        /// <remarks>
        /// If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ValidateFilenameUsingGETAsyncWithHttpInfo (string tableId, string filename);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class FileManagementApi : IFileManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="FileManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public FileManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="FileManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public FileManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Delete a single file Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteFileUsingDELETE (string fileId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteFileUsingDELETEWithHttpInfo(fileId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single file Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteFileUsingDELETEWithHttpInfo (string fileId)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->DeleteFileUsingDELETE");

            var localVarPath = "/api/v1/file/{fileId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteFileUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single file Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteFileUsingDELETEAsync (string fileId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteFileUsingDELETEAsyncWithHttpInfo(fileId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single file Unstages the file with the provided ID. The file must have a STAGED status; if the file isn&#39;t STAGED, returns a 409 status. If the file isn&#39;t found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteFileUsingDELETEAsyncWithHttpInfo (string fileId)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->DeleteFileUsingDELETE");

            var localVarPath = "/api/v1/file/{fileId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteFileUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Download a single file Returns a file with the provided ID, which points to a file meta ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>byte[]</returns>
        public byte[] DownloadFileUsingGET (string fileId)
        {
             ApiResponse<byte[]> localVarResponse = DownloadFileUsingGETWithHttpInfo(fileId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Download a single file Returns a file with the provided ID, which points to a file meta ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>ApiResponse of byte[]</returns>
        public ApiResponse< byte[] > DownloadFileUsingGETWithHttpInfo (string fileId)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->DownloadFileUsingGET");

            var localVarPath = "/api/v1/file/{fileId}/download";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadFileUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

        /// <summary>
        /// Download a single file Returns a file with the provided ID, which points to a file meta ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of byte[]</returns>
        public async System.Threading.Tasks.Task<byte[]> DownloadFileUsingGETAsync (string fileId)
        {
             ApiResponse<byte[]> localVarResponse = await DownloadFileUsingGETAsyncWithHttpInfo(fileId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Download a single file Returns a file with the provided ID, which points to a file meta ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        public async System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadFileUsingGETAsyncWithHttpInfo (string fileId)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->DownloadFileUsingGET");

            var localVarPath = "/api/v1/file/{fileId}/download";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadFileUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

        /// <summary>
        /// Export a file to spreadsheets Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>BaseResponseOfSpreadsheetInfoDto</returns>
        public BaseResponseOfSpreadsheetInfoDto ExportFileToSpreadsheetsUsingPOST (string fileId, ExportFileDto exportFileDto)
        {
             ApiResponse<BaseResponseOfSpreadsheetInfoDto> localVarResponse = ExportFileToSpreadsheetsUsingPOSTWithHttpInfo(fileId, exportFileDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Export a file to spreadsheets Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>ApiResponse of BaseResponseOfSpreadsheetInfoDto</returns>
        public ApiResponse< BaseResponseOfSpreadsheetInfoDto > ExportFileToSpreadsheetsUsingPOSTWithHttpInfo (string fileId, ExportFileDto exportFileDto)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->ExportFileToSpreadsheetsUsingPOST");
            // verify the required parameter 'exportFileDto' is set
            if (exportFileDto == null)
                throw new ApiException(400, "Missing required parameter 'exportFileDto' when calling FileManagementApi->ExportFileToSpreadsheetsUsingPOST");

            var localVarPath = "/api/v1/file/{fileId}/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter
            if (exportFileDto != null && exportFileDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(exportFileDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = exportFileDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ExportFileToSpreadsheetsUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSpreadsheetInfoDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSpreadsheetInfoDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSpreadsheetInfoDto)));
            
        }

        /// <summary>
        /// Export a file to spreadsheets Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>Task of BaseResponseOfSpreadsheetInfoDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfSpreadsheetInfoDto> ExportFileToSpreadsheetsUsingPOSTAsync (string fileId, ExportFileDto exportFileDto)
        {
             ApiResponse<BaseResponseOfSpreadsheetInfoDto> localVarResponse = await ExportFileToSpreadsheetsUsingPOSTAsyncWithHttpInfo(fileId, exportFileDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Export a file to spreadsheets Exports the file ID identified in the path to the spreadsheet identified by the provided URL. If the URL string is empty, creates and returns a new spreadsheet and its sheet IDs.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="exportFileDto">The representation of the file to export</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSpreadsheetInfoDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSpreadsheetInfoDto>> ExportFileToSpreadsheetsUsingPOSTAsyncWithHttpInfo (string fileId, ExportFileDto exportFileDto)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->ExportFileToSpreadsheetsUsingPOST");
            // verify the required parameter 'exportFileDto' is set
            if (exportFileDto == null)
                throw new ApiException(400, "Missing required parameter 'exportFileDto' when calling FileManagementApi->ExportFileToSpreadsheetsUsingPOST");

            var localVarPath = "/api/v1/file/{fileId}/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter
            if (exportFileDto != null && exportFileDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(exportFileDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = exportFileDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ExportFileToSpreadsheetsUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSpreadsheetInfoDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSpreadsheetInfoDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSpreadsheetInfoDto)));
            
        }

        /// <summary>
        /// Retrieve errors Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfImportErrorDto</returns>
        public PagedResponseOfImportErrorDto GetErrorsUsingGET (string fileId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfImportErrorDto> localVarResponse = GetErrorsUsingGETWithHttpInfo(fileId, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve errors Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfImportErrorDto</returns>
        public ApiResponse< PagedResponseOfImportErrorDto > GetErrorsUsingGETWithHttpInfo (string fileId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->GetErrorsUsingGET");

            var localVarPath = "/api/v1/file/{fileId}/error";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetErrorsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfImportErrorDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfImportErrorDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfImportErrorDto)));
            
        }

        /// <summary>
        /// Retrieve errors Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfImportErrorDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfImportErrorDto> GetErrorsUsingGETAsync (string fileId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfImportErrorDto> localVarResponse = await GetErrorsUsingGETAsyncWithHttpInfo(fileId, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve errors Returns a paged list of operation errors during the upload, import, or tagging processes for the provided file ID, if they exist. This list is immutable and may be empty if no errors have occurred. If errors exist we recommend fixing them and reimporting your file
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="limit">The number of errors to return, from 1 to 50; by default, 50 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfImportErrorDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfImportErrorDto>> GetErrorsUsingGETAsyncWithHttpInfo (string fileId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->GetErrorsUsingGET");

            var localVarPath = "/api/v1/file/{fileId}/error";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetErrorsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfImportErrorDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfImportErrorDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfImportErrorDto)));
            
        }

        /// <summary>
        /// Retrieve a single file Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        public BaseResponseOfFileMetaDto GetFileUsingGET (string fileId)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = GetFileUsingGETWithHttpInfo(fileId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single file Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        public ApiResponse< BaseResponseOfFileMetaDto > GetFileUsingGETWithHttpInfo (string fileId)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->GetFileUsingGET");

            var localVarPath = "/api/v1/file/{fileId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFileUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Retrieve a single file Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> GetFileUsingGETAsync (string fileId)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = await GetFileUsingGETAsyncWithHttpInfo(fileId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single file Returns the file meta that matches the provided ID, or a 404 if an associated file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> GetFileUsingGETAsyncWithHttpInfo (string fileId)
        {
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling FileManagementApi->GetFileUsingGET");

            var localVarPath = "/api/v1/file/{fileId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFileUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Retrieve a list of files Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>PagedResponseOfFileMetaDto</returns>
        public PagedResponseOfFileMetaDto GetFilesUsingGET (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null)
        {
             ApiResponse<PagedResponseOfFileMetaDto> localVarResponse = GetFilesUsingGETWithHttpInfo(tableId, limit, cursor, offset, sortOrder, sortBy, searchText);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of files Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFileMetaDto</returns>
        public ApiResponse< PagedResponseOfFileMetaDto > GetFilesUsingGETWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling FileManagementApi->GetFilesUsingGET");

            var localVarPath = "/api/v1/file";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarQueryParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter
            if (sortOrder != null) localVarQueryParams.Add("sortOrder", Configuration.ApiClient.ParameterToString(sortOrder)); // query parameter
            if (sortBy != null) localVarQueryParams.Add("sortBy", Configuration.ApiClient.ParameterToString(sortBy)); // query parameter
            if (searchText != null) localVarQueryParams.Add("searchText", Configuration.ApiClient.ParameterToString(searchText)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFilesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Retrieve a list of files Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>Task of PagedResponseOfFileMetaDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfFileMetaDto> GetFilesUsingGETAsync (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null)
        {
             ApiResponse<PagedResponseOfFileMetaDto> localVarResponse = await GetFilesUsingGETAsyncWithHttpInfo(tableId, limit, cursor, offset, sortOrder, sortBy, searchText);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of files Returns a paged list of all files associated with the provided table ID, as well as metadata associated with each file.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="limit">The number of files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="sortOrder">The sort order for the files being returned (optional)</param>
        /// <param name="sortBy">The column to use the sort order on (optional)</param>
        /// <param name="searchText">The text to filter the results upon; matching the file name (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFileMetaDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFileMetaDto>> GetFilesUsingGETAsyncWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null, string sortOrder = null, string sortBy = null, string searchText = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling FileManagementApi->GetFilesUsingGET");

            var localVarPath = "/api/v1/file";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarQueryParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter
            if (sortOrder != null) localVarQueryParams.Add("sortOrder", Configuration.ApiClient.ParameterToString(sortOrder)); // query parameter
            if (sortBy != null) localVarQueryParams.Add("sortBy", Configuration.ApiClient.ParameterToString(sortBy)); // query parameter
            if (searchText != null) localVarQueryParams.Add("searchText", Configuration.ApiClient.ParameterToString(searchText)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFilesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Upload a single file Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        public BaseResponseOfFileMetaDto UploadFileUsingPOST (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = UploadFileUsingPOSTWithHttpInfo(tableId, file, name, url, source, delimiter);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Upload a single file Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        public ApiResponse< BaseResponseOfFileMetaDto > UploadFileUsingPOSTWithHttpInfo (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling FileManagementApi->UploadFileUsingPOST");

            var localVarPath = "/api/v1/file";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "multipart/form-data"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (file != null) localVarFileParams.Add("file", Configuration.ApiClient.ParameterToFile("file", file));
            if (tableId != null) localVarFormParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // form parameter
            if (name != null) localVarFormParams.Add("name", Configuration.ApiClient.ParameterToString(name)); // form parameter
            if (url != null) localVarFormParams.Add("url", Configuration.ApiClient.ParameterToString(url)); // form parameter
            if (source != null) localVarFormParams.Add("source", Configuration.ApiClient.ParameterToString(source)); // form parameter
            if (delimiter != null) localVarFormParams.Add("delimiter", Configuration.ApiClient.ParameterToString(delimiter)); // form parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UploadFileUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Upload a single file Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> UploadFileUsingPOSTAsync (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = await UploadFileUsingPOSTAsyncWithHttpInfo(tableId, file, name, url, source, delimiter);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Upload a single file Accepts CSV, TSV, or JSON files, or a ZIP file that contains a single CSV, TSV, or JSON file. If a ZIP, it must contain a CSV, TSV, or JSON file, and the name of the CSV, TSV, or JSON file is also used with the imported file. Downloading this file again downloads the source. Note that all files uploaded must have a .csv, .tsv, or .json extension. JSON files are expected to have a single JSON record per line; a JSON file is a series of JSON objects delimited by a newline character.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with this file</param>
        /// <param name="file">The physical file to upload (optional)</param>
        /// <param name="name">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="url">No longer in use, here to ensure backwards compatibility (optional)</param>
        /// <param name="source">The data source to associate with the file, no more than 255 characters. This field is not in use; it only keeps track of the source (optional)</param>
        /// <param name="delimiter">The character to use as a delimiter within the file to separate one field from another.  The default is comma (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> UploadFileUsingPOSTAsyncWithHttpInfo (string tableId, System.IO.Stream file = null, string name = null, string url = null, string source = null, string delimiter = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling FileManagementApi->UploadFileUsingPOST");

            var localVarPath = "/api/v1/file";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "multipart/form-data"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (file != null) localVarFileParams.Add("file", Configuration.ApiClient.ParameterToFile("file", file));
            if (tableId != null) localVarFormParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // form parameter
            if (name != null) localVarFormParams.Add("name", Configuration.ApiClient.ParameterToString(name)); // form parameter
            if (url != null) localVarFormParams.Add("url", Configuration.ApiClient.ParameterToString(url)); // form parameter
            if (source != null) localVarFormParams.Add("source", Configuration.ApiClient.ParameterToString(source)); // form parameter
            if (delimiter != null) localVarFormParams.Add("delimiter", Configuration.ApiClient.ParameterToString(delimiter)); // form parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UploadFileUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring ValidateFilenameUsingGET (string tableId, string filename)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = ValidateFilenameUsingGETWithHttpInfo(tableId, filename);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > ValidateFilenameUsingGETWithHttpInfo (string tableId, string filename)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling FileManagementApi->ValidateFilenameUsingGET");
            // verify the required parameter 'filename' is set
            if (filename == null)
                throw new ApiException(400, "Missing required parameter 'filename' when calling FileManagementApi->ValidateFilenameUsingGET");

            var localVarPath = "/api/v1/file/validateName";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarQueryParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // query parameter
            if (filename != null) localVarQueryParams.Add("filename", Configuration.ApiClient.ParameterToString(filename)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ValidateFilenameUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> ValidateFilenameUsingGETAsync (string tableId, string filename)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await ValidateFilenameUsingGETAsyncWithHttpInfo(tableId, filename);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Validate whether a file with the filename can be uploaded to the table If the filename is valid, this returns 200. If the table already has a file with the same name, this returns 409. If the user isn&#39;t allowed to read the table, or if the table isn&#39;t found, this returns 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The ID of the table to upload the file to</param>
        /// <param name="filename">The name of the file to upload</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ValidateFilenameUsingGETAsyncWithHttpInfo (string tableId, string filename)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling FileManagementApi->ValidateFilenameUsingGET");
            // verify the required parameter 'filename' is set
            if (filename == null)
                throw new ApiException(400, "Missing required parameter 'filename' when calling FileManagementApi->ValidateFilenameUsingGET");

            var localVarPath = "/api/v1/file/validateName";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarQueryParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // query parameter
            if (filename != null) localVarQueryParams.Add("filename", Configuration.ApiClient.ParameterToString(filename)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ValidateFilenameUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

    }
}
