/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IFolderManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create a new folder
        /// </summary>
        /// <remarks>
        /// Creates a folder using the provided information and returns the folder meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>BaseResponseOfFolderDto</returns>
        BaseResponseOfFolderDto CreateFolderUsingPOST (FolderDto folderDto);

        /// <summary>
        /// Create a new folder
        /// </summary>
        /// <remarks>
        /// Creates a folder using the provided information and returns the folder meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>ApiResponse of BaseResponseOfFolderDto</returns>
        ApiResponse<BaseResponseOfFolderDto> CreateFolderUsingPOSTWithHttpInfo (FolderDto folderDto);
        /// <summary>
        /// Delete a single folder
        /// </summary>
        /// <remarks>
        /// Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteFolderUsingDELETE (string folderId);

        /// <summary>
        /// Delete a single folder
        /// </summary>
        /// <remarks>
        /// Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteFolderUsingDELETEWithHttpInfo (string folderId);
        /// <summary>
        /// Retrieve a single folder
        /// </summary>
        /// <remarks>
        /// Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>BaseResponseOfFolderDto</returns>
        BaseResponseOfFolderDto GetFolderUsingGET (string folderId);

        /// <summary>
        /// Retrieve a single folder
        /// </summary>
        /// <remarks>
        /// Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>ApiResponse of BaseResponseOfFolderDto</returns>
        ApiResponse<BaseResponseOfFolderDto> GetFolderUsingGETWithHttpInfo (string folderId);
        /// <summary>
        /// Retrieve list of folder contents
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFolderableDto</returns>
        PagedResponseOfFolderableDto ListChildrenUsingGET (string folderId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve list of folder contents
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFolderableDto</returns>
        ApiResponse<PagedResponseOfFolderableDto> ListChildrenUsingGETWithHttpInfo (string folderId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve a list of folders
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all folders associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFolderDto</returns>
        PagedResponseOfFolderDto ListFoldersUsingGET (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of folders
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all folders associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFolderDto</returns>
        ApiResponse<PagedResponseOfFolderDto> ListFoldersUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Search
        /// </summary>
        /// <remarks>
        /// Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFolderableDto</returns>
        PagedResponseOfFolderableDto SearchUsingGET (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Search
        /// </summary>
        /// <remarks>
        /// Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFolderableDto</returns>
        ApiResponse<PagedResponseOfFolderableDto> SearchUsingGETWithHttpInfo (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Move content into a folder
        /// </summary>
        /// <remarks>
        /// Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>BaseResponseOfCollectionOfFolderableDto</returns>
        BaseResponseOfCollectionOfFolderableDto SetChildrenUsingPOST (string folderId, List<FolderableDto> children);

        /// <summary>
        /// Move content into a folder
        /// </summary>
        /// <remarks>
        /// Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>ApiResponse of BaseResponseOfCollectionOfFolderableDto</returns>
        ApiResponse<BaseResponseOfCollectionOfFolderableDto> SetChildrenUsingPOSTWithHttpInfo (string folderId, List<FolderableDto> children);
        /// <summary>
        /// Update a single folder
        /// </summary>
        /// <remarks>
        /// Updates the folder that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>BaseResponseOfFolderDto</returns>
        BaseResponseOfFolderDto UpdateFolderUsingPUT (string folderId, FolderDto folderDto);

        /// <summary>
        /// Update a single folder
        /// </summary>
        /// <remarks>
        /// Updates the folder that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>ApiResponse of BaseResponseOfFolderDto</returns>
        ApiResponse<BaseResponseOfFolderDto> UpdateFolderUsingPUTWithHttpInfo (string folderId, FolderDto folderDto);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create a new folder
        /// </summary>
        /// <remarks>
        /// Creates a folder using the provided information and returns the folder meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>Task of BaseResponseOfFolderDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFolderDto> CreateFolderUsingPOSTAsync (FolderDto folderDto);

        /// <summary>
        /// Create a new folder
        /// </summary>
        /// <remarks>
        /// Creates a folder using the provided information and returns the folder meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFolderDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFolderDto>> CreateFolderUsingPOSTAsyncWithHttpInfo (FolderDto folderDto);
        /// <summary>
        /// Delete a single folder
        /// </summary>
        /// <remarks>
        /// Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteFolderUsingDELETEAsync (string folderId);

        /// <summary>
        /// Delete a single folder
        /// </summary>
        /// <remarks>
        /// Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteFolderUsingDELETEAsyncWithHttpInfo (string folderId);
        /// <summary>
        /// Retrieve a single folder
        /// </summary>
        /// <remarks>
        /// Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of BaseResponseOfFolderDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFolderDto> GetFolderUsingGETAsync (string folderId);

        /// <summary>
        /// Retrieve a single folder
        /// </summary>
        /// <remarks>
        /// Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFolderDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFolderDto>> GetFolderUsingGETAsyncWithHttpInfo (string folderId);
        /// <summary>
        /// Retrieve list of folder contents
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFolderableDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfFolderableDto> ListChildrenUsingGETAsync (string folderId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve list of folder contents
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFolderableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFolderableDto>> ListChildrenUsingGETAsyncWithHttpInfo (string folderId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve a list of folders
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all folders associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFolderDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfFolderDto> ListFoldersUsingGETAsync (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of folders
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all folders associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFolderDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFolderDto>> ListFoldersUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Search
        /// </summary>
        /// <remarks>
        /// Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFolderableDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfFolderableDto> SearchUsingGETAsync (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Search
        /// </summary>
        /// <remarks>
        /// Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFolderableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFolderableDto>> SearchUsingGETAsyncWithHttpInfo (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Move content into a folder
        /// </summary>
        /// <remarks>
        /// Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>Task of BaseResponseOfCollectionOfFolderableDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfCollectionOfFolderableDto> SetChildrenUsingPOSTAsync (string folderId, List<FolderableDto> children);

        /// <summary>
        /// Move content into a folder
        /// </summary>
        /// <remarks>
        /// Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>Task of ApiResponse (BaseResponseOfCollectionOfFolderableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfCollectionOfFolderableDto>> SetChildrenUsingPOSTAsyncWithHttpInfo (string folderId, List<FolderableDto> children);
        /// <summary>
        /// Update a single folder
        /// </summary>
        /// <remarks>
        /// Updates the folder that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>Task of BaseResponseOfFolderDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFolderDto> UpdateFolderUsingPUTAsync (string folderId, FolderDto folderDto);

        /// <summary>
        /// Update a single folder
        /// </summary>
        /// <remarks>
        /// Updates the folder that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFolderDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFolderDto>> UpdateFolderUsingPUTAsyncWithHttpInfo (string folderId, FolderDto folderDto);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class FolderManagementApi : IFolderManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="FolderManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public FolderManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="FolderManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public FolderManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create a new folder Creates a folder using the provided information and returns the folder meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>BaseResponseOfFolderDto</returns>
        public BaseResponseOfFolderDto CreateFolderUsingPOST (FolderDto folderDto)
        {
             ApiResponse<BaseResponseOfFolderDto> localVarResponse = CreateFolderUsingPOSTWithHttpInfo(folderDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new folder Creates a folder using the provided information and returns the folder meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>ApiResponse of BaseResponseOfFolderDto</returns>
        public ApiResponse< BaseResponseOfFolderDto > CreateFolderUsingPOSTWithHttpInfo (FolderDto folderDto)
        {
            // verify the required parameter 'folderDto' is set
            if (folderDto == null)
                throw new ApiException(400, "Missing required parameter 'folderDto' when calling FolderManagementApi->CreateFolderUsingPOST");

            var localVarPath = "/api/v1/folder";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderDto != null && folderDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(folderDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = folderDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateFolderUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFolderDto)));
            
        }

        /// <summary>
        /// Create a new folder Creates a folder using the provided information and returns the folder meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>Task of BaseResponseOfFolderDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFolderDto> CreateFolderUsingPOSTAsync (FolderDto folderDto)
        {
             ApiResponse<BaseResponseOfFolderDto> localVarResponse = await CreateFolderUsingPOSTAsyncWithHttpInfo(folderDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new folder Creates a folder using the provided information and returns the folder meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderDto">The representation of the folder to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFolderDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFolderDto>> CreateFolderUsingPOSTAsyncWithHttpInfo (FolderDto folderDto)
        {
            // verify the required parameter 'folderDto' is set
            if (folderDto == null)
                throw new ApiException(400, "Missing required parameter 'folderDto' when calling FolderManagementApi->CreateFolderUsingPOST");

            var localVarPath = "/api/v1/folder";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderDto != null && folderDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(folderDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = folderDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateFolderUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFolderDto)));
            
        }

        /// <summary>
        /// Delete a single folder Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteFolderUsingDELETE (string folderId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteFolderUsingDELETEWithHttpInfo(folderId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single folder Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteFolderUsingDELETEWithHttpInfo (string folderId)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->DeleteFolderUsingDELETE");

            var localVarPath = "/api/v1/folder/{folderId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteFolderUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single folder Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteFolderUsingDELETEAsync (string folderId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteFolderUsingDELETEAsyncWithHttpInfo(folderId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single folder Deletes the folder with the provided ID.  If the folder is not found, this is a no-op. &lt;b&gt;All files and sub-folders are also recursively deleted.&lt;/b&gt;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteFolderUsingDELETEAsyncWithHttpInfo (string folderId)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->DeleteFolderUsingDELETE");

            var localVarPath = "/api/v1/folder/{folderId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteFolderUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Retrieve a single folder Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>BaseResponseOfFolderDto</returns>
        public BaseResponseOfFolderDto GetFolderUsingGET (string folderId)
        {
             ApiResponse<BaseResponseOfFolderDto> localVarResponse = GetFolderUsingGETWithHttpInfo(folderId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single folder Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>ApiResponse of BaseResponseOfFolderDto</returns>
        public ApiResponse< BaseResponseOfFolderDto > GetFolderUsingGETWithHttpInfo (string folderId)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->GetFolderUsingGET");

            var localVarPath = "/api/v1/folder/{folderId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFolderUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFolderDto)));
            
        }

        /// <summary>
        /// Retrieve a single folder Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of BaseResponseOfFolderDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFolderDto> GetFolderUsingGETAsync (string folderId)
        {
             ApiResponse<BaseResponseOfFolderDto> localVarResponse = await GetFolderUsingGETAsyncWithHttpInfo(folderId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single folder Returns a folder with the provided ID, or a 404 if no matching folder is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFolderDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFolderDto>> GetFolderUsingGETAsyncWithHttpInfo (string folderId)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->GetFolderUsingGET");

            var localVarPath = "/api/v1/folder/{folderId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetFolderUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFolderDto)));
            
        }

        /// <summary>
        /// Retrieve list of folder contents Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFolderableDto</returns>
        public PagedResponseOfFolderableDto ListChildrenUsingGET (string folderId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFolderableDto> localVarResponse = ListChildrenUsingGETWithHttpInfo(folderId, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve list of folder contents Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFolderableDto</returns>
        public ApiResponse< PagedResponseOfFolderableDto > ListChildrenUsingGETWithHttpInfo (string folderId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->ListChildrenUsingGET");

            var localVarPath = "/api/v1/folder/{folderId}/children";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListChildrenUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFolderableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFolderableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFolderableDto)));
            
        }

        /// <summary>
        /// Retrieve list of folder contents Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFolderableDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfFolderableDto> ListChildrenUsingGETAsync (string folderId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFolderableDto> localVarResponse = await ListChildrenUsingGETAsyncWithHttpInfo(folderId, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve list of folder contents Returns a paged list of all children whose parent ID matches the provided folder ID.  If the folder ID in the path is the literal &#39;null&#39; value, returns a list of all entities with no parent.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFolderableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFolderableDto>> ListChildrenUsingGETAsyncWithHttpInfo (string folderId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->ListChildrenUsingGET");

            var localVarPath = "/api/v1/folder/{folderId}/children";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListChildrenUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFolderableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFolderableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFolderableDto)));
            
        }

        /// <summary>
        /// Retrieve a list of folders Returns a paged list of all folders associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFolderDto</returns>
        public PagedResponseOfFolderDto ListFoldersUsingGET (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFolderDto> localVarResponse = ListFoldersUsingGETWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of folders Returns a paged list of all folders associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFolderDto</returns>
        public ApiResponse< PagedResponseOfFolderDto > ListFoldersUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/folder";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListFoldersUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFolderDto)));
            
        }

        /// <summary>
        /// Retrieve a list of folders Returns a paged list of all folders associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFolderDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfFolderDto> ListFoldersUsingGETAsync (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFolderDto> localVarResponse = await ListFoldersUsingGETAsyncWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of folders Returns a paged list of all folders associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFolderDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFolderDto>> ListFoldersUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/folder";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListFoldersUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFolderDto)));
            
        }

        /// <summary>
        /// Search Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfFolderableDto</returns>
        public PagedResponseOfFolderableDto SearchUsingGET (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFolderableDto> localVarResponse = SearchUsingGETWithHttpInfo(name, description, type, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Search Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfFolderableDto</returns>
        public ApiResponse< PagedResponseOfFolderableDto > SearchUsingGETWithHttpInfo (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/entity";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (name != null) localVarQueryParams.Add("name", Configuration.ApiClient.ParameterToString(name)); // query parameter
            if (description != null) localVarQueryParams.Add("description", Configuration.ApiClient.ParameterToString(description)); // query parameter
            if (type != null) localVarQueryParams.Add("type", Configuration.ApiClient.ParameterToString(type)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("SearchUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFolderableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFolderableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFolderableDto)));
            
        }

        /// <summary>
        /// Search Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfFolderableDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfFolderableDto> SearchUsingGETAsync (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfFolderableDto> localVarResponse = await SearchUsingGETAsyncWithHttpInfo(name, description, type, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Search Returns a list of all entities that match the provided criteria. Both name and description are fuzzy matches; they match _any_ entity that contains the provided string. The type is used to filter results based on the provided type of entity.  The consumer must have READ access on all returned entities.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="name">The name to use when fuzzy-matching entities (optional)</param>
        /// <param name="description">The description to use when fuzzy-matching entities (optional)</param>
        /// <param name="type">To limit the scope, the type of entity to return in the results (optional)</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfFolderableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfFolderableDto>> SearchUsingGETAsyncWithHttpInfo (string name = null, string description = null, List<int?> type = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/entity";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (name != null) localVarQueryParams.Add("name", Configuration.ApiClient.ParameterToString(name)); // query parameter
            if (description != null) localVarQueryParams.Add("description", Configuration.ApiClient.ParameterToString(description)); // query parameter
            if (type != null) localVarQueryParams.Add("type", Configuration.ApiClient.ParameterToString(type)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("SearchUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfFolderableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfFolderableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfFolderableDto)));
            
        }

        /// <summary>
        /// Move content into a folder Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>BaseResponseOfCollectionOfFolderableDto</returns>
        public BaseResponseOfCollectionOfFolderableDto SetChildrenUsingPOST (string folderId, List<FolderableDto> children)
        {
             ApiResponse<BaseResponseOfCollectionOfFolderableDto> localVarResponse = SetChildrenUsingPOSTWithHttpInfo(folderId, children);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Move content into a folder Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>ApiResponse of BaseResponseOfCollectionOfFolderableDto</returns>
        public ApiResponse< BaseResponseOfCollectionOfFolderableDto > SetChildrenUsingPOSTWithHttpInfo (string folderId, List<FolderableDto> children)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->SetChildrenUsingPOST");
            // verify the required parameter 'children' is set
            if (children == null)
                throw new ApiException(400, "Missing required parameter 'children' when calling FolderManagementApi->SetChildrenUsingPOST");

            var localVarPath = "/api/v1/folder/{folderId}/children";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter
            if (children != null && children.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(children); // http body (model) parameter
            }
            else
            {
                localVarPostBody = children; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("SetChildrenUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfCollectionOfFolderableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfCollectionOfFolderableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfCollectionOfFolderableDto)));
            
        }

        /// <summary>
        /// Move content into a folder Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>Task of BaseResponseOfCollectionOfFolderableDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfCollectionOfFolderableDto> SetChildrenUsingPOSTAsync (string folderId, List<FolderableDto> children)
        {
             ApiResponse<BaseResponseOfCollectionOfFolderableDto> localVarResponse = await SetChildrenUsingPOSTAsyncWithHttpInfo(folderId, children);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Move content into a folder Sets the children of a folder using the entities&#39; types and IDs provided in the body. If the entities previously resided under a folder, including the root, they move to the folder with the provided ID. If the provided ID is &#39;null&#39;, the entities move to the root folder.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="children">The representation of the entities to drop into the folder</param>
        /// <returns>Task of ApiResponse (BaseResponseOfCollectionOfFolderableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfCollectionOfFolderableDto>> SetChildrenUsingPOSTAsyncWithHttpInfo (string folderId, List<FolderableDto> children)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->SetChildrenUsingPOST");
            // verify the required parameter 'children' is set
            if (children == null)
                throw new ApiException(400, "Missing required parameter 'children' when calling FolderManagementApi->SetChildrenUsingPOST");

            var localVarPath = "/api/v1/folder/{folderId}/children";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter
            if (children != null && children.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(children); // http body (model) parameter
            }
            else
            {
                localVarPostBody = children; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("SetChildrenUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfCollectionOfFolderableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfCollectionOfFolderableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfCollectionOfFolderableDto)));
            
        }

        /// <summary>
        /// Update a single folder Updates the folder that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>BaseResponseOfFolderDto</returns>
        public BaseResponseOfFolderDto UpdateFolderUsingPUT (string folderId, FolderDto folderDto)
        {
             ApiResponse<BaseResponseOfFolderDto> localVarResponse = UpdateFolderUsingPUTWithHttpInfo(folderId, folderDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update a single folder Updates the folder that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>ApiResponse of BaseResponseOfFolderDto</returns>
        public ApiResponse< BaseResponseOfFolderDto > UpdateFolderUsingPUTWithHttpInfo (string folderId, FolderDto folderDto)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->UpdateFolderUsingPUT");
            // verify the required parameter 'folderDto' is set
            if (folderDto == null)
                throw new ApiException(400, "Missing required parameter 'folderDto' when calling FolderManagementApi->UpdateFolderUsingPUT");

            var localVarPath = "/api/v1/folder/{folderId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter
            if (folderDto != null && folderDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(folderDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = folderDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateFolderUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFolderDto)));
            
        }

        /// <summary>
        /// Update a single folder Updates the folder that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>Task of BaseResponseOfFolderDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFolderDto> UpdateFolderUsingPUTAsync (string folderId, FolderDto folderDto)
        {
             ApiResponse<BaseResponseOfFolderDto> localVarResponse = await UpdateFolderUsingPUTAsyncWithHttpInfo(folderId, folderDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update a single folder Updates the folder that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="folderId">The unique identifier of the folder</param>
        /// <param name="folderDto">The representation of the folder to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFolderDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFolderDto>> UpdateFolderUsingPUTAsyncWithHttpInfo (string folderId, FolderDto folderDto)
        {
            // verify the required parameter 'folderId' is set
            if (folderId == null)
                throw new ApiException(400, "Missing required parameter 'folderId' when calling FolderManagementApi->UpdateFolderUsingPUT");
            // verify the required parameter 'folderDto' is set
            if (folderDto == null)
                throw new ApiException(400, "Missing required parameter 'folderDto' when calling FolderManagementApi->UpdateFolderUsingPUT");

            var localVarPath = "/api/v1/folder/{folderId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (folderId != null) localVarPathParams.Add("folderId", Configuration.ApiClient.ParameterToString(folderId)); // path parameter
            if (folderDto != null && folderDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(folderDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = folderDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateFolderUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFolderDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFolderDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFolderDto)));
            
        }

    }
}
