/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IParameterManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create parameter
        /// </summary>
        /// <remarks>
        /// Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>BaseResponseOfGlobalParameterDto</returns>
        BaseResponseOfGlobalParameterDto CreateParameterUsingPOST (GlobalParameterDto parameterDto);

        /// <summary>
        /// Create parameter
        /// </summary>
        /// <remarks>
        /// Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>ApiResponse of BaseResponseOfGlobalParameterDto</returns>
        ApiResponse<BaseResponseOfGlobalParameterDto> CreateParameterUsingPOSTWithHttpInfo (GlobalParameterDto parameterDto);
        /// <summary>
        /// Delete Parameter
        /// </summary>
        /// <remarks>
        /// Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteParameterUsingDELETE (string parameterId);

        /// <summary>
        /// Delete Parameter
        /// </summary>
        /// <remarks>
        /// Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteParameterUsingDELETEWithHttpInfo (string parameterId);
        /// <summary>
        /// Get Parameter
        /// </summary>
        /// <remarks>
        /// Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>BaseResponseOfGlobalParameterDto</returns>
        BaseResponseOfGlobalParameterDto GetParameterUsingGET (string parameterId);

        /// <summary>
        /// Get Parameter
        /// </summary>
        /// <remarks>
        /// Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>ApiResponse of BaseResponseOfGlobalParameterDto</returns>
        ApiResponse<BaseResponseOfGlobalParameterDto> GetParameterUsingGETWithHttpInfo (string parameterId);
        /// <summary>
        /// Get Parameters
        /// </summary>
        /// <remarks>
        /// Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>PagedResponseOfGlobalParameterDto</returns>
        PagedResponseOfGlobalParameterDto ListParametersUsingGET (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Get Parameters
        /// </summary>
        /// <remarks>
        /// Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfGlobalParameterDto</returns>
        ApiResponse<PagedResponseOfGlobalParameterDto> ListParametersUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update Parameter
        /// </summary>
        /// <remarks>
        /// Updates the parameter matching the provided ID in the provided payload.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>BaseResponseOfGlobalParameterDto</returns>
        BaseResponseOfGlobalParameterDto UpdateParameterUsingPUT (string parameterId, GlobalParameterDto parameterDto);

        /// <summary>
        /// Update Parameter
        /// </summary>
        /// <remarks>
        /// Updates the parameter matching the provided ID in the provided payload.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>ApiResponse of BaseResponseOfGlobalParameterDto</returns>
        ApiResponse<BaseResponseOfGlobalParameterDto> UpdateParameterUsingPUTWithHttpInfo (string parameterId, GlobalParameterDto parameterDto);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create parameter
        /// </summary>
        /// <remarks>
        /// Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>Task of BaseResponseOfGlobalParameterDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfGlobalParameterDto> CreateParameterUsingPOSTAsync (GlobalParameterDto parameterDto);

        /// <summary>
        /// Create parameter
        /// </summary>
        /// <remarks>
        /// Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfGlobalParameterDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfGlobalParameterDto>> CreateParameterUsingPOSTAsyncWithHttpInfo (GlobalParameterDto parameterDto);
        /// <summary>
        /// Delete Parameter
        /// </summary>
        /// <remarks>
        /// Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteParameterUsingDELETEAsync (string parameterId);

        /// <summary>
        /// Delete Parameter
        /// </summary>
        /// <remarks>
        /// Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteParameterUsingDELETEAsyncWithHttpInfo (string parameterId);
        /// <summary>
        /// Get Parameter
        /// </summary>
        /// <remarks>
        /// Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of BaseResponseOfGlobalParameterDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfGlobalParameterDto> GetParameterUsingGETAsync (string parameterId);

        /// <summary>
        /// Get Parameter
        /// </summary>
        /// <remarks>
        /// Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of ApiResponse (BaseResponseOfGlobalParameterDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfGlobalParameterDto>> GetParameterUsingGETAsyncWithHttpInfo (string parameterId);
        /// <summary>
        /// Get Parameters
        /// </summary>
        /// <remarks>
        /// Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of PagedResponseOfGlobalParameterDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfGlobalParameterDto> ListParametersUsingGETAsync (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Get Parameters
        /// </summary>
        /// <remarks>
        /// Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfGlobalParameterDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfGlobalParameterDto>> ListParametersUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update Parameter
        /// </summary>
        /// <remarks>
        /// Updates the parameter matching the provided ID in the provided payload.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>Task of BaseResponseOfGlobalParameterDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfGlobalParameterDto> UpdateParameterUsingPUTAsync (string parameterId, GlobalParameterDto parameterDto);

        /// <summary>
        /// Update Parameter
        /// </summary>
        /// <remarks>
        /// Updates the parameter matching the provided ID in the provided payload.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfGlobalParameterDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfGlobalParameterDto>> UpdateParameterUsingPUTAsyncWithHttpInfo (string parameterId, GlobalParameterDto parameterDto);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class ParameterManagementApi : IParameterManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="ParameterManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public ParameterManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ParameterManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public ParameterManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create parameter Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>BaseResponseOfGlobalParameterDto</returns>
        public BaseResponseOfGlobalParameterDto CreateParameterUsingPOST (GlobalParameterDto parameterDto)
        {
             ApiResponse<BaseResponseOfGlobalParameterDto> localVarResponse = CreateParameterUsingPOSTWithHttpInfo(parameterDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create parameter Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>ApiResponse of BaseResponseOfGlobalParameterDto</returns>
        public ApiResponse< BaseResponseOfGlobalParameterDto > CreateParameterUsingPOSTWithHttpInfo (GlobalParameterDto parameterDto)
        {
            // verify the required parameter 'parameterDto' is set
            if (parameterDto == null)
                throw new ApiException(400, "Missing required parameter 'parameterDto' when calling ParameterManagementApi->CreateParameterUsingPOST");

            var localVarPath = "/api/v1/parameter";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterDto != null && parameterDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(parameterDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = parameterDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateParameterUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfGlobalParameterDto)));
            
        }

        /// <summary>
        /// Create parameter Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>Task of BaseResponseOfGlobalParameterDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfGlobalParameterDto> CreateParameterUsingPOSTAsync (GlobalParameterDto parameterDto)
        {
             ApiResponse<BaseResponseOfGlobalParameterDto> localVarResponse = await CreateParameterUsingPOSTAsyncWithHttpInfo(parameterDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create parameter Creates a parameter.  If there is a parameter with the same ID, a 409 is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterDto">The representation of the parameter to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfGlobalParameterDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfGlobalParameterDto>> CreateParameterUsingPOSTAsyncWithHttpInfo (GlobalParameterDto parameterDto)
        {
            // verify the required parameter 'parameterDto' is set
            if (parameterDto == null)
                throw new ApiException(400, "Missing required parameter 'parameterDto' when calling ParameterManagementApi->CreateParameterUsingPOST");

            var localVarPath = "/api/v1/parameter";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterDto != null && parameterDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(parameterDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = parameterDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateParameterUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfGlobalParameterDto)));
            
        }

        /// <summary>
        /// Delete Parameter Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteParameterUsingDELETE (string parameterId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteParameterUsingDELETEWithHttpInfo(parameterId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete Parameter Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteParameterUsingDELETEWithHttpInfo (string parameterId)
        {
            // verify the required parameter 'parameterId' is set
            if (parameterId == null)
                throw new ApiException(400, "Missing required parameter 'parameterId' when calling ParameterManagementApi->DeleteParameterUsingDELETE");

            var localVarPath = "/api/v1/parameter/{parameterId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterId != null) localVarPathParams.Add("parameterId", Configuration.ApiClient.ParameterToString(parameterId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteParameterUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete Parameter Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteParameterUsingDELETEAsync (string parameterId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteParameterUsingDELETEAsyncWithHttpInfo(parameterId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete Parameter Deletes the parameter with the provided parameter ID.  If the parameter is not found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteParameterUsingDELETEAsyncWithHttpInfo (string parameterId)
        {
            // verify the required parameter 'parameterId' is set
            if (parameterId == null)
                throw new ApiException(400, "Missing required parameter 'parameterId' when calling ParameterManagementApi->DeleteParameterUsingDELETE");

            var localVarPath = "/api/v1/parameter/{parameterId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterId != null) localVarPathParams.Add("parameterId", Configuration.ApiClient.ParameterToString(parameterId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteParameterUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Get Parameter Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>BaseResponseOfGlobalParameterDto</returns>
        public BaseResponseOfGlobalParameterDto GetParameterUsingGET (string parameterId)
        {
             ApiResponse<BaseResponseOfGlobalParameterDto> localVarResponse = GetParameterUsingGETWithHttpInfo(parameterId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Get Parameter Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>ApiResponse of BaseResponseOfGlobalParameterDto</returns>
        public ApiResponse< BaseResponseOfGlobalParameterDto > GetParameterUsingGETWithHttpInfo (string parameterId)
        {
            // verify the required parameter 'parameterId' is set
            if (parameterId == null)
                throw new ApiException(400, "Missing required parameter 'parameterId' when calling ParameterManagementApi->GetParameterUsingGET");

            var localVarPath = "/api/v1/parameter/{parameterId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterId != null) localVarPathParams.Add("parameterId", Configuration.ApiClient.ParameterToString(parameterId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetParameterUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfGlobalParameterDto)));
            
        }

        /// <summary>
        /// Get Parameter Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of BaseResponseOfGlobalParameterDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfGlobalParameterDto> GetParameterUsingGETAsync (string parameterId)
        {
             ApiResponse<BaseResponseOfGlobalParameterDto> localVarResponse = await GetParameterUsingGETAsyncWithHttpInfo(parameterId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Get Parameter Returns a parameter matching the provided parameter ID.  If no matching entity can be found, a 404 status is returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <returns>Task of ApiResponse (BaseResponseOfGlobalParameterDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfGlobalParameterDto>> GetParameterUsingGETAsyncWithHttpInfo (string parameterId)
        {
            // verify the required parameter 'parameterId' is set
            if (parameterId == null)
                throw new ApiException(400, "Missing required parameter 'parameterId' when calling ParameterManagementApi->GetParameterUsingGET");

            var localVarPath = "/api/v1/parameter/{parameterId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterId != null) localVarPathParams.Add("parameterId", Configuration.ApiClient.ParameterToString(parameterId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetParameterUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfGlobalParameterDto)));
            
        }

        /// <summary>
        /// Get Parameters Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>PagedResponseOfGlobalParameterDto</returns>
        public PagedResponseOfGlobalParameterDto ListParametersUsingGET (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfGlobalParameterDto> localVarResponse = ListParametersUsingGETWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Get Parameters Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfGlobalParameterDto</returns>
        public ApiResponse< PagedResponseOfGlobalParameterDto > ListParametersUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/parameter";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListParametersUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfGlobalParameterDto)));
            
        }

        /// <summary>
        /// Get Parameters Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of PagedResponseOfGlobalParameterDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfGlobalParameterDto> ListParametersUsingGETAsync (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfGlobalParameterDto> localVarResponse = await ListParametersUsingGETAsyncWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Get Parameters Returns a list of all parameters associated with the workspace.  By default, these parameters are ordered by their names in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of parameters to return, must be between 1 and 1000, will default to 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfGlobalParameterDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfGlobalParameterDto>> ListParametersUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/parameter";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListParametersUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfGlobalParameterDto)));
            
        }

        /// <summary>
        /// Update Parameter Updates the parameter matching the provided ID in the provided payload.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>BaseResponseOfGlobalParameterDto</returns>
        public BaseResponseOfGlobalParameterDto UpdateParameterUsingPUT (string parameterId, GlobalParameterDto parameterDto)
        {
             ApiResponse<BaseResponseOfGlobalParameterDto> localVarResponse = UpdateParameterUsingPUTWithHttpInfo(parameterId, parameterDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update Parameter Updates the parameter matching the provided ID in the provided payload.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>ApiResponse of BaseResponseOfGlobalParameterDto</returns>
        public ApiResponse< BaseResponseOfGlobalParameterDto > UpdateParameterUsingPUTWithHttpInfo (string parameterId, GlobalParameterDto parameterDto)
        {
            // verify the required parameter 'parameterId' is set
            if (parameterId == null)
                throw new ApiException(400, "Missing required parameter 'parameterId' when calling ParameterManagementApi->UpdateParameterUsingPUT");
            // verify the required parameter 'parameterDto' is set
            if (parameterDto == null)
                throw new ApiException(400, "Missing required parameter 'parameterDto' when calling ParameterManagementApi->UpdateParameterUsingPUT");

            var localVarPath = "/api/v1/parameter/{parameterId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterId != null) localVarPathParams.Add("parameterId", Configuration.ApiClient.ParameterToString(parameterId)); // path parameter
            if (parameterDto != null && parameterDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(parameterDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = parameterDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateParameterUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfGlobalParameterDto)));
            
        }

        /// <summary>
        /// Update Parameter Updates the parameter matching the provided ID in the provided payload.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>Task of BaseResponseOfGlobalParameterDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfGlobalParameterDto> UpdateParameterUsingPUTAsync (string parameterId, GlobalParameterDto parameterDto)
        {
             ApiResponse<BaseResponseOfGlobalParameterDto> localVarResponse = await UpdateParameterUsingPUTAsyncWithHttpInfo(parameterId, parameterDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update Parameter Updates the parameter matching the provided ID in the provided payload.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="parameterId">The unique identifier of the parameter</param>
        /// <param name="parameterDto">The representation of the parameter to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfGlobalParameterDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfGlobalParameterDto>> UpdateParameterUsingPUTAsyncWithHttpInfo (string parameterId, GlobalParameterDto parameterDto)
        {
            // verify the required parameter 'parameterId' is set
            if (parameterId == null)
                throw new ApiException(400, "Missing required parameter 'parameterId' when calling ParameterManagementApi->UpdateParameterUsingPUT");
            // verify the required parameter 'parameterDto' is set
            if (parameterDto == null)
                throw new ApiException(400, "Missing required parameter 'parameterDto' when calling ParameterManagementApi->UpdateParameterUsingPUT");

            var localVarPath = "/api/v1/parameter/{parameterId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (parameterId != null) localVarPathParams.Add("parameterId", Configuration.ApiClient.ParameterToString(parameterId)); // path parameter
            if (parameterDto != null && parameterDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(parameterDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = parameterDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateParameterUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfGlobalParameterDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfGlobalParameterDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfGlobalParameterDto)));
            
        }

    }
}
