/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IPivotViewManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create a new pivot view
        /// </summary>
        /// <remarks>
        /// Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>BaseResponseOfPivotViewDto</returns>
        BaseResponseOfPivotViewDto CreatePivotViewUsingPOST (PivotViewDto pivotViewDto);

        /// <summary>
        /// Create a new pivot view
        /// </summary>
        /// <remarks>
        /// Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>ApiResponse of BaseResponseOfPivotViewDto</returns>
        ApiResponse<BaseResponseOfPivotViewDto> CreatePivotViewUsingPOSTWithHttpInfo (PivotViewDto pivotViewDto);
        /// <summary>
        /// Delete a single pivot view
        /// </summary>
        /// <remarks>
        /// Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeletePivotViewUsingDELETE (string pivotViewId);

        /// <summary>
        /// Delete a single pivot view
        /// </summary>
        /// <remarks>
        /// Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeletePivotViewUsingDELETEWithHttpInfo (string pivotViewId);
        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>BaseResponseOfTokenDto</returns>
        BaseResponseOfTokenDto DownloadPivotViewTokenUsingGET (string pivotViewId);

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of BaseResponseOfTokenDto</returns>
        ApiResponse<BaseResponseOfTokenDto> DownloadPivotViewTokenUsingGETWithHttpInfo (string pivotViewId);
        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>byte[]</returns>
        byte[] DownloadPivotViewUsingGET (string pivotViewId);

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of byte[]</returns>
        ApiResponse<byte[]> DownloadPivotViewUsingGETWithHttpInfo (string pivotViewId);
        /// <summary>
        /// Retrieve a single pivot view
        /// </summary>
        /// <remarks>
        /// Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>BaseResponseOfPivotViewDto</returns>
        BaseResponseOfPivotViewDto GetPivotViewUsingGET (string pivotViewId);

        /// <summary>
        /// Retrieve a single pivot view
        /// </summary>
        /// <remarks>
        /// Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of BaseResponseOfPivotViewDto</returns>
        ApiResponse<BaseResponseOfPivotViewDto> GetPivotViewUsingGETWithHttpInfo (string pivotViewId);
        /// <summary>
        /// Retrieve a list of pivot views
        /// </summary>
        /// <remarks>
        /// Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfPivotViewDto</returns>
        PagedResponseOfPivotViewDto ListPivotViewsUsingGET (string queryId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of pivot views
        /// </summary>
        /// <remarks>
        /// Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfPivotViewDto</returns>
        ApiResponse<PagedResponseOfPivotViewDto> ListPivotViewsUsingGETWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update a single pivot view
        /// </summary>
        /// <remarks>
        /// Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>BaseResponseOfPivotViewDto</returns>
        BaseResponseOfPivotViewDto UpdatePivotViewUsingPUT (string pivotViewId, PivotViewDto pivotViewDto);

        /// <summary>
        /// Update a single pivot view
        /// </summary>
        /// <remarks>
        /// Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>ApiResponse of BaseResponseOfPivotViewDto</returns>
        ApiResponse<BaseResponseOfPivotViewDto> UpdatePivotViewUsingPUTWithHttpInfo (string pivotViewId, PivotViewDto pivotViewDto);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create a new pivot view
        /// </summary>
        /// <remarks>
        /// Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>Task of BaseResponseOfPivotViewDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfPivotViewDto> CreatePivotViewUsingPOSTAsync (PivotViewDto pivotViewDto);

        /// <summary>
        /// Create a new pivot view
        /// </summary>
        /// <remarks>
        /// Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfPivotViewDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfPivotViewDto>> CreatePivotViewUsingPOSTAsyncWithHttpInfo (PivotViewDto pivotViewDto);
        /// <summary>
        /// Delete a single pivot view
        /// </summary>
        /// <remarks>
        /// Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeletePivotViewUsingDELETEAsync (string pivotViewId);

        /// <summary>
        /// Delete a single pivot view
        /// </summary>
        /// <remarks>
        /// Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeletePivotViewUsingDELETEAsyncWithHttpInfo (string pivotViewId);
        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of BaseResponseOfTokenDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTokenDto> DownloadPivotViewTokenUsingGETAsync (string pivotViewId);

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTokenDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTokenDto>> DownloadPivotViewTokenUsingGETAsyncWithHttpInfo (string pivotViewId);
        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of byte[]</returns>
        System.Threading.Tasks.Task<byte[]> DownloadPivotViewUsingGETAsync (string pivotViewId);

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020.
        /// </summary>
        /// <remarks>
        /// 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadPivotViewUsingGETAsyncWithHttpInfo (string pivotViewId);
        /// <summary>
        /// Retrieve a single pivot view
        /// </summary>
        /// <remarks>
        /// Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of BaseResponseOfPivotViewDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfPivotViewDto> GetPivotViewUsingGETAsync (string pivotViewId);

        /// <summary>
        /// Retrieve a single pivot view
        /// </summary>
        /// <remarks>
        /// Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (BaseResponseOfPivotViewDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfPivotViewDto>> GetPivotViewUsingGETAsyncWithHttpInfo (string pivotViewId);
        /// <summary>
        /// Retrieve a list of pivot views
        /// </summary>
        /// <remarks>
        /// Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfPivotViewDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfPivotViewDto> ListPivotViewsUsingGETAsync (string queryId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of pivot views
        /// </summary>
        /// <remarks>
        /// Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfPivotViewDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfPivotViewDto>> ListPivotViewsUsingGETAsyncWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update a single pivot view
        /// </summary>
        /// <remarks>
        /// Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>Task of BaseResponseOfPivotViewDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfPivotViewDto> UpdatePivotViewUsingPUTAsync (string pivotViewId, PivotViewDto pivotViewDto);

        /// <summary>
        /// Update a single pivot view
        /// </summary>
        /// <remarks>
        /// Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfPivotViewDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfPivotViewDto>> UpdatePivotViewUsingPUTAsyncWithHttpInfo (string pivotViewId, PivotViewDto pivotViewDto);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class PivotViewManagementApi : IPivotViewManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="PivotViewManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public PivotViewManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PivotViewManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public PivotViewManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create a new pivot view Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>BaseResponseOfPivotViewDto</returns>
        public BaseResponseOfPivotViewDto CreatePivotViewUsingPOST (PivotViewDto pivotViewDto)
        {
             ApiResponse<BaseResponseOfPivotViewDto> localVarResponse = CreatePivotViewUsingPOSTWithHttpInfo(pivotViewDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new pivot view Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>ApiResponse of BaseResponseOfPivotViewDto</returns>
        public ApiResponse< BaseResponseOfPivotViewDto > CreatePivotViewUsingPOSTWithHttpInfo (PivotViewDto pivotViewDto)
        {
            // verify the required parameter 'pivotViewDto' is set
            if (pivotViewDto == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewDto' when calling PivotViewManagementApi->CreatePivotViewUsingPOST");

            var localVarPath = "/api/v1/pivotview";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewDto != null && pivotViewDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(pivotViewDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = pivotViewDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreatePivotViewUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfPivotViewDto)));
            
        }

        /// <summary>
        /// Create a new pivot view Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>Task of BaseResponseOfPivotViewDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfPivotViewDto> CreatePivotViewUsingPOSTAsync (PivotViewDto pivotViewDto)
        {
             ApiResponse<BaseResponseOfPivotViewDto> localVarResponse = await CreatePivotViewUsingPOSTAsyncWithHttpInfo(pivotViewDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new pivot view Creates a view from the provided information. Currently, persists the provided &#x60;additionalMetadata&#x60; field, which can store an arbitrary JSON definition of a pivot table view. This pivot table must be associated with a query, and can optionally be associated with a query result. When a query is deleted, its associated views are also deleted.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewDto">The representation of the view to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfPivotViewDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfPivotViewDto>> CreatePivotViewUsingPOSTAsyncWithHttpInfo (PivotViewDto pivotViewDto)
        {
            // verify the required parameter 'pivotViewDto' is set
            if (pivotViewDto == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewDto' when calling PivotViewManagementApi->CreatePivotViewUsingPOST");

            var localVarPath = "/api/v1/pivotview";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewDto != null && pivotViewDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(pivotViewDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = pivotViewDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreatePivotViewUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfPivotViewDto)));
            
        }

        /// <summary>
        /// Delete a single pivot view Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeletePivotViewUsingDELETE (string pivotViewId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeletePivotViewUsingDELETEWithHttpInfo(pivotViewId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single pivot view Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeletePivotViewUsingDELETEWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->DeletePivotViewUsingDELETE");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeletePivotViewUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single pivot view Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeletePivotViewUsingDELETEAsync (string pivotViewId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeletePivotViewUsingDELETEAsyncWithHttpInfo(pivotViewId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single pivot view Deletes a view that matches the provided ID.  This is an administrative method and should be assumed a hard-delete, given no capability to restore a deleted view is available.  A no-op if no such view exists.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeletePivotViewUsingDELETEAsyncWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->DeletePivotViewUsingDELETE");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeletePivotViewUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>BaseResponseOfTokenDto</returns>
        public BaseResponseOfTokenDto DownloadPivotViewTokenUsingGET (string pivotViewId)
        {
             ApiResponse<BaseResponseOfTokenDto> localVarResponse = DownloadPivotViewTokenUsingGETWithHttpInfo(pivotViewId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of BaseResponseOfTokenDto</returns>
        public ApiResponse< BaseResponseOfTokenDto > DownloadPivotViewTokenUsingGETWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->DownloadPivotViewTokenUsingGET");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}/token";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadPivotViewTokenUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTokenDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTokenDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTokenDto)));
            
        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of BaseResponseOfTokenDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTokenDto> DownloadPivotViewTokenUsingGETAsync (string pivotViewId)
        {
             ApiResponse<BaseResponseOfTokenDto> localVarResponse = await DownloadPivotViewTokenUsingGETAsyncWithHttpInfo(pivotViewId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTokenDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTokenDto>> DownloadPivotViewTokenUsingGETAsyncWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->DownloadPivotViewTokenUsingGET");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}/token";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadPivotViewTokenUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTokenDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTokenDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTokenDto)));
            
        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>byte[]</returns>
        public byte[] DownloadPivotViewUsingGET (string pivotViewId)
        {
             ApiResponse<byte[]> localVarResponse = DownloadPivotViewUsingGETWithHttpInfo(pivotViewId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of byte[]</returns>
        public ApiResponse< byte[] > DownloadPivotViewUsingGETWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->DownloadPivotViewUsingGET");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}/download";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadPivotViewUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of byte[]</returns>
        public async System.Threading.Tasks.Task<byte[]> DownloadPivotViewUsingGETAsync (string pivotViewId)
        {
             ApiResponse<byte[]> localVarResponse = await DownloadPivotViewUsingGETAsyncWithHttpInfo(pivotViewId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// This endpoint is deprecated. It not longer functions as intended, as pivotingquery results is now handled by cross tab queries. This endpoint will be removedon September 1, 2020. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        public async System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadPivotViewUsingGETAsyncWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->DownloadPivotViewUsingGET");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}/download";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadPivotViewUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

        /// <summary>
        /// Retrieve a single pivot view Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>BaseResponseOfPivotViewDto</returns>
        public BaseResponseOfPivotViewDto GetPivotViewUsingGET (string pivotViewId)
        {
             ApiResponse<BaseResponseOfPivotViewDto> localVarResponse = GetPivotViewUsingGETWithHttpInfo(pivotViewId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single pivot view Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>ApiResponse of BaseResponseOfPivotViewDto</returns>
        public ApiResponse< BaseResponseOfPivotViewDto > GetPivotViewUsingGETWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->GetPivotViewUsingGET");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetPivotViewUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfPivotViewDto)));
            
        }

        /// <summary>
        /// Retrieve a single pivot view Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of BaseResponseOfPivotViewDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfPivotViewDto> GetPivotViewUsingGETAsync (string pivotViewId)
        {
             ApiResponse<BaseResponseOfPivotViewDto> localVarResponse = await GetPivotViewUsingGETAsyncWithHttpInfo(pivotViewId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single pivot view Returns a view with the provided ID, or a 404 if no view matches the ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <returns>Task of ApiResponse (BaseResponseOfPivotViewDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfPivotViewDto>> GetPivotViewUsingGETAsyncWithHttpInfo (string pivotViewId)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->GetPivotViewUsingGET");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetPivotViewUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfPivotViewDto)));
            
        }

        /// <summary>
        /// Retrieve a list of pivot views Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfPivotViewDto</returns>
        public PagedResponseOfPivotViewDto ListPivotViewsUsingGET (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfPivotViewDto> localVarResponse = ListPivotViewsUsingGETWithHttpInfo(queryId, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of pivot views Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfPivotViewDto</returns>
        public ApiResponse< PagedResponseOfPivotViewDto > ListPivotViewsUsingGETWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling PivotViewManagementApi->ListPivotViewsUsingGET");

            var localVarPath = "/api/v1/pivotview";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarQueryParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListPivotViewsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfPivotViewDto)));
            
        }

        /// <summary>
        /// Retrieve a list of pivot views Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfPivotViewDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfPivotViewDto> ListPivotViewsUsingGETAsync (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfPivotViewDto> localVarResponse = await ListPivotViewsUsingGETAsyncWithHttpInfo(queryId, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of pivot views Returns a paged list of views in the workspace of the request. If queryId is provided, the results are limited to only views associated with the query ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique query identifier to filter the views</param>
        /// <param name="limit">The number of views to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfPivotViewDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfPivotViewDto>> ListPivotViewsUsingGETAsyncWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling PivotViewManagementApi->ListPivotViewsUsingGET");

            var localVarPath = "/api/v1/pivotview";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarQueryParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListPivotViewsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfPivotViewDto)));
            
        }

        /// <summary>
        /// Update a single pivot view Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>BaseResponseOfPivotViewDto</returns>
        public BaseResponseOfPivotViewDto UpdatePivotViewUsingPUT (string pivotViewId, PivotViewDto pivotViewDto)
        {
             ApiResponse<BaseResponseOfPivotViewDto> localVarResponse = UpdatePivotViewUsingPUTWithHttpInfo(pivotViewId, pivotViewDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update a single pivot view Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>ApiResponse of BaseResponseOfPivotViewDto</returns>
        public ApiResponse< BaseResponseOfPivotViewDto > UpdatePivotViewUsingPUTWithHttpInfo (string pivotViewId, PivotViewDto pivotViewDto)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->UpdatePivotViewUsingPUT");
            // verify the required parameter 'pivotViewDto' is set
            if (pivotViewDto == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewDto' when calling PivotViewManagementApi->UpdatePivotViewUsingPUT");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter
            if (pivotViewDto != null && pivotViewDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(pivotViewDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = pivotViewDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdatePivotViewUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfPivotViewDto)));
            
        }

        /// <summary>
        /// Update a single pivot view Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>Task of BaseResponseOfPivotViewDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfPivotViewDto> UpdatePivotViewUsingPUTAsync (string pivotViewId, PivotViewDto pivotViewDto)
        {
             ApiResponse<BaseResponseOfPivotViewDto> localVarResponse = await UpdatePivotViewUsingPUTAsyncWithHttpInfo(pivotViewId, pivotViewDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update a single pivot view Updates the view that matches the provided ID with the details provided in the body. The associated query can&#39;t be updated, so providing the query ID has no effect.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="pivotViewId">The unique identifier of the pivot view</param>
        /// <param name="pivotViewDto">The representation of the pivot view to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfPivotViewDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfPivotViewDto>> UpdatePivotViewUsingPUTAsyncWithHttpInfo (string pivotViewId, PivotViewDto pivotViewDto)
        {
            // verify the required parameter 'pivotViewId' is set
            if (pivotViewId == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewId' when calling PivotViewManagementApi->UpdatePivotViewUsingPUT");
            // verify the required parameter 'pivotViewDto' is set
            if (pivotViewDto == null)
                throw new ApiException(400, "Missing required parameter 'pivotViewDto' when calling PivotViewManagementApi->UpdatePivotViewUsingPUT");

            var localVarPath = "/api/v1/pivotview/{pivotViewId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (pivotViewId != null) localVarPathParams.Add("pivotViewId", Configuration.ApiClient.ParameterToString(pivotViewId)); // path parameter
            if (pivotViewDto != null && pivotViewDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(pivotViewDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = pivotViewDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdatePivotViewUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfPivotViewDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfPivotViewDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfPivotViewDto)));
            
        }

    }
}
