/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IQueryManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Cancel a running query
        /// </summary>
        /// <remarks>
        /// Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>BaseResponseOfQueryResultDto</returns>
        BaseResponseOfQueryResultDto CancelQueryUsingDELETE (string queryResultId);

        /// <summary>
        /// Cancel a running query
        /// </summary>
        /// <remarks>
        /// Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>ApiResponse of BaseResponseOfQueryResultDto</returns>
        ApiResponse<BaseResponseOfQueryResultDto> CancelQueryUsingDELETEWithHttpInfo (string queryResultId);
        /// <summary>
        /// Create a new query
        /// </summary>
        /// <remarks>
        /// Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        BaseResponseOfQueryDto CreateQueryUsingPOST (QueryDto queryDto);

        /// <summary>
        /// Create a new query
        /// </summary>
        /// <remarks>
        /// Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        ApiResponse<BaseResponseOfQueryDto> CreateQueryUsingPOSTWithHttpInfo (QueryDto queryDto);
        /// <summary>
        /// Delete a single query
        /// </summary>
        /// <remarks>
        /// Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteQueryUsingDELETE (string queryId);

        /// <summary>
        /// Delete a single query
        /// </summary>
        /// <remarks>
        /// Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteQueryUsingDELETEWithHttpInfo (string queryId);
        /// <summary>
        /// Download a query result
        /// </summary>
        /// <remarks>
        /// Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>byte[]</returns>
        byte[] DownloadQueryResultUsingGET (string queryResultId);

        /// <summary>
        /// Download a query result
        /// </summary>
        /// <remarks>
        /// Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>ApiResponse of byte[]</returns>
        ApiResponse<byte[]> DownloadQueryResultUsingGETWithHttpInfo (string queryResultId);
        /// <summary>
        /// Export query result to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring ExportQueryResultToSpreadsheetsUsingPOST (string queryResultId, ExportQueryResultDto dto);

        /// <summary>
        /// Export query result to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> ExportQueryResultToSpreadsheetsUsingPOSTWithHttpInfo (string queryResultId, ExportQueryResultDto dto);
        /// <summary>
        /// Retrieve dependencies
        /// </summary>
        /// <remarks>
        /// Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfTableDto</returns>
        PagedResponseOfTableDto GetDependenciesUsingGET (string queryId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve dependencies
        /// </summary>
        /// <remarks>
        /// Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTableDto</returns>
        ApiResponse<PagedResponseOfTableDto> GetDependenciesUsingGETWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve query column data
        /// </summary>
        /// <remarks>
        /// Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>BaseResponseOfQueryColumnDataDto</returns>
        BaseResponseOfQueryColumnDataDto GetQueryColumnDataUsingPOST (QueryTextDto queryTextDto);

        /// <summary>
        /// Retrieve query column data
        /// </summary>
        /// <remarks>
        /// Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>ApiResponse of BaseResponseOfQueryColumnDataDto</returns>
        ApiResponse<BaseResponseOfQueryColumnDataDto> GetQueryColumnDataUsingPOSTWithHttpInfo (QueryTextDto queryTextDto);
        /// <summary>
        /// Retrieve a single query result
        /// </summary>
        /// <remarks>
        /// Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>BaseResponseOfQueryResultDto</returns>
        BaseResponseOfQueryResultDto GetQueryResultUsingGET (string queryResultId);

        /// <summary>
        /// Retrieve a single query result
        /// </summary>
        /// <remarks>
        /// Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>ApiResponse of BaseResponseOfQueryResultDto</returns>
        ApiResponse<BaseResponseOfQueryResultDto> GetQueryResultUsingGETWithHttpInfo (string queryResultId);
        /// <summary>
        /// Retrieve a single query
        /// </summary>
        /// <remarks>
        /// Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        BaseResponseOfQueryDto GetQueryUsingGET (string queryId);

        /// <summary>
        /// Retrieve a single query
        /// </summary>
        /// <remarks>
        /// Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        ApiResponse<BaseResponseOfQueryDto> GetQueryUsingGETWithHttpInfo (string queryId);
        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfTableDto</returns>
        PagedResponseOfTableDto GetTablesDependentOnQueryUsingGET (string queryId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTableDto</returns>
        ApiResponse<PagedResponseOfTableDto> GetTablesDependentOnQueryUsingGETWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Parses the query to determine if it is valid
        /// </summary>
        /// <remarks>
        /// Returns the provided QueryDto
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        BaseResponseOfQueryDto IsQueryValidUsingPOST (QueryDto queryDto);

        /// <summary>
        /// Parses the query to determine if it is valid
        /// </summary>
        /// <remarks>
        /// Returns the provided QueryDto
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        ApiResponse<BaseResponseOfQueryDto> IsQueryValidUsingPOSTWithHttpInfo (QueryDto queryDto);
        /// <summary>
        /// Retrieve list of queries
        /// </summary>
        /// <remarks>
        /// Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>PagedResponseOfQueryDto</returns>
        PagedResponseOfQueryDto ListQueriesUsingGET (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null);

        /// <summary>
        /// Retrieve list of queries
        /// </summary>
        /// <remarks>
        /// Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfQueryDto</returns>
        ApiResponse<PagedResponseOfQueryDto> ListQueriesUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null);
        /// <summary>
        /// Retrieve a list of query results
        /// </summary>
        /// <remarks>
        /// Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>PagedResponseOfQueryResultDto</returns>
        PagedResponseOfQueryResultDto ListQueryResultsUsingGET (string queryId = null, string cursor = null, int? limit = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of query results
        /// </summary>
        /// <remarks>
        /// Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>ApiResponse of PagedResponseOfQueryResultDto</returns>
        ApiResponse<PagedResponseOfQueryResultDto> ListQueryResultsUsingGETWithHttpInfo (string queryId = null, string cursor = null, int? limit = null, long? offset = null);
        /// <summary>
        /// Preview a query
        /// </summary>
        /// <remarks>
        /// Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        BaseResponseOfQueryDto PreviewQueryUsingPOST (string tableId, int? limit = null, string fileName = null);

        /// <summary>
        /// Preview a query
        /// </summary>
        /// <remarks>
        /// Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        ApiResponse<BaseResponseOfQueryDto> PreviewQueryUsingPOSTWithHttpInfo (string tableId, int? limit = null, string fileName = null);
        /// <summary>
        /// Execute a query
        /// </summary>
        /// <remarks>
        /// Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>BaseResponseOfQueryResultDto</returns>
        BaseResponseOfQueryResultDto RunQueryUsingPOST (QueryResultDto queryResultDto);

        /// <summary>
        /// Execute a query
        /// </summary>
        /// <remarks>
        /// Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>ApiResponse of BaseResponseOfQueryResultDto</returns>
        ApiResponse<BaseResponseOfQueryResultDto> RunQueryUsingPOSTWithHttpInfo (QueryResultDto queryResultDto);
        /// <summary>
        /// Update a single query
        /// </summary>
        /// <remarks>
        /// Updates the query that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        BaseResponseOfQueryDto UpdateQueryUsingPUT (string queryId, QueryDto queryDto);

        /// <summary>
        /// Update a single query
        /// </summary>
        /// <remarks>
        /// Updates the query that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        ApiResponse<BaseResponseOfQueryDto> UpdateQueryUsingPUTWithHttpInfo (string queryId, QueryDto queryDto);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Cancel a running query
        /// </summary>
        /// <remarks>
        /// Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of BaseResponseOfQueryResultDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryResultDto> CancelQueryUsingDELETEAsync (string queryResultId);

        /// <summary>
        /// Cancel a running query
        /// </summary>
        /// <remarks>
        /// Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryResultDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryResultDto>> CancelQueryUsingDELETEAsyncWithHttpInfo (string queryResultId);
        /// <summary>
        /// Create a new query
        /// </summary>
        /// <remarks>
        /// Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryDto> CreateQueryUsingPOSTAsync (QueryDto queryDto);

        /// <summary>
        /// Create a new query
        /// </summary>
        /// <remarks>
        /// Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> CreateQueryUsingPOSTAsyncWithHttpInfo (QueryDto queryDto);
        /// <summary>
        /// Delete a single query
        /// </summary>
        /// <remarks>
        /// Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteQueryUsingDELETEAsync (string queryId);

        /// <summary>
        /// Delete a single query
        /// </summary>
        /// <remarks>
        /// Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteQueryUsingDELETEAsyncWithHttpInfo (string queryId);
        /// <summary>
        /// Download a query result
        /// </summary>
        /// <remarks>
        /// Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of byte[]</returns>
        System.Threading.Tasks.Task<byte[]> DownloadQueryResultUsingGETAsync (string queryResultId);

        /// <summary>
        /// Download a query result
        /// </summary>
        /// <remarks>
        /// Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadQueryResultUsingGETAsyncWithHttpInfo (string queryResultId);
        /// <summary>
        /// Export query result to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> ExportQueryResultToSpreadsheetsUsingPOSTAsync (string queryResultId, ExportQueryResultDto dto);

        /// <summary>
        /// Export query result to spreadsheets
        /// </summary>
        /// <remarks>
        /// Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ExportQueryResultToSpreadsheetsUsingPOSTAsyncWithHttpInfo (string queryResultId, ExportQueryResultDto dto);
        /// <summary>
        /// Retrieve dependencies
        /// </summary>
        /// <remarks>
        /// Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTableDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfTableDto> GetDependenciesUsingGETAsync (string queryId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve dependencies
        /// </summary>
        /// <remarks>
        /// Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTableDto>> GetDependenciesUsingGETAsyncWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve query column data
        /// </summary>
        /// <remarks>
        /// Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>Task of BaseResponseOfQueryColumnDataDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryColumnDataDto> GetQueryColumnDataUsingPOSTAsync (QueryTextDto queryTextDto);

        /// <summary>
        /// Retrieve query column data
        /// </summary>
        /// <remarks>
        /// Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryColumnDataDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryColumnDataDto>> GetQueryColumnDataUsingPOSTAsyncWithHttpInfo (QueryTextDto queryTextDto);
        /// <summary>
        /// Retrieve a single query result
        /// </summary>
        /// <remarks>
        /// Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of BaseResponseOfQueryResultDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryResultDto> GetQueryResultUsingGETAsync (string queryResultId);

        /// <summary>
        /// Retrieve a single query result
        /// </summary>
        /// <remarks>
        /// Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryResultDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryResultDto>> GetQueryResultUsingGETAsyncWithHttpInfo (string queryResultId);
        /// <summary>
        /// Retrieve a single query
        /// </summary>
        /// <remarks>
        /// Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryDto> GetQueryUsingGETAsync (string queryId);

        /// <summary>
        /// Retrieve a single query
        /// </summary>
        /// <remarks>
        /// Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> GetQueryUsingGETAsyncWithHttpInfo (string queryId);
        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTableDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfTableDto> GetTablesDependentOnQueryUsingGETAsync (string queryId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTableDto>> GetTablesDependentOnQueryUsingGETAsyncWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Parses the query to determine if it is valid
        /// </summary>
        /// <remarks>
        /// Returns the provided QueryDto
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryDto> IsQueryValidUsingPOSTAsync (QueryDto queryDto);

        /// <summary>
        /// Parses the query to determine if it is valid
        /// </summary>
        /// <remarks>
        /// Returns the provided QueryDto
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> IsQueryValidUsingPOSTAsyncWithHttpInfo (QueryDto queryDto);
        /// <summary>
        /// Retrieve list of queries
        /// </summary>
        /// <remarks>
        /// Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>Task of PagedResponseOfQueryDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfQueryDto> ListQueriesUsingGETAsync (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null);

        /// <summary>
        /// Retrieve list of queries
        /// </summary>
        /// <remarks>
        /// Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfQueryDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfQueryDto>> ListQueriesUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null);
        /// <summary>
        /// Retrieve a list of query results
        /// </summary>
        /// <remarks>
        /// Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>Task of PagedResponseOfQueryResultDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfQueryResultDto> ListQueryResultsUsingGETAsync (string queryId = null, string cursor = null, int? limit = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of query results
        /// </summary>
        /// <remarks>
        /// Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfQueryResultDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfQueryResultDto>> ListQueryResultsUsingGETAsyncWithHttpInfo (string queryId = null, string cursor = null, int? limit = null, long? offset = null);
        /// <summary>
        /// Preview a query
        /// </summary>
        /// <remarks>
        /// Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryDto> PreviewQueryUsingPOSTAsync (string tableId, int? limit = null, string fileName = null);

        /// <summary>
        /// Preview a query
        /// </summary>
        /// <remarks>
        /// Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> PreviewQueryUsingPOSTAsyncWithHttpInfo (string tableId, int? limit = null, string fileName = null);
        /// <summary>
        /// Execute a query
        /// </summary>
        /// <remarks>
        /// Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>Task of BaseResponseOfQueryResultDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryResultDto> RunQueryUsingPOSTAsync (QueryResultDto queryResultDto);

        /// <summary>
        /// Execute a query
        /// </summary>
        /// <remarks>
        /// Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryResultDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryResultDto>> RunQueryUsingPOSTAsyncWithHttpInfo (QueryResultDto queryResultDto);
        /// <summary>
        /// Update a single query
        /// </summary>
        /// <remarks>
        /// Updates the query that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfQueryDto> UpdateQueryUsingPUTAsync (string queryId, QueryDto queryDto);

        /// <summary>
        /// Update a single query
        /// </summary>
        /// <remarks>
        /// Updates the query that matches the provided ID with the details provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> UpdateQueryUsingPUTAsyncWithHttpInfo (string queryId, QueryDto queryDto);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class QueryManagementApi : IQueryManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="QueryManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public QueryManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="QueryManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public QueryManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Cancel a running query Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>BaseResponseOfQueryResultDto</returns>
        public BaseResponseOfQueryResultDto CancelQueryUsingDELETE (string queryResultId)
        {
             ApiResponse<BaseResponseOfQueryResultDto> localVarResponse = CancelQueryUsingDELETEWithHttpInfo(queryResultId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Cancel a running query Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>ApiResponse of BaseResponseOfQueryResultDto</returns>
        public ApiResponse< BaseResponseOfQueryResultDto > CancelQueryUsingDELETEWithHttpInfo (string queryResultId)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->CancelQueryUsingDELETE");

            var localVarPath = "/api/v1/queryresult/{queryResultId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CancelQueryUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Cancel a running query Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of BaseResponseOfQueryResultDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryResultDto> CancelQueryUsingDELETEAsync (string queryResultId)
        {
             ApiResponse<BaseResponseOfQueryResultDto> localVarResponse = await CancelQueryUsingDELETEAsyncWithHttpInfo(queryResultId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Cancel a running query Cancels a running query based on the provided result ID, and returns a cancelled result unless the query&#39;s already in a COMPLETED state.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryResultDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryResultDto>> CancelQueryUsingDELETEAsyncWithHttpInfo (string queryResultId)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->CancelQueryUsingDELETE");

            var localVarPath = "/api/v1/queryresult/{queryResultId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CancelQueryUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Create a new query Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        public BaseResponseOfQueryDto CreateQueryUsingPOST (QueryDto queryDto)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = CreateQueryUsingPOSTWithHttpInfo(queryDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new query Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        public ApiResponse< BaseResponseOfQueryDto > CreateQueryUsingPOSTWithHttpInfo (QueryDto queryDto)
        {
            // verify the required parameter 'queryDto' is set
            if (queryDto == null)
                throw new ApiException(400, "Missing required parameter 'queryDto' when calling QueryManagementApi->CreateQueryUsingPOST");

            var localVarPath = "/api/v1/query";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryDto != null && queryDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateQueryUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Create a new query Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryDto> CreateQueryUsingPOSTAsync (QueryDto queryDto)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = await CreateQueryUsingPOSTAsyncWithHttpInfo(queryDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new query Creates a query object and validates full permissions to ensure the requestor has access to all data sources being queried. This endpoint _doesn&#39;t_ execute the query; to execute, call the POST /queryresult method.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the query to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> CreateQueryUsingPOSTAsyncWithHttpInfo (QueryDto queryDto)
        {
            // verify the required parameter 'queryDto' is set
            if (queryDto == null)
                throw new ApiException(400, "Missing required parameter 'queryDto' when calling QueryManagementApi->CreateQueryUsingPOST");

            var localVarPath = "/api/v1/query";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryDto != null && queryDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateQueryUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Delete a single query Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteQueryUsingDELETE (string queryId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteQueryUsingDELETEWithHttpInfo(queryId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single query Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteQueryUsingDELETEWithHttpInfo (string queryId)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->DeleteQueryUsingDELETE");

            var localVarPath = "/api/v1/query/{queryId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteQueryUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single query Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteQueryUsingDELETEAsync (string queryId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteQueryUsingDELETEAsyncWithHttpInfo(queryId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single query Deletes the query that matches the provided ID. If no such query is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteQueryUsingDELETEAsyncWithHttpInfo (string queryId)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->DeleteQueryUsingDELETE");

            var localVarPath = "/api/v1/query/{queryId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteQueryUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Download a query result Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>byte[]</returns>
        public byte[] DownloadQueryResultUsingGET (string queryResultId)
        {
             ApiResponse<byte[]> localVarResponse = DownloadQueryResultUsingGETWithHttpInfo(queryResultId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Download a query result Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>ApiResponse of byte[]</returns>
        public ApiResponse< byte[] > DownloadQueryResultUsingGETWithHttpInfo (string queryResultId)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->DownloadQueryResultUsingGET");

            var localVarPath = "/api/v1/queryresult/{queryResultId}/download";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadQueryResultUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

        /// <summary>
        /// Download a query result Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of byte[]</returns>
        public async System.Threading.Tasks.Task<byte[]> DownloadQueryResultUsingGETAsync (string queryResultId)
        {
             ApiResponse<byte[]> localVarResponse = await DownloadQueryResultUsingGETAsyncWithHttpInfo(queryResultId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Download a query result Uses the Token Management API to create a token with the query result ID, which it then uses to download a CSV file of the query results.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        public async System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadQueryResultUsingGETAsyncWithHttpInfo (string queryResultId)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->DownloadQueryResultUsingGET");

            var localVarPath = "/api/v1/queryresult/{queryResultId}/download";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadQueryResultUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

        /// <summary>
        /// Export query result to spreadsheets Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring ExportQueryResultToSpreadsheetsUsingPOST (string queryResultId, ExportQueryResultDto dto)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = ExportQueryResultToSpreadsheetsUsingPOSTWithHttpInfo(queryResultId, dto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Export query result to spreadsheets Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > ExportQueryResultToSpreadsheetsUsingPOSTWithHttpInfo (string queryResultId, ExportQueryResultDto dto)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->ExportQueryResultToSpreadsheetsUsingPOST");
            // verify the required parameter 'dto' is set
            if (dto == null)
                throw new ApiException(400, "Missing required parameter 'dto' when calling QueryManagementApi->ExportQueryResultToSpreadsheetsUsingPOST");

            var localVarPath = "/api/v1/queryresult/{queryResultId}/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter
            if (dto != null && dto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(dto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = dto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ExportQueryResultToSpreadsheetsUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Export query result to spreadsheets Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> ExportQueryResultToSpreadsheetsUsingPOSTAsync (string queryResultId, ExportQueryResultDto dto)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await ExportQueryResultToSpreadsheetsUsingPOSTAsyncWithHttpInfo(queryResultId, dto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Export query result to spreadsheets Exports a query result with the provided ID to Spreadsheets. To determine where to export the results, the request body should include a URL copied and pasted from the Spreadsheets UI. Returns a 404 if no matching query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <param name="dto">The representation of the export query result</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ExportQueryResultToSpreadsheetsUsingPOSTAsyncWithHttpInfo (string queryResultId, ExportQueryResultDto dto)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->ExportQueryResultToSpreadsheetsUsingPOST");
            // verify the required parameter 'dto' is set
            if (dto == null)
                throw new ApiException(400, "Missing required parameter 'dto' when calling QueryManagementApi->ExportQueryResultToSpreadsheetsUsingPOST");

            var localVarPath = "/api/v1/queryresult/{queryResultId}/export";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter
            if (dto != null && dto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(dto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = dto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ExportQueryResultToSpreadsheetsUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Retrieve dependencies Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfTableDto</returns>
        public PagedResponseOfTableDto GetDependenciesUsingGET (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTableDto> localVarResponse = GetDependenciesUsingGETWithHttpInfo(queryId, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve dependencies Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTableDto</returns>
        public ApiResponse< PagedResponseOfTableDto > GetDependenciesUsingGETWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->GetDependenciesUsingGET");

            var localVarPath = "/api/v1/query/{queryId}/dependencies";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetDependenciesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTableDto)));
            
        }

        /// <summary>
        /// Retrieve dependencies Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTableDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfTableDto> GetDependenciesUsingGETAsync (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTableDto> localVarResponse = await GetDependenciesUsingGETAsyncWithHttpInfo(queryId, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve dependencies Returns an unordered collection of all tables the matching query uses as datasources, including any shared tables outside of this OAuth token&#39;s workspace. The endpoint verifies the user has read permissions on the query, but _not_ on the tables returned.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of dependencies to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTableDto>> GetDependenciesUsingGETAsyncWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->GetDependenciesUsingGET");

            var localVarPath = "/api/v1/query/{queryId}/dependencies";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetDependenciesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTableDto)));
            
        }

        /// <summary>
        /// Retrieve query column data Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>BaseResponseOfQueryColumnDataDto</returns>
        public BaseResponseOfQueryColumnDataDto GetQueryColumnDataUsingPOST (QueryTextDto queryTextDto)
        {
             ApiResponse<BaseResponseOfQueryColumnDataDto> localVarResponse = GetQueryColumnDataUsingPOSTWithHttpInfo(queryTextDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve query column data Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>ApiResponse of BaseResponseOfQueryColumnDataDto</returns>
        public ApiResponse< BaseResponseOfQueryColumnDataDto > GetQueryColumnDataUsingPOSTWithHttpInfo (QueryTextDto queryTextDto)
        {
            // verify the required parameter 'queryTextDto' is set
            if (queryTextDto == null)
                throw new ApiException(400, "Missing required parameter 'queryTextDto' when calling QueryManagementApi->GetQueryColumnDataUsingPOST");

            var localVarPath = "/api/v1/query/data";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryTextDto != null && queryTextDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryTextDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryTextDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetQueryColumnDataUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryColumnDataDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryColumnDataDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryColumnDataDto)));
            
        }

        /// <summary>
        /// Retrieve query column data Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>Task of BaseResponseOfQueryColumnDataDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryColumnDataDto> GetQueryColumnDataUsingPOSTAsync (QueryTextDto queryTextDto)
        {
             ApiResponse<BaseResponseOfQueryColumnDataDto> localVarResponse = await GetQueryColumnDataUsingPOSTAsyncWithHttpInfo(queryTextDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve query column data Returns a QueryColumnDataDto representing the column data for the given query text. If the query isn&#39;t valid, returns a 400.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryTextDto">The query text to parse, up to 30000 characters; must not be null or empty</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryColumnDataDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryColumnDataDto>> GetQueryColumnDataUsingPOSTAsyncWithHttpInfo (QueryTextDto queryTextDto)
        {
            // verify the required parameter 'queryTextDto' is set
            if (queryTextDto == null)
                throw new ApiException(400, "Missing required parameter 'queryTextDto' when calling QueryManagementApi->GetQueryColumnDataUsingPOST");

            var localVarPath = "/api/v1/query/data";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryTextDto != null && queryTextDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryTextDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryTextDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetQueryColumnDataUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryColumnDataDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryColumnDataDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryColumnDataDto)));
            
        }

        /// <summary>
        /// Retrieve a single query result Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>BaseResponseOfQueryResultDto</returns>
        public BaseResponseOfQueryResultDto GetQueryResultUsingGET (string queryResultId)
        {
             ApiResponse<BaseResponseOfQueryResultDto> localVarResponse = GetQueryResultUsingGETWithHttpInfo(queryResultId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single query result Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>ApiResponse of BaseResponseOfQueryResultDto</returns>
        public ApiResponse< BaseResponseOfQueryResultDto > GetQueryResultUsingGETWithHttpInfo (string queryResultId)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->GetQueryResultUsingGET");

            var localVarPath = "/api/v1/queryresult/{queryResultId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetQueryResultUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Retrieve a single query result Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of BaseResponseOfQueryResultDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryResultDto> GetQueryResultUsingGETAsync (string queryResultId)
        {
             ApiResponse<BaseResponseOfQueryResultDto> localVarResponse = await GetQueryResultUsingGETAsyncWithHttpInfo(queryResultId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single query result Returns a single query result that matches the provided ID, or a 404 if no such query result is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultId">The unique identifier of the query result</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryResultDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryResultDto>> GetQueryResultUsingGETAsyncWithHttpInfo (string queryResultId)
        {
            // verify the required parameter 'queryResultId' is set
            if (queryResultId == null)
                throw new ApiException(400, "Missing required parameter 'queryResultId' when calling QueryManagementApi->GetQueryResultUsingGET");

            var localVarPath = "/api/v1/queryresult/{queryResultId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultId != null) localVarPathParams.Add("queryResultId", Configuration.ApiClient.ParameterToString(queryResultId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetQueryResultUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Retrieve a single query Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        public BaseResponseOfQueryDto GetQueryUsingGET (string queryId)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = GetQueryUsingGETWithHttpInfo(queryId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single query Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        public ApiResponse< BaseResponseOfQueryDto > GetQueryUsingGETWithHttpInfo (string queryId)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->GetQueryUsingGET");

            var localVarPath = "/api/v1/query/{queryId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetQueryUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Retrieve a single query Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryDto> GetQueryUsingGETAsync (string queryId)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = await GetQueryUsingGETAsyncWithHttpInfo(queryId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single query Returns a query that matches the provided ID, or a 404 if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> GetQueryUsingGETAsyncWithHttpInfo (string queryId)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->GetQueryUsingGET");

            var localVarPath = "/api/v1/query/{queryId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetQueryUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfTableDto</returns>
        public PagedResponseOfTableDto GetTablesDependentOnQueryUsingGET (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTableDto> localVarResponse = GetTablesDependentOnQueryUsingGETWithHttpInfo(queryId, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTableDto</returns>
        public ApiResponse< PagedResponseOfTableDto > GetTablesDependentOnQueryUsingGETWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->GetTablesDependentOnQueryUsingGET");

            var localVarPath = "/api/v1/query/{queryId}/dependents";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetTablesDependentOnQueryUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTableDto)));
            
        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTableDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfTableDto> GetTablesDependentOnQueryUsingGETAsync (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTableDto> localVarResponse = await GetTablesDependentOnQueryUsingGETAsyncWithHttpInfo(queryId, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all tables that use the query with provided ID as a datasource. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTableDto>> GetTablesDependentOnQueryUsingGETAsyncWithHttpInfo (string queryId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->GetTablesDependentOnQueryUsingGET");

            var localVarPath = "/api/v1/query/{queryId}/dependents";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetTablesDependentOnQueryUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTableDto)));
            
        }

        /// <summary>
        /// Parses the query to determine if it is valid Returns the provided QueryDto
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        public BaseResponseOfQueryDto IsQueryValidUsingPOST (QueryDto queryDto)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = IsQueryValidUsingPOSTWithHttpInfo(queryDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Parses the query to determine if it is valid Returns the provided QueryDto
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        public ApiResponse< BaseResponseOfQueryDto > IsQueryValidUsingPOSTWithHttpInfo (QueryDto queryDto)
        {
            // verify the required parameter 'queryDto' is set
            if (queryDto == null)
                throw new ApiException(400, "Missing required parameter 'queryDto' when calling QueryManagementApi->IsQueryValidUsingPOST");

            var localVarPath = "/api/v1/query/validation";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryDto != null && queryDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("IsQueryValidUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Parses the query to determine if it is valid Returns the provided QueryDto
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryDto> IsQueryValidUsingPOSTAsync (QueryDto queryDto)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = await IsQueryValidUsingPOSTAsyncWithHttpInfo(queryDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Parses the query to determine if it is valid Returns the provided QueryDto
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryDto">The representation of the created query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> IsQueryValidUsingPOSTAsyncWithHttpInfo (QueryDto queryDto)
        {
            // verify the required parameter 'queryDto' is set
            if (queryDto == null)
                throw new ApiException(400, "Missing required parameter 'queryDto' when calling QueryManagementApi->IsQueryValidUsingPOST");

            var localVarPath = "/api/v1/query/validation";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryDto != null && queryDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("IsQueryValidUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Retrieve list of queries Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>PagedResponseOfQueryDto</returns>
        public PagedResponseOfQueryDto ListQueriesUsingGET (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null)
        {
             ApiResponse<PagedResponseOfQueryDto> localVarResponse = ListQueriesUsingGETWithHttpInfo(limit, cursor, offset, ids);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve list of queries Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfQueryDto</returns>
        public ApiResponse< PagedResponseOfQueryDto > ListQueriesUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null)
        {

            var localVarPath = "/api/v1/query";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter
            if (ids != null) localVarQueryParams.Add("ids", Configuration.ApiClient.ParameterToString(ids)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListQueriesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Retrieve list of queries Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>Task of PagedResponseOfQueryDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfQueryDto> ListQueriesUsingGETAsync (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null)
        {
             ApiResponse<PagedResponseOfQueryDto> localVarResponse = await ListQueriesUsingGETAsyncWithHttpInfo(limit, cursor, offset, ids);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve list of queries Returns a list of all non-temporary queries associated with the workspace. By default, these queries are ordered by their names, in ascending order.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of queries to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <param name="ids">A list of ids to filter the returned list by (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfQueryDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfQueryDto>> ListQueriesUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null, List<string> ids = null)
        {

            var localVarPath = "/api/v1/query";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter
            if (ids != null) localVarQueryParams.Add("ids", Configuration.ApiClient.ParameterToString(ids)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListQueriesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Retrieve a list of query results Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>PagedResponseOfQueryResultDto</returns>
        public PagedResponseOfQueryResultDto ListQueryResultsUsingGET (string queryId = null, string cursor = null, int? limit = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfQueryResultDto> localVarResponse = ListQueryResultsUsingGETWithHttpInfo(queryId, cursor, limit, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of query results Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>ApiResponse of PagedResponseOfQueryResultDto</returns>
        public ApiResponse< PagedResponseOfQueryResultDto > ListQueryResultsUsingGETWithHttpInfo (string queryId = null, string cursor = null, int? limit = null, long? offset = null)
        {

            var localVarPath = "/api/v1/queryresult";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarQueryParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListQueryResultsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Retrieve a list of query results Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>Task of PagedResponseOfQueryResultDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfQueryResultDto> ListQueryResultsUsingGETAsync (string queryId = null, string cursor = null, int? limit = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfQueryResultDto> localVarResponse = await ListQueryResultsUsingGETAsyncWithHttpInfo(queryId, cursor, limit, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of query results Returns a paged list of query results that match the provided query ID, or an empty list if no matching query is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="limit">The number of query results to return, from 1 to 1000; by default, 1000 (optional, default to 1000)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional, default to 0)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfQueryResultDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfQueryResultDto>> ListQueryResultsUsingGETAsyncWithHttpInfo (string queryId = null, string cursor = null, int? limit = null, long? offset = null)
        {

            var localVarPath = "/api/v1/queryresult";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarQueryParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListQueryResultsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Preview a query Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        public BaseResponseOfQueryDto PreviewQueryUsingPOST (string tableId, int? limit = null, string fileName = null)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = PreviewQueryUsingPOSTWithHttpInfo(tableId, limit, fileName);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Preview a query Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        public ApiResponse< BaseResponseOfQueryDto > PreviewQueryUsingPOSTWithHttpInfo (string tableId, int? limit = null, string fileName = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling QueryManagementApi->PreviewQueryUsingPOST");

            var localVarPath = "/api/v1/query/preview/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (fileName != null) localVarQueryParams.Add("fileName", Configuration.ApiClient.ParameterToString(fileName)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PreviewQueryUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Preview a query Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryDto> PreviewQueryUsingPOSTAsync (string tableId, int? limit = null, string fileName = null)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = await PreviewQueryUsingPOSTAsyncWithHttpInfo(tableId, limit, fileName);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Preview a query Creates a limited scope query object, but does _not_ execute it. The query selects all values against the provided table, up to 10 rows. This endpoint may allow unpermissioned users to preview table data; full permissions to datasources are _not_ validated.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The identifier of the table to query</param>
        /// <param name="limit">The number of rows to return (optional)</param>
        /// <param name="fileName">The name of the file to create (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> PreviewQueryUsingPOSTAsyncWithHttpInfo (string tableId, int? limit = null, string fileName = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling QueryManagementApi->PreviewQueryUsingPOST");

            var localVarPath = "/api/v1/query/preview/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (fileName != null) localVarQueryParams.Add("fileName", Configuration.ApiClient.ParameterToString(fileName)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PreviewQueryUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Execute a query Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>BaseResponseOfQueryResultDto</returns>
        public BaseResponseOfQueryResultDto RunQueryUsingPOST (QueryResultDto queryResultDto)
        {
             ApiResponse<BaseResponseOfQueryResultDto> localVarResponse = RunQueryUsingPOSTWithHttpInfo(queryResultDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Execute a query Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>ApiResponse of BaseResponseOfQueryResultDto</returns>
        public ApiResponse< BaseResponseOfQueryResultDto > RunQueryUsingPOSTWithHttpInfo (QueryResultDto queryResultDto)
        {
            // verify the required parameter 'queryResultDto' is set
            if (queryResultDto == null)
                throw new ApiException(400, "Missing required parameter 'queryResultDto' when calling QueryManagementApi->RunQueryUsingPOST");

            var localVarPath = "/api/v1/queryresult";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultDto != null && queryResultDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryResultDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryResultDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("RunQueryUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Execute a query Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>Task of BaseResponseOfQueryResultDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryResultDto> RunQueryUsingPOSTAsync (QueryResultDto queryResultDto)
        {
             ApiResponse<BaseResponseOfQueryResultDto> localVarResponse = await RunQueryUsingPOSTAsyncWithHttpInfo(queryResultDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Execute a query Runs a query and immediately returns a query result entity, which has an ID that can be used to poll the status from the GET /queryresult method. A status of COMPLETED or ERROR indicates the query has completed.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryResultDto">The representation of the created query</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryResultDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryResultDto>> RunQueryUsingPOSTAsyncWithHttpInfo (QueryResultDto queryResultDto)
        {
            // verify the required parameter 'queryResultDto' is set
            if (queryResultDto == null)
                throw new ApiException(400, "Missing required parameter 'queryResultDto' when calling QueryManagementApi->RunQueryUsingPOST");

            var localVarPath = "/api/v1/queryresult";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryResultDto != null && queryResultDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryResultDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryResultDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("RunQueryUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryResultDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryResultDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryResultDto)));
            
        }

        /// <summary>
        /// Update a single query Updates the query that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>BaseResponseOfQueryDto</returns>
        public BaseResponseOfQueryDto UpdateQueryUsingPUT (string queryId, QueryDto queryDto)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = UpdateQueryUsingPUTWithHttpInfo(queryId, queryDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update a single query Updates the query that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>ApiResponse of BaseResponseOfQueryDto</returns>
        public ApiResponse< BaseResponseOfQueryDto > UpdateQueryUsingPUTWithHttpInfo (string queryId, QueryDto queryDto)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->UpdateQueryUsingPUT");
            // verify the required parameter 'queryDto' is set
            if (queryDto == null)
                throw new ApiException(400, "Missing required parameter 'queryDto' when calling QueryManagementApi->UpdateQueryUsingPUT");

            var localVarPath = "/api/v1/query/{queryId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter
            if (queryDto != null && queryDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateQueryUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Update a single query Updates the query that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>Task of BaseResponseOfQueryDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfQueryDto> UpdateQueryUsingPUTAsync (string queryId, QueryDto queryDto)
        {
             ApiResponse<BaseResponseOfQueryDto> localVarResponse = await UpdateQueryUsingPUTAsyncWithHttpInfo(queryId, queryDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update a single query Updates the query that matches the provided ID with the details provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="queryId">The unique identifier of the query</param>
        /// <param name="queryDto">The representation of the query to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfQueryDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfQueryDto>> UpdateQueryUsingPUTAsyncWithHttpInfo (string queryId, QueryDto queryDto)
        {
            // verify the required parameter 'queryId' is set
            if (queryId == null)
                throw new ApiException(400, "Missing required parameter 'queryId' when calling QueryManagementApi->UpdateQueryUsingPUT");
            // verify the required parameter 'queryDto' is set
            if (queryDto == null)
                throw new ApiException(400, "Missing required parameter 'queryDto' when calling QueryManagementApi->UpdateQueryUsingPUT");

            var localVarPath = "/api/v1/query/{queryId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (queryId != null) localVarPathParams.Add("queryId", Configuration.ApiClient.ParameterToString(queryId)); // path parameter
            if (queryDto != null && queryDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(queryDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = queryDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateQueryUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfQueryDto)));
            
        }

    }
}
