/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ISelectListManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create a new select list
        /// </summary>
        /// <remarks>
        /// Creates a select list using the provided information and returns the select list meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>BaseResponseOfSelectListDto</returns>
        BaseResponseOfSelectListDto CreateSelectListUsingPOST (SelectListDto selectListDto);

        /// <summary>
        /// Create a new select list
        /// </summary>
        /// <remarks>
        /// Creates a select list using the provided information and returns the select list meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>ApiResponse of BaseResponseOfSelectListDto</returns>
        ApiResponse<BaseResponseOfSelectListDto> CreateSelectListUsingPOSTWithHttpInfo (SelectListDto selectListDto);
        /// <summary>
        /// Delete a single select list
        /// </summary>
        /// <remarks>
        /// Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteUsingDELETE (string selectListId);

        /// <summary>
        /// Delete a single select list
        /// </summary>
        /// <remarks>
        /// Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteUsingDELETEWithHttpInfo (string selectListId);
        /// <summary>
        /// Retrieve a single select list
        /// </summary>
        /// <remarks>
        /// Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>BaseResponseOfSelectListDto</returns>
        BaseResponseOfSelectListDto GetSelectListUsingGET (string selectListId);

        /// <summary>
        /// Retrieve a single select list
        /// </summary>
        /// <remarks>
        /// Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>ApiResponse of BaseResponseOfSelectListDto</returns>
        ApiResponse<BaseResponseOfSelectListDto> GetSelectListUsingGETWithHttpInfo (string selectListId);
        /// <summary>
        /// Retrieve a list of select lists
        /// </summary>
        /// <remarks>
        /// Returns a list of select lists associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfSelectListDto</returns>
        PagedResponseOfSelectListDto ListSelectListsUsingGET (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of select lists
        /// </summary>
        /// <remarks>
        /// Returns a list of select lists associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfSelectListDto</returns>
        ApiResponse<PagedResponseOfSelectListDto> ListSelectListsUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update a single select list
        /// </summary>
        /// <remarks>
        /// Updates the select list with the provided ID with the details provided  in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>BaseResponseOfSelectListDto</returns>
        BaseResponseOfSelectListDto UpdateSelectListUsingPUT (SelectListDto selectListDto, string selectListId);

        /// <summary>
        /// Update a single select list
        /// </summary>
        /// <remarks>
        /// Updates the select list with the provided ID with the details provided  in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>ApiResponse of BaseResponseOfSelectListDto</returns>
        ApiResponse<BaseResponseOfSelectListDto> UpdateSelectListUsingPUTWithHttpInfo (SelectListDto selectListDto, string selectListId);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create a new select list
        /// </summary>
        /// <remarks>
        /// Creates a select list using the provided information and returns the select list meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>Task of BaseResponseOfSelectListDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfSelectListDto> CreateSelectListUsingPOSTAsync (SelectListDto selectListDto);

        /// <summary>
        /// Create a new select list
        /// </summary>
        /// <remarks>
        /// Creates a select list using the provided information and returns the select list meta.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSelectListDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSelectListDto>> CreateSelectListUsingPOSTAsyncWithHttpInfo (SelectListDto selectListDto);
        /// <summary>
        /// Delete a single select list
        /// </summary>
        /// <remarks>
        /// Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteUsingDELETEAsync (string selectListId);

        /// <summary>
        /// Delete a single select list
        /// </summary>
        /// <remarks>
        /// Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteUsingDELETEAsyncWithHttpInfo (string selectListId);
        /// <summary>
        /// Retrieve a single select list
        /// </summary>
        /// <remarks>
        /// Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of BaseResponseOfSelectListDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfSelectListDto> GetSelectListUsingGETAsync (string selectListId);

        /// <summary>
        /// Retrieve a single select list
        /// </summary>
        /// <remarks>
        /// Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSelectListDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSelectListDto>> GetSelectListUsingGETAsyncWithHttpInfo (string selectListId);
        /// <summary>
        /// Retrieve a list of select lists
        /// </summary>
        /// <remarks>
        /// Returns a list of select lists associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfSelectListDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfSelectListDto> ListSelectListsUsingGETAsync (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of select lists
        /// </summary>
        /// <remarks>
        /// Returns a list of select lists associated with the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfSelectListDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfSelectListDto>> ListSelectListsUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update a single select list
        /// </summary>
        /// <remarks>
        /// Updates the select list with the provided ID with the details provided  in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of BaseResponseOfSelectListDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfSelectListDto> UpdateSelectListUsingPUTAsync (SelectListDto selectListDto, string selectListId);

        /// <summary>
        /// Update a single select list
        /// </summary>
        /// <remarks>
        /// Updates the select list with the provided ID with the details provided  in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSelectListDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSelectListDto>> UpdateSelectListUsingPUTAsyncWithHttpInfo (SelectListDto selectListDto, string selectListId);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class SelectListManagementApi : ISelectListManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="SelectListManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public SelectListManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SelectListManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public SelectListManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create a new select list Creates a select list using the provided information and returns the select list meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>BaseResponseOfSelectListDto</returns>
        public BaseResponseOfSelectListDto CreateSelectListUsingPOST (SelectListDto selectListDto)
        {
             ApiResponse<BaseResponseOfSelectListDto> localVarResponse = CreateSelectListUsingPOSTWithHttpInfo(selectListDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new select list Creates a select list using the provided information and returns the select list meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>ApiResponse of BaseResponseOfSelectListDto</returns>
        public ApiResponse< BaseResponseOfSelectListDto > CreateSelectListUsingPOSTWithHttpInfo (SelectListDto selectListDto)
        {
            // verify the required parameter 'selectListDto' is set
            if (selectListDto == null)
                throw new ApiException(400, "Missing required parameter 'selectListDto' when calling SelectListManagementApi->CreateSelectListUsingPOST");

            var localVarPath = "/api/v1/selectlist";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListDto != null && selectListDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(selectListDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = selectListDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateSelectListUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSelectListDto)));
            
        }

        /// <summary>
        /// Create a new select list Creates a select list using the provided information and returns the select list meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>Task of BaseResponseOfSelectListDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfSelectListDto> CreateSelectListUsingPOSTAsync (SelectListDto selectListDto)
        {
             ApiResponse<BaseResponseOfSelectListDto> localVarResponse = await CreateSelectListUsingPOSTAsyncWithHttpInfo(selectListDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new select list Creates a select list using the provided information and returns the select list meta.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSelectListDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSelectListDto>> CreateSelectListUsingPOSTAsyncWithHttpInfo (SelectListDto selectListDto)
        {
            // verify the required parameter 'selectListDto' is set
            if (selectListDto == null)
                throw new ApiException(400, "Missing required parameter 'selectListDto' when calling SelectListManagementApi->CreateSelectListUsingPOST");

            var localVarPath = "/api/v1/selectlist";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListDto != null && selectListDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(selectListDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = selectListDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateSelectListUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSelectListDto)));
            
        }

        /// <summary>
        /// Delete a single select list Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteUsingDELETE (string selectListId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteUsingDELETEWithHttpInfo(selectListId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single select list Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteUsingDELETEWithHttpInfo (string selectListId)
        {
            // verify the required parameter 'selectListId' is set
            if (selectListId == null)
                throw new ApiException(400, "Missing required parameter 'selectListId' when calling SelectListManagementApi->DeleteUsingDELETE");

            var localVarPath = "/api/v1/selectlist/{selectListId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListId != null) localVarPathParams.Add("selectListId", Configuration.ApiClient.ParameterToString(selectListId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single select list Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteUsingDELETEAsync (string selectListId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteUsingDELETEAsyncWithHttpInfo(selectListId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single select list Deletes a select list with the provided ID. If no such select list exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteUsingDELETEAsyncWithHttpInfo (string selectListId)
        {
            // verify the required parameter 'selectListId' is set
            if (selectListId == null)
                throw new ApiException(400, "Missing required parameter 'selectListId' when calling SelectListManagementApi->DeleteUsingDELETE");

            var localVarPath = "/api/v1/selectlist/{selectListId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListId != null) localVarPathParams.Add("selectListId", Configuration.ApiClient.ParameterToString(selectListId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Retrieve a single select list Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>BaseResponseOfSelectListDto</returns>
        public BaseResponseOfSelectListDto GetSelectListUsingGET (string selectListId)
        {
             ApiResponse<BaseResponseOfSelectListDto> localVarResponse = GetSelectListUsingGETWithHttpInfo(selectListId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single select list Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>ApiResponse of BaseResponseOfSelectListDto</returns>
        public ApiResponse< BaseResponseOfSelectListDto > GetSelectListUsingGETWithHttpInfo (string selectListId)
        {
            // verify the required parameter 'selectListId' is set
            if (selectListId == null)
                throw new ApiException(400, "Missing required parameter 'selectListId' when calling SelectListManagementApi->GetSelectListUsingGET");

            var localVarPath = "/api/v1/selectlist/{selectListId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListId != null) localVarPathParams.Add("selectListId", Configuration.ApiClient.ParameterToString(selectListId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetSelectListUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSelectListDto)));
            
        }

        /// <summary>
        /// Retrieve a single select list Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of BaseResponseOfSelectListDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfSelectListDto> GetSelectListUsingGETAsync (string selectListId)
        {
             ApiResponse<BaseResponseOfSelectListDto> localVarResponse = await GetSelectListUsingGETAsyncWithHttpInfo(selectListId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single select list Returns a select list that matches the provided ID, or a 404 if no matching select list is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSelectListDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSelectListDto>> GetSelectListUsingGETAsyncWithHttpInfo (string selectListId)
        {
            // verify the required parameter 'selectListId' is set
            if (selectListId == null)
                throw new ApiException(400, "Missing required parameter 'selectListId' when calling SelectListManagementApi->GetSelectListUsingGET");

            var localVarPath = "/api/v1/selectlist/{selectListId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListId != null) localVarPathParams.Add("selectListId", Configuration.ApiClient.ParameterToString(selectListId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetSelectListUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSelectListDto)));
            
        }

        /// <summary>
        /// Retrieve a list of select lists Returns a list of select lists associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfSelectListDto</returns>
        public PagedResponseOfSelectListDto ListSelectListsUsingGET (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfSelectListDto> localVarResponse = ListSelectListsUsingGETWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of select lists Returns a list of select lists associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfSelectListDto</returns>
        public ApiResponse< PagedResponseOfSelectListDto > ListSelectListsUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/selectlist";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListSelectListsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfSelectListDto)));
            
        }

        /// <summary>
        /// Retrieve a list of select lists Returns a list of select lists associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfSelectListDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfSelectListDto> ListSelectListsUsingGETAsync (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfSelectListDto> localVarResponse = await ListSelectListsUsingGETAsyncWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of select lists Returns a list of select lists associated with the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of select lists to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfSelectListDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfSelectListDto>> ListSelectListsUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/selectlist";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListSelectListsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfSelectListDto)));
            
        }

        /// <summary>
        /// Update a single select list Updates the select list with the provided ID with the details provided  in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>BaseResponseOfSelectListDto</returns>
        public BaseResponseOfSelectListDto UpdateSelectListUsingPUT (SelectListDto selectListDto, string selectListId)
        {
             ApiResponse<BaseResponseOfSelectListDto> localVarResponse = UpdateSelectListUsingPUTWithHttpInfo(selectListDto, selectListId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update a single select list Updates the select list with the provided ID with the details provided  in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>ApiResponse of BaseResponseOfSelectListDto</returns>
        public ApiResponse< BaseResponseOfSelectListDto > UpdateSelectListUsingPUTWithHttpInfo (SelectListDto selectListDto, string selectListId)
        {
            // verify the required parameter 'selectListDto' is set
            if (selectListDto == null)
                throw new ApiException(400, "Missing required parameter 'selectListDto' when calling SelectListManagementApi->UpdateSelectListUsingPUT");
            // verify the required parameter 'selectListId' is set
            if (selectListId == null)
                throw new ApiException(400, "Missing required parameter 'selectListId' when calling SelectListManagementApi->UpdateSelectListUsingPUT");

            var localVarPath = "/api/v1/selectlist/{selectListId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListId != null) localVarPathParams.Add("selectListId", Configuration.ApiClient.ParameterToString(selectListId)); // path parameter
            if (selectListDto != null && selectListDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(selectListDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = selectListDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateSelectListUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSelectListDto)));
            
        }

        /// <summary>
        /// Update a single select list Updates the select list with the provided ID with the details provided  in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of BaseResponseOfSelectListDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfSelectListDto> UpdateSelectListUsingPUTAsync (SelectListDto selectListDto, string selectListId)
        {
             ApiResponse<BaseResponseOfSelectListDto> localVarResponse = await UpdateSelectListUsingPUTAsyncWithHttpInfo(selectListDto, selectListId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update a single select list Updates the select list with the provided ID with the details provided  in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="selectListDto">The representation of the select list to update</param>
        /// <param name="selectListId">The unique identifier of the select list</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSelectListDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSelectListDto>> UpdateSelectListUsingPUTAsyncWithHttpInfo (SelectListDto selectListDto, string selectListId)
        {
            // verify the required parameter 'selectListDto' is set
            if (selectListDto == null)
                throw new ApiException(400, "Missing required parameter 'selectListDto' when calling SelectListManagementApi->UpdateSelectListUsingPUT");
            // verify the required parameter 'selectListId' is set
            if (selectListId == null)
                throw new ApiException(400, "Missing required parameter 'selectListId' when calling SelectListManagementApi->UpdateSelectListUsingPUT");

            var localVarPath = "/api/v1/selectlist/{selectListId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (selectListId != null) localVarPathParams.Add("selectListId", Configuration.ApiClient.ParameterToString(selectListId)); // path parameter
            if (selectListDto != null && selectListDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(selectListDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = selectListDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateSelectListUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSelectListDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSelectListDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSelectListDto)));
            
        }

    }
}
