/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ISharedTableManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create a new shared table
        /// </summary>
        /// <remarks>
        /// Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>BaseResponseOfSharedTableDto</returns>
        BaseResponseOfSharedTableDto CreateSharedTableUsingPOST (SharedTableDto sharedTableDto);

        /// <summary>
        /// Create a new shared table
        /// </summary>
        /// <remarks>
        /// Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>ApiResponse of BaseResponseOfSharedTableDto</returns>
        ApiResponse<BaseResponseOfSharedTableDto> CreateSharedTableUsingPOSTWithHttpInfo (SharedTableDto sharedTableDto);
        /// <summary>
        /// Delete a single shared table
        /// </summary>
        /// <remarks>
        /// Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteSharedTableUsingDELETE (string sharedTableId);

        /// <summary>
        /// Delete a single shared table
        /// </summary>
        /// <remarks>
        /// Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteSharedTableUsingDELETEWithHttpInfo (string sharedTableId);
        /// <summary>
        /// Retrieve a single shared table
        /// </summary>
        /// <remarks>
        /// Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>BaseResponseOfSharedTableDto</returns>
        BaseResponseOfSharedTableDto GetSharedTableUsingGET (string sharedTableId, bool? sharedWithMe = null);

        /// <summary>
        /// Retrieve a single shared table
        /// </summary>
        /// <remarks>
        /// Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfSharedTableDto</returns>
        ApiResponse<BaseResponseOfSharedTableDto> GetSharedTableUsingGETWithHttpInfo (string sharedTableId, bool? sharedWithMe = null);
        /// <summary>
        /// Retrieve a list of shared tables
        /// </summary>
        /// <remarks>
        /// Returns a list of shared tables associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfSharedTableDto</returns>
        PagedResponseOfSharedTableDto ListSharedTablesUsingGET (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of shared tables
        /// </summary>
        /// <remarks>
        /// Returns a list of shared tables associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfSharedTableDto</returns>
        ApiResponse<PagedResponseOfSharedTableDto> ListSharedTablesUsingGETWithHttpInfo (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create a new shared table
        /// </summary>
        /// <remarks>
        /// Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>Task of BaseResponseOfSharedTableDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfSharedTableDto> CreateSharedTableUsingPOSTAsync (SharedTableDto sharedTableDto);

        /// <summary>
        /// Create a new shared table
        /// </summary>
        /// <remarks>
        /// Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSharedTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSharedTableDto>> CreateSharedTableUsingPOSTAsyncWithHttpInfo (SharedTableDto sharedTableDto);
        /// <summary>
        /// Delete a single shared table
        /// </summary>
        /// <remarks>
        /// Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteSharedTableUsingDELETEAsync (string sharedTableId);

        /// <summary>
        /// Delete a single shared table
        /// </summary>
        /// <remarks>
        /// Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteSharedTableUsingDELETEAsyncWithHttpInfo (string sharedTableId);
        /// <summary>
        /// Retrieve a single shared table
        /// </summary>
        /// <remarks>
        /// Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>Task of BaseResponseOfSharedTableDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfSharedTableDto> GetSharedTableUsingGETAsync (string sharedTableId, bool? sharedWithMe = null);

        /// <summary>
        /// Retrieve a single shared table
        /// </summary>
        /// <remarks>
        /// Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSharedTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSharedTableDto>> GetSharedTableUsingGETAsyncWithHttpInfo (string sharedTableId, bool? sharedWithMe = null);
        /// <summary>
        /// Retrieve a list of shared tables
        /// </summary>
        /// <remarks>
        /// Returns a list of shared tables associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfSharedTableDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfSharedTableDto> ListSharedTablesUsingGETAsync (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of shared tables
        /// </summary>
        /// <remarks>
        /// Returns a list of shared tables associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfSharedTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfSharedTableDto>> ListSharedTablesUsingGETAsyncWithHttpInfo (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class SharedTableManagementApi : ISharedTableManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="SharedTableManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public SharedTableManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="SharedTableManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public SharedTableManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create a new shared table Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>BaseResponseOfSharedTableDto</returns>
        public BaseResponseOfSharedTableDto CreateSharedTableUsingPOST (SharedTableDto sharedTableDto)
        {
             ApiResponse<BaseResponseOfSharedTableDto> localVarResponse = CreateSharedTableUsingPOSTWithHttpInfo(sharedTableDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new shared table Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>ApiResponse of BaseResponseOfSharedTableDto</returns>
        public ApiResponse< BaseResponseOfSharedTableDto > CreateSharedTableUsingPOSTWithHttpInfo (SharedTableDto sharedTableDto)
        {
            // verify the required parameter 'sharedTableDto' is set
            if (sharedTableDto == null)
                throw new ApiException(400, "Missing required parameter 'sharedTableDto' when calling SharedTableManagementApi->CreateSharedTableUsingPOST");

            var localVarPath = "/api/v1/sharedtable";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sharedTableDto != null && sharedTableDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(sharedTableDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = sharedTableDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateSharedTableUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSharedTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSharedTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSharedTableDto)));
            
        }

        /// <summary>
        /// Create a new shared table Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>Task of BaseResponseOfSharedTableDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfSharedTableDto> CreateSharedTableUsingPOSTAsync (SharedTableDto sharedTableDto)
        {
             ApiResponse<BaseResponseOfSharedTableDto> localVarResponse = await CreateSharedTableUsingPOSTAsyncWithHttpInfo(sharedTableDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new shared table Creates a shared table instance between the workspace of the request and the workspace provided in the body.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableDto">The representation of the shared table to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSharedTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSharedTableDto>> CreateSharedTableUsingPOSTAsyncWithHttpInfo (SharedTableDto sharedTableDto)
        {
            // verify the required parameter 'sharedTableDto' is set
            if (sharedTableDto == null)
                throw new ApiException(400, "Missing required parameter 'sharedTableDto' when calling SharedTableManagementApi->CreateSharedTableUsingPOST");

            var localVarPath = "/api/v1/sharedtable";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sharedTableDto != null && sharedTableDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(sharedTableDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = sharedTableDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateSharedTableUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSharedTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSharedTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSharedTableDto)));
            
        }

        /// <summary>
        /// Delete a single shared table Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteSharedTableUsingDELETE (string sharedTableId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteSharedTableUsingDELETEWithHttpInfo(sharedTableId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single shared table Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteSharedTableUsingDELETEWithHttpInfo (string sharedTableId)
        {
            // verify the required parameter 'sharedTableId' is set
            if (sharedTableId == null)
                throw new ApiException(400, "Missing required parameter 'sharedTableId' when calling SharedTableManagementApi->DeleteSharedTableUsingDELETE");

            var localVarPath = "/api/v1/sharedtable/{sharedTableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sharedTableId != null) localVarPathParams.Add("sharedTableId", Configuration.ApiClient.ParameterToString(sharedTableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteSharedTableUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single shared table Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteSharedTableUsingDELETEAsync (string sharedTableId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteSharedTableUsingDELETEAsyncWithHttpInfo(sharedTableId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single shared table Deletes the linkages between the source and destination of a shared table that matches the provided ID; the actual table itself is left intact. If no such shared table exists, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteSharedTableUsingDELETEAsyncWithHttpInfo (string sharedTableId)
        {
            // verify the required parameter 'sharedTableId' is set
            if (sharedTableId == null)
                throw new ApiException(400, "Missing required parameter 'sharedTableId' when calling SharedTableManagementApi->DeleteSharedTableUsingDELETE");

            var localVarPath = "/api/v1/sharedtable/{sharedTableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sharedTableId != null) localVarPathParams.Add("sharedTableId", Configuration.ApiClient.ParameterToString(sharedTableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteSharedTableUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Retrieve a single shared table Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>BaseResponseOfSharedTableDto</returns>
        public BaseResponseOfSharedTableDto GetSharedTableUsingGET (string sharedTableId, bool? sharedWithMe = null)
        {
             ApiResponse<BaseResponseOfSharedTableDto> localVarResponse = GetSharedTableUsingGETWithHttpInfo(sharedTableId, sharedWithMe);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single shared table Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>ApiResponse of BaseResponseOfSharedTableDto</returns>
        public ApiResponse< BaseResponseOfSharedTableDto > GetSharedTableUsingGETWithHttpInfo (string sharedTableId, bool? sharedWithMe = null)
        {
            // verify the required parameter 'sharedTableId' is set
            if (sharedTableId == null)
                throw new ApiException(400, "Missing required parameter 'sharedTableId' when calling SharedTableManagementApi->GetSharedTableUsingGET");

            var localVarPath = "/api/v1/sharedtable/{sharedTableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sharedTableId != null) localVarPathParams.Add("sharedTableId", Configuration.ApiClient.ParameterToString(sharedTableId)); // path parameter
            if (sharedWithMe != null) localVarQueryParams.Add("sharedWithMe", Configuration.ApiClient.ParameterToString(sharedWithMe)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetSharedTableUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSharedTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSharedTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSharedTableDto)));
            
        }

        /// <summary>
        /// Retrieve a single shared table Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>Task of BaseResponseOfSharedTableDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfSharedTableDto> GetSharedTableUsingGETAsync (string sharedTableId, bool? sharedWithMe = null)
        {
             ApiResponse<BaseResponseOfSharedTableDto> localVarResponse = await GetSharedTableUsingGETAsyncWithHttpInfo(sharedTableId, sharedWithMe);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single shared table Returns a shared table that matches the provided ID, or a 404 if no matching shared table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="sharedTableId">The unique identifier of the shared table</param>
        /// <param name="sharedWithMe">If true, returns a shared table with the provided ID that has been shared _to_—rather than from—the workspace of the request. (optional)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfSharedTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfSharedTableDto>> GetSharedTableUsingGETAsyncWithHttpInfo (string sharedTableId, bool? sharedWithMe = null)
        {
            // verify the required parameter 'sharedTableId' is set
            if (sharedTableId == null)
                throw new ApiException(400, "Missing required parameter 'sharedTableId' when calling SharedTableManagementApi->GetSharedTableUsingGET");

            var localVarPath = "/api/v1/sharedtable/{sharedTableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (sharedTableId != null) localVarPathParams.Add("sharedTableId", Configuration.ApiClient.ParameterToString(sharedTableId)); // path parameter
            if (sharedWithMe != null) localVarQueryParams.Add("sharedWithMe", Configuration.ApiClient.ParameterToString(sharedWithMe)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetSharedTableUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfSharedTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfSharedTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfSharedTableDto)));
            
        }

        /// <summary>
        /// Retrieve a list of shared tables Returns a list of shared tables associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfSharedTableDto</returns>
        public PagedResponseOfSharedTableDto ListSharedTablesUsingGET (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfSharedTableDto> localVarResponse = ListSharedTablesUsingGETWithHttpInfo(tableId, sharedWithMe, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of shared tables Returns a list of shared tables associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfSharedTableDto</returns>
        public ApiResponse< PagedResponseOfSharedTableDto > ListSharedTablesUsingGETWithHttpInfo (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/sharedtable";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarQueryParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // query parameter
            if (sharedWithMe != null) localVarQueryParams.Add("sharedWithMe", Configuration.ApiClient.ParameterToString(sharedWithMe)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListSharedTablesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfSharedTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfSharedTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfSharedTableDto)));
            
        }

        /// <summary>
        /// Retrieve a list of shared tables Returns a list of shared tables associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfSharedTableDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfSharedTableDto> ListSharedTablesUsingGETAsync (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfSharedTableDto> localVarResponse = await ListSharedTablesUsingGETAsyncWithHttpInfo(tableId, sharedWithMe, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of shared tables Returns a list of shared tables associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique table identifier associated with the shared table (optional)</param>
        /// <param name="sharedWithMe">If true, returns a list of tables that have been shared _to_ it rather than from it. The entities contain both the shared table entity _and_ the table being shared. If true, &#x60;tableId&#x60; is ignored. (optional)</param>
        /// <param name="limit">The number of shared files to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfSharedTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfSharedTableDto>> ListSharedTablesUsingGETAsyncWithHttpInfo (string tableId = null, bool? sharedWithMe = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/sharedtable";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarQueryParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // query parameter
            if (sharedWithMe != null) localVarQueryParams.Add("sharedWithMe", Configuration.ApiClient.ParameterToString(sharedWithMe)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListSharedTablesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfSharedTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfSharedTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfSharedTableDto)));
            
        }

    }
}
