/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ITableManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create a new table
        /// </summary>
        /// <remarks>
        /// Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>BaseResponseOfTableDto</returns>
        BaseResponseOfTableDto CreateTableUsingPOST (TableDto body);

        /// <summary>
        /// Create a new table
        /// </summary>
        /// <remarks>
        /// Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>ApiResponse of BaseResponseOfTableDto</returns>
        ApiResponse<BaseResponseOfTableDto> CreateTableUsingPOSTWithHttpInfo (TableDto body);
        /// <summary>
        /// Delete a single table
        /// </summary>
        /// <remarks>
        /// Soft-deletes the table with the provided ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteTableUsingDELETE (string tableId);

        /// <summary>
        /// Delete a single table
        /// </summary>
        /// <remarks>
        /// Soft-deletes the table with the provided ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteTableUsingDELETEWithHttpInfo (string tableId);
        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfQueryDto</returns>
        PagedResponseOfQueryDto GetDependentsUsingGET (string tableId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfQueryDto</returns>
        ApiResponse<PagedResponseOfQueryDto> GetDependentsUsingGETWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve import information
        /// </summary>
        /// <remarks>
        /// Returns information around imported files for a table.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfImportInfoDto</returns>
        BaseResponseOfImportInfoDto GetImportInfoUsingGET (string tableId);

        /// <summary>
        /// Retrieve import information
        /// </summary>
        /// <remarks>
        /// Returns information around imported files for a table.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfImportInfoDto</returns>
        ApiResponse<BaseResponseOfImportInfoDto> GetImportInfoUsingGETWithHttpInfo (string tableId);
        /// <summary>
        /// Retrieve a single table
        /// </summary>
        /// <remarks>
        /// Returns a table with the provided ID, or a 404 if no such table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfTableDto</returns>
        BaseResponseOfTableDto GetTableUsingGET (string tableId);

        /// <summary>
        /// Retrieve a single table
        /// </summary>
        /// <remarks>
        /// Returns a table with the provided ID, or a 404 if no such table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfTableDto</returns>
        ApiResponse<BaseResponseOfTableDto> GetTableUsingGETWithHttpInfo (string tableId);
        /// <summary>
        /// Retrieve a list of tables
        /// </summary>
        /// <remarks>
        /// Returns all tables available in the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>PagedResponseOfTableDto</returns>
        PagedResponseOfTableDto GetTablesUsingGET (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of tables
        /// </summary>
        /// <remarks>
        /// Returns all tables available in the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTableDto</returns>
        ApiResponse<PagedResponseOfTableDto> GetTablesUsingGETWithHttpInfo (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Import a single file
        /// </summary>
        /// <remarks>
        /// Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        BaseResponseOfFileMetaDto ImportFileUsingPOST (string tableId, ImportDto importDto);

        /// <summary>
        /// Import a single file
        /// </summary>
        /// <remarks>
        /// Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        ApiResponse<BaseResponseOfFileMetaDto> ImportFileUsingPOSTWithHttpInfo (string tableId, ImportDto importDto);
        /// <summary>
        /// Import from spreadsheets
        /// </summary>
        /// <remarks>
        /// Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        BaseResponseOfFileMetaDto ImportFromSpreadsheetsUsingPOST (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto);

        /// <summary>
        /// Import from spreadsheets
        /// </summary>
        /// <remarks>
        /// Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        ApiResponse<BaseResponseOfFileMetaDto> ImportFromSpreadsheetsUsingPOSTWithHttpInfo (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto);
        /// <summary>
        /// Unimport a single file
        /// </summary>
        /// <remarks>
        /// Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        BaseResponseOfFileMetaDto UnimportFileUsingDELETE (string tableId, string fileId, string force = null);

        /// <summary>
        /// Unimport a single file
        /// </summary>
        /// <remarks>
        /// Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        ApiResponse<BaseResponseOfFileMetaDto> UnimportFileUsingDELETEWithHttpInfo (string tableId, string fileId, string force = null);
        /// <summary>
        /// Update a single table
        /// </summary>
        /// <remarks>
        /// Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfTableDto</returns>
        BaseResponseOfTableDto UpdateTableUsingPUT (TableDto tableDto, string tableId);

        /// <summary>
        /// Update a single table
        /// </summary>
        /// <remarks>
        /// Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfTableDto</returns>
        ApiResponse<BaseResponseOfTableDto> UpdateTableUsingPUTWithHttpInfo (TableDto tableDto, string tableId);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create a new table
        /// </summary>
        /// <remarks>
        /// Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>Task of BaseResponseOfTableDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTableDto> CreateTableUsingPOSTAsync (TableDto body);

        /// <summary>
        /// Create a new table
        /// </summary>
        /// <remarks>
        /// Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTableDto>> CreateTableUsingPOSTAsyncWithHttpInfo (TableDto body);
        /// <summary>
        /// Delete a single table
        /// </summary>
        /// <remarks>
        /// Soft-deletes the table with the provided ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteTableUsingDELETEAsync (string tableId);

        /// <summary>
        /// Delete a single table
        /// </summary>
        /// <remarks>
        /// Soft-deletes the table with the provided ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteTableUsingDELETEAsyncWithHttpInfo (string tableId);
        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfQueryDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfQueryDto> GetDependentsUsingGETAsync (string tableId, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of dependents
        /// </summary>
        /// <remarks>
        /// Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfQueryDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfQueryDto>> GetDependentsUsingGETAsyncWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Retrieve import information
        /// </summary>
        /// <remarks>
        /// Returns information around imported files for a table.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfImportInfoDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfImportInfoDto> GetImportInfoUsingGETAsync (string tableId);

        /// <summary>
        /// Retrieve import information
        /// </summary>
        /// <remarks>
        /// Returns information around imported files for a table.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfImportInfoDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfImportInfoDto>> GetImportInfoUsingGETAsyncWithHttpInfo (string tableId);
        /// <summary>
        /// Retrieve a single table
        /// </summary>
        /// <remarks>
        /// Returns a table with the provided ID, or a 404 if no such table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfTableDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTableDto> GetTableUsingGETAsync (string tableId);

        /// <summary>
        /// Retrieve a single table
        /// </summary>
        /// <remarks>
        /// Returns a table with the provided ID, or a 404 if no such table is found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTableDto>> GetTableUsingGETAsyncWithHttpInfo (string tableId);
        /// <summary>
        /// Retrieve a list of tables
        /// </summary>
        /// <remarks>
        /// Returns all tables available in the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTableDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfTableDto> GetTablesUsingGETAsync (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of tables
        /// </summary>
        /// <remarks>
        /// Returns all tables available in the workspace.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTableDto>> GetTablesUsingGETAsyncWithHttpInfo (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Import a single file
        /// </summary>
        /// <remarks>
        /// Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> ImportFileUsingPOSTAsync (string tableId, ImportDto importDto);

        /// <summary>
        /// Import a single file
        /// </summary>
        /// <remarks>
        /// Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> ImportFileUsingPOSTAsyncWithHttpInfo (string tableId, ImportDto importDto);
        /// <summary>
        /// Import from spreadsheets
        /// </summary>
        /// <remarks>
        /// Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> ImportFromSpreadsheetsUsingPOSTAsync (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto);

        /// <summary>
        /// Import from spreadsheets
        /// </summary>
        /// <remarks>
        /// Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> ImportFromSpreadsheetsUsingPOSTAsyncWithHttpInfo (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto);
        /// <summary>
        /// Unimport a single file
        /// </summary>
        /// <remarks>
        /// Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> UnimportFileUsingDELETEAsync (string tableId, string fileId, string force = null);

        /// <summary>
        /// Unimport a single file
        /// </summary>
        /// <remarks>
        /// Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> UnimportFileUsingDELETEAsyncWithHttpInfo (string tableId, string fileId, string force = null);
        /// <summary>
        /// Update a single table
        /// </summary>
        /// <remarks>
        /// Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfTableDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTableDto> UpdateTableUsingPUTAsync (TableDto tableDto, string tableId);

        /// <summary>
        /// Update a single table
        /// </summary>
        /// <remarks>
        /// Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTableDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTableDto>> UpdateTableUsingPUTAsyncWithHttpInfo (TableDto tableDto, string tableId);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class TableManagementApi : ITableManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="TableManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public TableManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="TableManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public TableManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create a new table Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>BaseResponseOfTableDto</returns>
        public BaseResponseOfTableDto CreateTableUsingPOST (TableDto body)
        {
             ApiResponse<BaseResponseOfTableDto> localVarResponse = CreateTableUsingPOSTWithHttpInfo(body);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new table Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>ApiResponse of BaseResponseOfTableDto</returns>
        public ApiResponse< BaseResponseOfTableDto > CreateTableUsingPOSTWithHttpInfo (TableDto body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling TableManagementApi->CreateTableUsingPOST");

            var localVarPath = "/api/v1/table";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateTableUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTableDto)));
            
        }

        /// <summary>
        /// Create a new table Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>Task of BaseResponseOfTableDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTableDto> CreateTableUsingPOSTAsync (TableDto body)
        {
             ApiResponse<BaseResponseOfTableDto> localVarResponse = await CreateTableUsingPOSTAsyncWithHttpInfo(body);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new table Creates a table in the database with the specified schema. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="body">The representation of the table to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTableDto>> CreateTableUsingPOSTAsyncWithHttpInfo (TableDto body)
        {
            // verify the required parameter 'body' is set
            if (body == null)
                throw new ApiException(400, "Missing required parameter 'body' when calling TableManagementApi->CreateTableUsingPOST");

            var localVarPath = "/api/v1/table";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (body != null && body.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(body); // http body (model) parameter
            }
            else
            {
                localVarPostBody = body; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateTableUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTableDto)));
            
        }

        /// <summary>
        /// Delete a single table Soft-deletes the table with the provided ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteTableUsingDELETE (string tableId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteTableUsingDELETEWithHttpInfo(tableId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single table Soft-deletes the table with the provided ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteTableUsingDELETEWithHttpInfo (string tableId)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->DeleteTableUsingDELETE");

            var localVarPath = "/api/v1/table/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteTableUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single table Soft-deletes the table with the provided ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteTableUsingDELETEAsync (string tableId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteTableUsingDELETEAsyncWithHttpInfo(tableId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single table Soft-deletes the table with the provided ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteTableUsingDELETEAsyncWithHttpInfo (string tableId)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->DeleteTableUsingDELETE");

            var localVarPath = "/api/v1/table/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteTableUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfQueryDto</returns>
        public PagedResponseOfQueryDto GetDependentsUsingGET (string tableId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfQueryDto> localVarResponse = GetDependentsUsingGETWithHttpInfo(tableId, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfQueryDto</returns>
        public ApiResponse< PagedResponseOfQueryDto > GetDependentsUsingGETWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->GetDependentsUsingGET");

            var localVarPath = "/api/v1/table/{tableId}/dependents";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetDependentsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfQueryDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfQueryDto> GetDependentsUsingGETAsync (string tableId, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfQueryDto> localVarResponse = await GetDependentsUsingGETAsyncWithHttpInfo(tableId, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of dependents Returns a list of all queries that use the table with provided ID as a datasource. If a shared table, this may include queries outside of the current OAuth context.  Permission is checked only for the table ID provided, _not_ on the returned list of queries.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="limit">The number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfQueryDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfQueryDto>> GetDependentsUsingGETAsyncWithHttpInfo (string tableId, int? limit = null, string cursor = null, long? offset = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->GetDependentsUsingGET");

            var localVarPath = "/api/v1/table/{tableId}/dependents";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetDependentsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfQueryDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfQueryDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfQueryDto)));
            
        }

        /// <summary>
        /// Retrieve import information Returns information around imported files for a table.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfImportInfoDto</returns>
        public BaseResponseOfImportInfoDto GetImportInfoUsingGET (string tableId)
        {
             ApiResponse<BaseResponseOfImportInfoDto> localVarResponse = GetImportInfoUsingGETWithHttpInfo(tableId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve import information Returns information around imported files for a table.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfImportInfoDto</returns>
        public ApiResponse< BaseResponseOfImportInfoDto > GetImportInfoUsingGETWithHttpInfo (string tableId)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->GetImportInfoUsingGET");

            var localVarPath = "/api/v1/table/{tableId}/importInfo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetImportInfoUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfImportInfoDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfImportInfoDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfImportInfoDto)));
            
        }

        /// <summary>
        /// Retrieve import information Returns information around imported files for a table.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfImportInfoDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfImportInfoDto> GetImportInfoUsingGETAsync (string tableId)
        {
             ApiResponse<BaseResponseOfImportInfoDto> localVarResponse = await GetImportInfoUsingGETAsyncWithHttpInfo(tableId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve import information Returns information around imported files for a table.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfImportInfoDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfImportInfoDto>> GetImportInfoUsingGETAsyncWithHttpInfo (string tableId)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->GetImportInfoUsingGET");

            var localVarPath = "/api/v1/table/{tableId}/importInfo";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetImportInfoUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfImportInfoDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfImportInfoDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfImportInfoDto)));
            
        }

        /// <summary>
        /// Retrieve a single table Returns a table with the provided ID, or a 404 if no such table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfTableDto</returns>
        public BaseResponseOfTableDto GetTableUsingGET (string tableId)
        {
             ApiResponse<BaseResponseOfTableDto> localVarResponse = GetTableUsingGETWithHttpInfo(tableId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a single table Returns a table with the provided ID, or a 404 if no such table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfTableDto</returns>
        public ApiResponse< BaseResponseOfTableDto > GetTableUsingGETWithHttpInfo (string tableId)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->GetTableUsingGET");

            var localVarPath = "/api/v1/table/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetTableUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTableDto)));
            
        }

        /// <summary>
        /// Retrieve a single table Returns a table with the provided ID, or a 404 if no such table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfTableDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTableDto> GetTableUsingGETAsync (string tableId)
        {
             ApiResponse<BaseResponseOfTableDto> localVarResponse = await GetTableUsingGETAsyncWithHttpInfo(tableId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a single table Returns a table with the provided ID, or a 404 if no such table is found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTableDto>> GetTableUsingGETAsyncWithHttpInfo (string tableId)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->GetTableUsingGET");

            var localVarPath = "/api/v1/table/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetTableUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTableDto)));
            
        }

        /// <summary>
        /// Retrieve a list of tables Returns all tables available in the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>PagedResponseOfTableDto</returns>
        public PagedResponseOfTableDto GetTablesUsingGET (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTableDto> localVarResponse = GetTablesUsingGETWithHttpInfo(includeShared, limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of tables Returns all tables available in the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTableDto</returns>
        public ApiResponse< PagedResponseOfTableDto > GetTablesUsingGETWithHttpInfo (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/table";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (includeShared != null) localVarQueryParams.Add("includeShared", Configuration.ApiClient.ParameterToString(includeShared)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetTablesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTableDto)));
            
        }

        /// <summary>
        /// Retrieve a list of tables Returns all tables available in the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTableDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfTableDto> GetTablesUsingGETAsync (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTableDto> localVarResponse = await GetTablesUsingGETAsyncWithHttpInfo(includeShared, limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of tables Returns all tables available in the workspace.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="includeShared">If true, returns all tables shared with the workspace associated with the request. If false, returns only tables the workspace owns. (optional, default to false)</param>
        /// <param name="limit">the number of folders to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">a paging cursor; if included the limit is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, must be greater than or equal to 0, will default to 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTableDto>> GetTablesUsingGETAsyncWithHttpInfo (bool? includeShared = null, int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/table";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (includeShared != null) localVarQueryParams.Add("includeShared", Configuration.ApiClient.ParameterToString(includeShared)); // query parameter
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("GetTablesUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTableDto)));
            
        }

        /// <summary>
        /// Import a single file Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        public BaseResponseOfFileMetaDto ImportFileUsingPOST (string tableId, ImportDto importDto)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = ImportFileUsingPOSTWithHttpInfo(tableId, importDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Import a single file Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        public ApiResponse< BaseResponseOfFileMetaDto > ImportFileUsingPOSTWithHttpInfo (string tableId, ImportDto importDto)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->ImportFileUsingPOST");
            // verify the required parameter 'importDto' is set
            if (importDto == null)
                throw new ApiException(400, "Missing required parameter 'importDto' when calling TableManagementApi->ImportFileUsingPOST");

            var localVarPath = "/api/v1/table/{tableId}/import";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (importDto != null && importDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(importDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = importDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ImportFileUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Import a single file Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> ImportFileUsingPOSTAsync (string tableId, ImportDto importDto)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = await ImportFileUsingPOSTAsyncWithHttpInfo(tableId, importDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Import a single file Imports the provided file into the associated table, and immediately returns a file meta object with an ID that can be used to poll the file controller for status.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importDto">The representation of the table to import</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> ImportFileUsingPOSTAsyncWithHttpInfo (string tableId, ImportDto importDto)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->ImportFileUsingPOST");
            // verify the required parameter 'importDto' is set
            if (importDto == null)
                throw new ApiException(400, "Missing required parameter 'importDto' when calling TableManagementApi->ImportFileUsingPOST");

            var localVarPath = "/api/v1/table/{tableId}/import";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (importDto != null && importDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(importDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = importDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ImportFileUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Import from spreadsheets Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        public BaseResponseOfFileMetaDto ImportFromSpreadsheetsUsingPOST (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = ImportFromSpreadsheetsUsingPOSTWithHttpInfo(tableId, importFromSpreadsheetDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Import from spreadsheets Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        public ApiResponse< BaseResponseOfFileMetaDto > ImportFromSpreadsheetsUsingPOSTWithHttpInfo (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->ImportFromSpreadsheetsUsingPOST");
            // verify the required parameter 'importFromSpreadsheetDto' is set
            if (importFromSpreadsheetDto == null)
                throw new ApiException(400, "Missing required parameter 'importFromSpreadsheetDto' when calling TableManagementApi->ImportFromSpreadsheetsUsingPOST");

            var localVarPath = "/api/v1/table/{tableId}/spreadsheet/import";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (importFromSpreadsheetDto != null && importFromSpreadsheetDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(importFromSpreadsheetDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = importFromSpreadsheetDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ImportFromSpreadsheetsUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Import from spreadsheets Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> ImportFromSpreadsheetsUsingPOSTAsync (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = await ImportFromSpreadsheetsUsingPOSTAsyncWithHttpInfo(tableId, importFromSpreadsheetDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Import from spreadsheets Imports spreadsheet data and immediately returns a file meta result. This DTO has an ID, which can be used to poll on status via the file controller.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="importFromSpreadsheetDto">The representation of the table to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> ImportFromSpreadsheetsUsingPOSTAsyncWithHttpInfo (string tableId, ImportFromSpreadsheetDto importFromSpreadsheetDto)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->ImportFromSpreadsheetsUsingPOST");
            // verify the required parameter 'importFromSpreadsheetDto' is set
            if (importFromSpreadsheetDto == null)
                throw new ApiException(400, "Missing required parameter 'importFromSpreadsheetDto' when calling TableManagementApi->ImportFromSpreadsheetsUsingPOST");

            var localVarPath = "/api/v1/table/{tableId}/spreadsheet/import";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (importFromSpreadsheetDto != null && importFromSpreadsheetDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(importFromSpreadsheetDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = importFromSpreadsheetDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ImportFromSpreadsheetsUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Unimport a single file Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>BaseResponseOfFileMetaDto</returns>
        public BaseResponseOfFileMetaDto UnimportFileUsingDELETE (string tableId, string fileId, string force = null)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = UnimportFileUsingDELETEWithHttpInfo(tableId, fileId, force);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Unimport a single file Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>ApiResponse of BaseResponseOfFileMetaDto</returns>
        public ApiResponse< BaseResponseOfFileMetaDto > UnimportFileUsingDELETEWithHttpInfo (string tableId, string fileId, string force = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->UnimportFileUsingDELETE");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling TableManagementApi->UnimportFileUsingDELETE");

            var localVarPath = "/api/v1/table/{tableId}/import/{fileId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter
            if (force != null) localVarQueryParams.Add("force", Configuration.ApiClient.ParameterToString(force)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UnimportFileUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Unimport a single file Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>Task of BaseResponseOfFileMetaDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfFileMetaDto> UnimportFileUsingDELETEAsync (string tableId, string fileId, string force = null)
        {
             ApiResponse<BaseResponseOfFileMetaDto> localVarResponse = await UnimportFileUsingDELETEAsyncWithHttpInfo(tableId, fileId, force);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Unimport a single file Unimports the provided file from the provided table. Returns a 409 if the file is not in an imported state, or a 404 if the file can&#39;t be found.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <param name="fileId">The unique identifier of the file</param>
        /// <param name="force">If true, unimports and deletes file from the table (optional, default to false)</param>
        /// <returns>Task of ApiResponse (BaseResponseOfFileMetaDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfFileMetaDto>> UnimportFileUsingDELETEAsyncWithHttpInfo (string tableId, string fileId, string force = null)
        {
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->UnimportFileUsingDELETE");
            // verify the required parameter 'fileId' is set
            if (fileId == null)
                throw new ApiException(400, "Missing required parameter 'fileId' when calling TableManagementApi->UnimportFileUsingDELETE");

            var localVarPath = "/api/v1/table/{tableId}/import/{fileId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (fileId != null) localVarPathParams.Add("fileId", Configuration.ApiClient.ParameterToString(fileId)); // path parameter
            if (force != null) localVarQueryParams.Add("force", Configuration.ApiClient.ParameterToString(force)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UnimportFileUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfFileMetaDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfFileMetaDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfFileMetaDto)));
            
        }

        /// <summary>
        /// Update a single table Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>BaseResponseOfTableDto</returns>
        public BaseResponseOfTableDto UpdateTableUsingPUT (TableDto tableDto, string tableId)
        {
             ApiResponse<BaseResponseOfTableDto> localVarResponse = UpdateTableUsingPUTWithHttpInfo(tableDto, tableId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update a single table Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>ApiResponse of BaseResponseOfTableDto</returns>
        public ApiResponse< BaseResponseOfTableDto > UpdateTableUsingPUTWithHttpInfo (TableDto tableDto, string tableId)
        {
            // verify the required parameter 'tableDto' is set
            if (tableDto == null)
                throw new ApiException(400, "Missing required parameter 'tableDto' when calling TableManagementApi->UpdateTableUsingPUT");
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->UpdateTableUsingPUT");

            var localVarPath = "/api/v1/table/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (tableDto != null && tableDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tableDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tableDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateTableUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTableDto)));
            
        }

        /// <summary>
        /// Update a single table Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of BaseResponseOfTableDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTableDto> UpdateTableUsingPUTAsync (TableDto tableDto, string tableId)
        {
             ApiResponse<BaseResponseOfTableDto> localVarResponse = await UpdateTableUsingPUTAsyncWithHttpInfo(tableDto, tableId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update a single table Updates an existing table with the provided information. Include all user-defined table columns with the request. For type, specify either a dimension or data table. In the interface, data tables appear as fact tables.  * If the table has no imported data, user-defined columns not included with the request are deleted, and columns are sorted according to their order in the request.  * If the table has imported data, any columns with names not already in the table are considered new. This equality check is case-insensitive. Any new columns appear after other user-defined columns, but before any meta columns, which start with &#x60;_&#x60;.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tableDto">The representation of the table to update</param>
        /// <param name="tableId">The unique identifier of the table</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTableDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTableDto>> UpdateTableUsingPUTAsyncWithHttpInfo (TableDto tableDto, string tableId)
        {
            // verify the required parameter 'tableDto' is set
            if (tableDto == null)
                throw new ApiException(400, "Missing required parameter 'tableDto' when calling TableManagementApi->UpdateTableUsingPUT");
            // verify the required parameter 'tableId' is set
            if (tableId == null)
                throw new ApiException(400, "Missing required parameter 'tableId' when calling TableManagementApi->UpdateTableUsingPUT");

            var localVarPath = "/api/v1/table/{tableId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tableId != null) localVarPathParams.Add("tableId", Configuration.ApiClient.ParameterToString(tableId)); // path parameter
            if (tableDto != null && tableDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tableDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tableDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateTableUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTableDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTableDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTableDto)));
            
        }

    }
}
