/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ITagManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create a new tag
        /// </summary>
        /// <remarks>
        /// Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>BaseResponseOfTagDto</returns>
        BaseResponseOfTagDto CreateTagUsingPOST (TagDto tagDto);

        /// <summary>
        /// Create a new tag
        /// </summary>
        /// <remarks>
        /// Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>ApiResponse of BaseResponseOfTagDto</returns>
        ApiResponse<BaseResponseOfTagDto> CreateTagUsingPOSTWithHttpInfo (TagDto tagDto);
        /// <summary>
        /// Delete a single tag
        /// </summary>
        /// <remarks>
        /// Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring DeleteTagUsingDELETE (string tagId);

        /// <summary>
        /// Delete a single tag
        /// </summary>
        /// <remarks>
        /// Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> DeleteTagUsingDELETEWithHttpInfo (string tagId);
        /// <summary>
        /// Retrieve a list of tags
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all tags associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfTagDto</returns>
        PagedResponseOfTagDto ListTagsUsingGET (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of tags
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all tags associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTagDto</returns>
        ApiResponse<PagedResponseOfTagDto> ListTagsUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update a single tag
        /// </summary>
        /// <remarks>
        /// Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>BaseResponseOfTagDto</returns>
        BaseResponseOfTagDto UpdateTagUsingPUT (string tagId, TagDto tagDto);

        /// <summary>
        /// Update a single tag
        /// </summary>
        /// <remarks>
        /// Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>ApiResponse of BaseResponseOfTagDto</returns>
        ApiResponse<BaseResponseOfTagDto> UpdateTagUsingPUTWithHttpInfo (string tagId, TagDto tagDto);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create a new tag
        /// </summary>
        /// <remarks>
        /// Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>Task of BaseResponseOfTagDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTagDto> CreateTagUsingPOSTAsync (TagDto tagDto);

        /// <summary>
        /// Create a new tag
        /// </summary>
        /// <remarks>
        /// Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTagDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTagDto>> CreateTagUsingPOSTAsyncWithHttpInfo (TagDto tagDto);
        /// <summary>
        /// Delete a single tag
        /// </summary>
        /// <remarks>
        /// Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> DeleteTagUsingDELETEAsync (string tagId);

        /// <summary>
        /// Delete a single tag
        /// </summary>
        /// <remarks>
        /// Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteTagUsingDELETEAsyncWithHttpInfo (string tagId);
        /// <summary>
        /// Retrieve a list of tags
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all tags associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTagDto</returns>
        System.Threading.Tasks.Task<PagedResponseOfTagDto> ListTagsUsingGETAsync (int? limit = null, string cursor = null, long? offset = null);

        /// <summary>
        /// Retrieve a list of tags
        /// </summary>
        /// <remarks>
        /// Returns a paged list of all tags associated with the workspace of the request.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTagDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTagDto>> ListTagsUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null);
        /// <summary>
        /// Update a single tag
        /// </summary>
        /// <remarks>
        /// Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>Task of BaseResponseOfTagDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTagDto> UpdateTagUsingPUTAsync (string tagId, TagDto tagDto);

        /// <summary>
        /// Update a single tag
        /// </summary>
        /// <remarks>
        /// Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTagDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTagDto>> UpdateTagUsingPUTAsyncWithHttpInfo (string tagId, TagDto tagDto);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class TagManagementApi : ITagManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="TagManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public TagManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="TagManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public TagManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create a new tag Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>BaseResponseOfTagDto</returns>
        public BaseResponseOfTagDto CreateTagUsingPOST (TagDto tagDto)
        {
             ApiResponse<BaseResponseOfTagDto> localVarResponse = CreateTagUsingPOSTWithHttpInfo(tagDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new tag Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>ApiResponse of BaseResponseOfTagDto</returns>
        public ApiResponse< BaseResponseOfTagDto > CreateTagUsingPOSTWithHttpInfo (TagDto tagDto)
        {
            // verify the required parameter 'tagDto' is set
            if (tagDto == null)
                throw new ApiException(400, "Missing required parameter 'tagDto' when calling TagManagementApi->CreateTagUsingPOST");

            var localVarPath = "/api/v1/tag";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tagDto != null && tagDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tagDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tagDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateTagUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTagDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTagDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTagDto)));
            
        }

        /// <summary>
        /// Create a new tag Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>Task of BaseResponseOfTagDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTagDto> CreateTagUsingPOSTAsync (TagDto tagDto)
        {
             ApiResponse<BaseResponseOfTagDto> localVarResponse = await CreateTagUsingPOSTAsyncWithHttpInfo(tagDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new tag Creates a tag. If another tag already has the same key, returns a 409. There is a limit of 300 values for a tag.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagDto">The representation of the tag to create</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTagDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTagDto>> CreateTagUsingPOSTAsyncWithHttpInfo (TagDto tagDto)
        {
            // verify the required parameter 'tagDto' is set
            if (tagDto == null)
                throw new ApiException(400, "Missing required parameter 'tagDto' when calling TagManagementApi->CreateTagUsingPOST");

            var localVarPath = "/api/v1/tag";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tagDto != null && tagDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tagDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tagDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateTagUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTagDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTagDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTagDto)));
            
        }

        /// <summary>
        /// Delete a single tag Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring DeleteTagUsingDELETE (string tagId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = DeleteTagUsingDELETEWithHttpInfo(tagId);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Delete a single tag Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > DeleteTagUsingDELETEWithHttpInfo (string tagId)
        {
            // verify the required parameter 'tagId' is set
            if (tagId == null)
                throw new ApiException(400, "Missing required parameter 'tagId' when calling TagManagementApi->DeleteTagUsingDELETE");

            var localVarPath = "/api/v1/tag/{tagId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tagId != null) localVarPathParams.Add("tagId", Configuration.ApiClient.ParameterToString(tagId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteTagUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Delete a single tag Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> DeleteTagUsingDELETEAsync (string tagId)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await DeleteTagUsingDELETEAsyncWithHttpInfo(tagId);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Delete a single tag Deletes the tag with the provided ID. If no such tag is found, this is a no-op.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> DeleteTagUsingDELETEAsyncWithHttpInfo (string tagId)
        {
            // verify the required parameter 'tagId' is set
            if (tagId == null)
                throw new ApiException(400, "Missing required parameter 'tagId' when calling TagManagementApi->DeleteTagUsingDELETE");

            var localVarPath = "/api/v1/tag/{tagId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tagId != null) localVarPathParams.Add("tagId", Configuration.ApiClient.ParameterToString(tagId)); // path parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.DELETE, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DeleteTagUsingDELETE", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Retrieve a list of tags Returns a paged list of all tags associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>PagedResponseOfTagDto</returns>
        public PagedResponseOfTagDto ListTagsUsingGET (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTagDto> localVarResponse = ListTagsUsingGETWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Retrieve a list of tags Returns a paged list of all tags associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>ApiResponse of PagedResponseOfTagDto</returns>
        public ApiResponse< PagedResponseOfTagDto > ListTagsUsingGETWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/tag";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListTagsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTagDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTagDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTagDto)));
            
        }

        /// <summary>
        /// Retrieve a list of tags Returns a paged list of all tags associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of PagedResponseOfTagDto</returns>
        public async System.Threading.Tasks.Task<PagedResponseOfTagDto> ListTagsUsingGETAsync (int? limit = null, string cursor = null, long? offset = null)
        {
             ApiResponse<PagedResponseOfTagDto> localVarResponse = await ListTagsUsingGETAsyncWithHttpInfo(limit, cursor, offset);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Retrieve a list of tags Returns a paged list of all tags associated with the workspace of the request.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="limit">The number of tags to return, from 1 to 1000; by default, 1000 (optional)</param>
        /// <param name="cursor">A paging cursor; if included, &#x60;limit&#x60; is ignored (optional)</param>
        /// <param name="offset">The item to start with on the page, greater than or equal to 0; by default, 0 (optional)</param>
        /// <returns>Task of ApiResponse (PagedResponseOfTagDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PagedResponseOfTagDto>> ListTagsUsingGETAsyncWithHttpInfo (int? limit = null, string cursor = null, long? offset = null)
        {

            var localVarPath = "/api/v1/tag";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (limit != null) localVarQueryParams.Add("limit", Configuration.ApiClient.ParameterToString(limit)); // query parameter
            if (cursor != null) localVarQueryParams.Add("cursor", Configuration.ApiClient.ParameterToString(cursor)); // query parameter
            if (offset != null) localVarQueryParams.Add("offset", Configuration.ApiClient.ParameterToString(offset)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ListTagsUsingGET", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PagedResponseOfTagDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (PagedResponseOfTagDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(PagedResponseOfTagDto)));
            
        }

        /// <summary>
        /// Update a single tag Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>BaseResponseOfTagDto</returns>
        public BaseResponseOfTagDto UpdateTagUsingPUT (string tagId, TagDto tagDto)
        {
             ApiResponse<BaseResponseOfTagDto> localVarResponse = UpdateTagUsingPUTWithHttpInfo(tagId, tagDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Update a single tag Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>ApiResponse of BaseResponseOfTagDto</returns>
        public ApiResponse< BaseResponseOfTagDto > UpdateTagUsingPUTWithHttpInfo (string tagId, TagDto tagDto)
        {
            // verify the required parameter 'tagId' is set
            if (tagId == null)
                throw new ApiException(400, "Missing required parameter 'tagId' when calling TagManagementApi->UpdateTagUsingPUT");
            // verify the required parameter 'tagDto' is set
            if (tagDto == null)
                throw new ApiException(400, "Missing required parameter 'tagDto' when calling TagManagementApi->UpdateTagUsingPUT");

            var localVarPath = "/api/v1/tag/{tagId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tagId != null) localVarPathParams.Add("tagId", Configuration.ApiClient.ParameterToString(tagId)); // path parameter
            if (tagDto != null && tagDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tagDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tagDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateTagUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTagDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTagDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTagDto)));
            
        }

        /// <summary>
        /// Update a single tag Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>Task of BaseResponseOfTagDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTagDto> UpdateTagUsingPUTAsync (string tagId, TagDto tagDto)
        {
             ApiResponse<BaseResponseOfTagDto> localVarResponse = await UpdateTagUsingPUTAsyncWithHttpInfo(tagId, tagDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Update a single tag Updates the tag that matches the provided ID with the details provided in the body. Ignores the provided key, as keys are immutable once set. There is a limit of 300 values for a tag. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tagId">The unique identifier of the tag</param>
        /// <param name="tagDto">The representation of the tag to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTagDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTagDto>> UpdateTagUsingPUTAsyncWithHttpInfo (string tagId, TagDto tagDto)
        {
            // verify the required parameter 'tagId' is set
            if (tagId == null)
                throw new ApiException(400, "Missing required parameter 'tagId' when calling TagManagementApi->UpdateTagUsingPUT");
            // verify the required parameter 'tagDto' is set
            if (tagDto == null)
                throw new ApiException(400, "Missing required parameter 'tagDto' when calling TagManagementApi->UpdateTagUsingPUT");

            var localVarPath = "/api/v1/tag/{tagId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tagId != null) localVarPathParams.Add("tagId", Configuration.ApiClient.ParameterToString(tagId)); // path parameter
            if (tagDto != null && tagDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tagDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tagDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.PUT, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("UpdateTagUsingPUT", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTagDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTagDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTagDto)));
            
        }

    }
}
