/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface ITokenManagementApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Create a new token
        /// </summary>
        /// <remarks>
        /// Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>BaseResponseOfTokenDto</returns>
        BaseResponseOfTokenDto CreateTokenUsingPOST (TokenDto tokenDto);

        /// <summary>
        /// Create a new token
        /// </summary>
        /// <remarks>
        /// Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>ApiResponse of BaseResponseOfTokenDto</returns>
        ApiResponse<BaseResponseOfTokenDto> CreateTokenUsingPOSTWithHttpInfo (TokenDto tokenDto);
        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>byte[]</returns>
        byte[] DownloadFileUsingGET1 (string tokenId, string filename = null);

        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>ApiResponse of byte[]</returns>
        ApiResponse<byte[]> DownloadFileUsingGET1WithHttpInfo (string tokenId, string filename = null);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Create a new token
        /// </summary>
        /// <remarks>
        /// Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>Task of BaseResponseOfTokenDto</returns>
        System.Threading.Tasks.Task<BaseResponseOfTokenDto> CreateTokenUsingPOSTAsync (TokenDto tokenDto);

        /// <summary>
        /// Create a new token
        /// </summary>
        /// <remarks>
        /// Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTokenDto)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTokenDto>> CreateTokenUsingPOSTAsyncWithHttpInfo (TokenDto tokenDto);
        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>Task of byte[]</returns>
        System.Threading.Tasks.Task<byte[]> DownloadFileUsingGET1Async (string tokenId, string filename = null);

        /// <summary>
        /// Download a single file
        /// </summary>
        /// <remarks>
        /// Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadFileUsingGET1AsyncWithHttpInfo (string tokenId, string filename = null);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class TokenManagementApi : ITokenManagementApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="TokenManagementApi"/> class.
        /// </summary>
        /// <returns></returns>
        public TokenManagementApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="TokenManagementApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public TokenManagementApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Create a new token Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>BaseResponseOfTokenDto</returns>
        public BaseResponseOfTokenDto CreateTokenUsingPOST (TokenDto tokenDto)
        {
             ApiResponse<BaseResponseOfTokenDto> localVarResponse = CreateTokenUsingPOSTWithHttpInfo(tokenDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Create a new token Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>ApiResponse of BaseResponseOfTokenDto</returns>
        public ApiResponse< BaseResponseOfTokenDto > CreateTokenUsingPOSTWithHttpInfo (TokenDto tokenDto)
        {
            // verify the required parameter 'tokenDto' is set
            if (tokenDto == null)
                throw new ApiException(400, "Missing required parameter 'tokenDto' when calling TokenManagementApi->CreateTokenUsingPOST");

            var localVarPath = "/api/v1/token";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tokenDto != null && tokenDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tokenDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tokenDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateTokenUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTokenDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTokenDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTokenDto)));
            
        }

        /// <summary>
        /// Create a new token Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>Task of BaseResponseOfTokenDto</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfTokenDto> CreateTokenUsingPOSTAsync (TokenDto tokenDto)
        {
             ApiResponse<BaseResponseOfTokenDto> localVarResponse = await CreateTokenUsingPOSTAsyncWithHttpInfo(tokenDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Create a new token Creates a temporary token—valid for only a short period of time—to download a table dataset file or query result, given its ID.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenDto">The representation of the token to update</param>
        /// <returns>Task of ApiResponse (BaseResponseOfTokenDto)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfTokenDto>> CreateTokenUsingPOSTAsyncWithHttpInfo (TokenDto tokenDto)
        {
            // verify the required parameter 'tokenDto' is set
            if (tokenDto == null)
                throw new ApiException(400, "Missing required parameter 'tokenDto' when calling TokenManagementApi->CreateTokenUsingPOST");

            var localVarPath = "/api/v1/token";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tokenDto != null && tokenDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(tokenDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = tokenDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("CreateTokenUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfTokenDto>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfTokenDto) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfTokenDto)));
            
        }

        /// <summary>
        /// Download a single file Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>byte[]</returns>
        public byte[] DownloadFileUsingGET1 (string tokenId, string filename = null)
        {
             ApiResponse<byte[]> localVarResponse = DownloadFileUsingGET1WithHttpInfo(tokenId, filename);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Download a single file Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>ApiResponse of byte[]</returns>
        public ApiResponse< byte[] > DownloadFileUsingGET1WithHttpInfo (string tokenId, string filename = null)
        {
            // verify the required parameter 'tokenId' is set
            if (tokenId == null)
                throw new ApiException(400, "Missing required parameter 'tokenId' when calling TokenManagementApi->DownloadFileUsingGET1");

            var localVarPath = "/api/v1/token/{tokenId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tokenId != null) localVarPathParams.Add("tokenId", Configuration.ApiClient.ParameterToString(tokenId)); // path parameter
            if (filename != null) localVarQueryParams.Add("filename", Configuration.ApiClient.ParameterToString(filename)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadFileUsingGET1", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

        /// <summary>
        /// Download a single file Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>Task of byte[]</returns>
        public async System.Threading.Tasks.Task<byte[]> DownloadFileUsingGET1Async (string tokenId, string filename = null)
        {
             ApiResponse<byte[]> localVarResponse = await DownloadFileUsingGET1AsyncWithHttpInfo(tokenId, filename);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Download a single file Downloads a table dataset or query result as a file, given its token from the [&#x60;Create a new token endpoint&#x60;](ref:wdata-createtokenusingpost). If no matching entity is found, returns a 404.
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="tokenId">The unique identifier of the token</param>
        /// <param name="filename">A filename for the download; if included, the default filename is overridden (optional)</param>
        /// <returns>Task of ApiResponse (byte[])</returns>
        public async System.Threading.Tasks.Task<ApiResponse<byte[]>> DownloadFileUsingGET1AsyncWithHttpInfo (string tokenId, string filename = null)
        {
            // verify the required parameter 'tokenId' is set
            if (tokenId == null)
                throw new ApiException(400, "Missing required parameter 'tokenId' when calling TokenManagementApi->DownloadFileUsingGET1");

            var localVarPath = "/api/v1/token/{tokenId}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "*_/_*"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (tokenId != null) localVarPathParams.Add("tokenId", Configuration.ApiClient.ParameterToString(tokenId)); // path parameter
            if (filename != null) localVarQueryParams.Add("filename", Configuration.ApiClient.ParameterToString(filename)); // query parameter

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("DownloadFileUsingGET1", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<byte[]>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (byte[]) Configuration.ApiClient.Deserialize(localVarResponse, typeof(byte[])));
            
        }

    }
}
