/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IUtilitiesApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Parse a date
        /// </summary>
        /// <remarks>
        /// Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>BaseResponseOfstring</returns>
        BaseResponseOfstring ParseDateUsingPOST (DatetimeDto datetimeDto);

        /// <summary>
        /// Parse a date
        /// </summary>
        /// <remarks>
        /// Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        ApiResponse<BaseResponseOfstring> ParseDateUsingPOSTWithHttpInfo (DatetimeDto datetimeDto);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Parse a date
        /// </summary>
        /// <remarks>
        /// Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        System.Threading.Tasks.Task<BaseResponseOfstring> ParseDateUsingPOSTAsync (DatetimeDto datetimeDto);

        /// <summary>
        /// Parse a date
        /// </summary>
        /// <remarks>
        /// Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ParseDateUsingPOSTAsyncWithHttpInfo (DatetimeDto datetimeDto);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public partial class UtilitiesApi : IUtilitiesApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="UtilitiesApi"/> class.
        /// </summary>
        /// <returns></returns>
        public UtilitiesApi(String basePath)
        {
            this.Configuration = new Configuration(new ApiClient(basePath));

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="UtilitiesApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public UtilitiesApi(Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;

            // ensure API client has configuration ready
            if (Configuration.ApiClient.Configuration == null)
            {
                this.Configuration.ApiClient.Configuration = this.Configuration;
            }
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public Dictionary<String, String> DefaultHeader()
        {
            return this.Configuration.DefaultHeader;
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Parse a date Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>BaseResponseOfstring</returns>
        public BaseResponseOfstring ParseDateUsingPOST (DatetimeDto datetimeDto)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = ParseDateUsingPOSTWithHttpInfo(datetimeDto);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Parse a date Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>ApiResponse of BaseResponseOfstring</returns>
        public ApiResponse< BaseResponseOfstring > ParseDateUsingPOSTWithHttpInfo (DatetimeDto datetimeDto)
        {
            // verify the required parameter 'datetimeDto' is set
            if (datetimeDto == null)
                throw new ApiException(400, "Missing required parameter 'datetimeDto' when calling UtilitiesApi->ParseDateUsingPOST");

            var localVarPath = "/api/v1/util/datetime";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (datetimeDto != null && datetimeDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(datetimeDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = datetimeDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) Configuration.ApiClient.CallApi(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ParseDateUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

        /// <summary>
        /// Parse a date Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>Task of BaseResponseOfstring</returns>
        public async System.Threading.Tasks.Task<BaseResponseOfstring> ParseDateUsingPOSTAsync (DatetimeDto datetimeDto)
        {
             ApiResponse<BaseResponseOfstring> localVarResponse = await ParseDateUsingPOSTAsyncWithHttpInfo(datetimeDto);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Parse a date Provides a simple endpoint to check whether a given date candidate parses with the provided format string.  Both the date candidate and format strings are required. Returns a 200 if the date parses, or a 400 with a message if not. If the date parses, the provided format can be provided as column metadata, and the imported values parse correctly. The format string is java DateTimeFormatter style e.g. dateFormat &#x3D; \&quot;MM/dd/yyyy\&quot; and candidate &#x3D; \&quot;07/28/1987\&quot;
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="datetimeDto">The representation of the datetime object to parse</param>
        /// <returns>Task of ApiResponse (BaseResponseOfstring)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<BaseResponseOfstring>> ParseDateUsingPOSTAsyncWithHttpInfo (DatetimeDto datetimeDto)
        {
            // verify the required parameter 'datetimeDto' is set
            if (datetimeDto == null)
                throw new ApiException(400, "Missing required parameter 'datetimeDto' when calling UtilitiesApi->ParseDateUsingPOST");

            var localVarPath = "/api/v1/util/datetime";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new Dictionary<String, String>();
            var localVarHeaderParams = new Dictionary<String, String>(Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
                "application/json"
            };
            String localVarHttpContentType = Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            // set "format" to json by default
            // e.g. /pet/{petId}.{format} becomes /pet/{petId}.json
            localVarPathParams.Add("format", "json");
            if (datetimeDto != null && datetimeDto.GetType() != typeof(byte[]))
            {
                localVarPostBody = Configuration.ApiClient.Serialize(datetimeDto); // http body (model) parameter
            }
            else
            {
                localVarPostBody = datetimeDto; // byte array
            }

            // authentication (oauth) required
            // oauth required
            if (!String.IsNullOrEmpty(Configuration.AccessToken))
            {
                localVarHeaderParams["Authorization"] = "Bearer " + Configuration.AccessToken;
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.POST, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("ParseDateUsingPOST", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<BaseResponseOfstring>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => x.Value.ToString()),
                (BaseResponseOfstring) Configuration.ApiClient.Deserialize(localVarResponse, typeof(BaseResponseOfstring)));
            
        }

    }
}
