/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// ConnectionRunDto
    /// </summary>
    [DataContract]
    public partial class ConnectionRunDto :  IEquatable<ConnectionRunDto>
    {
        /// <summary>
        /// The run status of the destination
        /// </summary>
        /// <value>The run status of the destination</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum DestinationStatusEnum
        {
            
            /// <summary>
            /// Enum Notstarted for "not_started"
            /// </summary>
            [EnumMember(Value = "not_started")]
            Notstarted,
            
            /// <summary>
            /// Enum Running for "running"
            /// </summary>
            [EnumMember(Value = "running")]
            Running,
            
            /// <summary>
            /// Enum Complete for "complete"
            /// </summary>
            [EnumMember(Value = "complete")]
            Complete,
            
            /// <summary>
            /// Enum Error for "error"
            /// </summary>
            [EnumMember(Value = "error")]
            Error,
            
            /// <summary>
            /// Enum Cancelled for "cancelled"
            /// </summary>
            [EnumMember(Value = "cancelled")]
            Cancelled
        }

        /// <summary>
        /// The run status of the source
        /// </summary>
        /// <value>The run status of the source</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum SourceStatusEnum
        {
            
            /// <summary>
            /// Enum Notstarted for "not_started"
            /// </summary>
            [EnumMember(Value = "not_started")]
            Notstarted,
            
            /// <summary>
            /// Enum Running for "running"
            /// </summary>
            [EnumMember(Value = "running")]
            Running,
            
            /// <summary>
            /// Enum Complete for "complete"
            /// </summary>
            [EnumMember(Value = "complete")]
            Complete,
            
            /// <summary>
            /// Enum Error for "error"
            /// </summary>
            [EnumMember(Value = "error")]
            Error,
            
            /// <summary>
            /// Enum Cancelled for "cancelled"
            /// </summary>
            [EnumMember(Value = "cancelled")]
            Cancelled
        }

        /// <summary>
        /// The run status of the destination
        /// </summary>
        /// <value>The run status of the destination</value>
        [DataMember(Name="destinationStatus", EmitDefaultValue=false)]
        public DestinationStatusEnum? DestinationStatus { get; set; }
        /// <summary>
        /// The run status of the source
        /// </summary>
        /// <value>The run status of the source</value>
        [DataMember(Name="sourceStatus", EmitDefaultValue=false)]
        public SourceStatusEnum? SourceStatus { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="ConnectionRunDto" /> class.
        /// </summary>
        /// <param name="DestinationParameters">Any parameters provided to the destination.</param>
        /// <param name="SourceParameters">Any parameters provided to the source.</param>
        public ConnectionRunDto(Object DestinationParameters = null, Object SourceParameters = null)
        {
            this.DestinationParameters = DestinationParameters;
            this.SourceParameters = SourceParameters;
        }
        
        /// <summary>
        /// The unique ID of the connection
        /// </summary>
        /// <value>The unique ID of the connection</value>
        [DataMember(Name="connectionId", EmitDefaultValue=false)]
        public string ConnectionId { get; private set; }
        /// <summary>
        /// When the connection was created, as a datetime
        /// </summary>
        /// <value>When the connection was created, as a datetime</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The ID of the user that created the connection
        /// </summary>
        /// <value>The ID of the user that created the connection</value>
        [DataMember(Name="createdBy", EmitDefaultValue=false)]
        public string CreatedBy { get; private set; }
        /// <summary>
        /// Any parameters provided to the destination
        /// </summary>
        /// <value>Any parameters provided to the destination</value>
        [DataMember(Name="destinationParameters", EmitDefaultValue=false)]
        public Object DestinationParameters { get; set; }
        /// <summary>
        /// The workspace of the the run destination
        /// </summary>
        /// <value>The workspace of the the run destination</value>
        [DataMember(Name="destinationWorkspaceId", EmitDefaultValue=false)]
        public string DestinationWorkspaceId { get; private set; }
        /// <summary>
        /// An error, if encountered, while initiating the job
        /// </summary>
        /// <value>An error, if encountered, while initiating the job</value>
        [DataMember(Name="error", EmitDefaultValue=false)]
        public string Error { get; private set; }
        /// <summary>
        /// The unique ID of the job
        /// </summary>
        /// <value>The unique ID of the job</value>
        [DataMember(Name="jobId", EmitDefaultValue=false)]
        public string JobId { get; private set; }
        /// <summary>
        /// Any parameters provided to the source
        /// </summary>
        /// <value>Any parameters provided to the source</value>
        [DataMember(Name="sourceParameters", EmitDefaultValue=false)]
        public Object SourceParameters { get; set; }
        /// <summary>
        /// The workspace of the run source
        /// </summary>
        /// <value>The workspace of the run source</value>
        [DataMember(Name="sourceWorkspaceId", EmitDefaultValue=false)]
        public string SourceWorkspaceId { get; private set; }
        /// <summary>
        /// When the connection was updated, as a datetime
        /// </summary>
        /// <value>When the connection was updated, as a datetime</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The workspace id for this connection
        /// </summary>
        /// <value>The workspace id for this connection</value>
        [DataMember(Name="workspaceId", EmitDefaultValue=false)]
        public string WorkspaceId { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class ConnectionRunDto {\n");
            sb.Append("  ConnectionId: ").Append(ConnectionId).Append("\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  CreatedBy: ").Append(CreatedBy).Append("\n");
            sb.Append("  DestinationParameters: ").Append(DestinationParameters).Append("\n");
            sb.Append("  DestinationStatus: ").Append(DestinationStatus).Append("\n");
            sb.Append("  DestinationWorkspaceId: ").Append(DestinationWorkspaceId).Append("\n");
            sb.Append("  Error: ").Append(Error).Append("\n");
            sb.Append("  JobId: ").Append(JobId).Append("\n");
            sb.Append("  SourceParameters: ").Append(SourceParameters).Append("\n");
            sb.Append("  SourceStatus: ").Append(SourceStatus).Append("\n");
            sb.Append("  SourceWorkspaceId: ").Append(SourceWorkspaceId).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  WorkspaceId: ").Append(WorkspaceId).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as ConnectionRunDto);
        }

        /// <summary>
        /// Returns true if ConnectionRunDto instances are equal
        /// </summary>
        /// <param name="other">Instance of ConnectionRunDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(ConnectionRunDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.ConnectionId == other.ConnectionId ||
                    this.ConnectionId != null &&
                    this.ConnectionId.Equals(other.ConnectionId)
                ) && 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.CreatedBy == other.CreatedBy ||
                    this.CreatedBy != null &&
                    this.CreatedBy.Equals(other.CreatedBy)
                ) && 
                (
                    this.DestinationParameters == other.DestinationParameters ||
                    this.DestinationParameters != null &&
                    this.DestinationParameters.Equals(other.DestinationParameters)
                ) && 
                (
                    this.DestinationStatus == other.DestinationStatus ||
                    this.DestinationStatus != null &&
                    this.DestinationStatus.Equals(other.DestinationStatus)
                ) && 
                (
                    this.DestinationWorkspaceId == other.DestinationWorkspaceId ||
                    this.DestinationWorkspaceId != null &&
                    this.DestinationWorkspaceId.Equals(other.DestinationWorkspaceId)
                ) && 
                (
                    this.Error == other.Error ||
                    this.Error != null &&
                    this.Error.Equals(other.Error)
                ) && 
                (
                    this.JobId == other.JobId ||
                    this.JobId != null &&
                    this.JobId.Equals(other.JobId)
                ) && 
                (
                    this.SourceParameters == other.SourceParameters ||
                    this.SourceParameters != null &&
                    this.SourceParameters.Equals(other.SourceParameters)
                ) && 
                (
                    this.SourceStatus == other.SourceStatus ||
                    this.SourceStatus != null &&
                    this.SourceStatus.Equals(other.SourceStatus)
                ) && 
                (
                    this.SourceWorkspaceId == other.SourceWorkspaceId ||
                    this.SourceWorkspaceId != null &&
                    this.SourceWorkspaceId.Equals(other.SourceWorkspaceId)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.WorkspaceId == other.WorkspaceId ||
                    this.WorkspaceId != null &&
                    this.WorkspaceId.Equals(other.WorkspaceId)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.ConnectionId != null)
                    hash = hash * 59 + this.ConnectionId.GetHashCode();
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.CreatedBy != null)
                    hash = hash * 59 + this.CreatedBy.GetHashCode();
                if (this.DestinationParameters != null)
                    hash = hash * 59 + this.DestinationParameters.GetHashCode();
                if (this.DestinationStatus != null)
                    hash = hash * 59 + this.DestinationStatus.GetHashCode();
                if (this.DestinationWorkspaceId != null)
                    hash = hash * 59 + this.DestinationWorkspaceId.GetHashCode();
                if (this.Error != null)
                    hash = hash * 59 + this.Error.GetHashCode();
                if (this.JobId != null)
                    hash = hash * 59 + this.JobId.GetHashCode();
                if (this.SourceParameters != null)
                    hash = hash * 59 + this.SourceParameters.GetHashCode();
                if (this.SourceStatus != null)
                    hash = hash * 59 + this.SourceStatus.GetHashCode();
                if (this.SourceWorkspaceId != null)
                    hash = hash * 59 + this.SourceWorkspaceId.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.WorkspaceId != null)
                    hash = hash * 59 + this.WorkspaceId.GetHashCode();
                return hash;
            }
        }
    }

}
