/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// FileMetaDto
    /// </summary>
    [DataContract]
    public partial class FileMetaDto :  IEquatable<FileMetaDto>
    {
        /// <summary>
        /// The files's current status
        /// </summary>
        /// <value>The files's current status</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum StatusEnum
        {
            
            /// <summary>
            /// Enum STAGING for "STAGING"
            /// </summary>
            [EnumMember(Value = "STAGING")]
            STAGING,
            
            /// <summary>
            /// Enum STAGED for "STAGED"
            /// </summary>
            [EnumMember(Value = "STAGED")]
            STAGED,
            
            /// <summary>
            /// Enum IMPORTING for "IMPORTING"
            /// </summary>
            [EnumMember(Value = "IMPORTING")]
            IMPORTING,
            
            /// <summary>
            /// Enum IMPORTED for "IMPORTED"
            /// </summary>
            [EnumMember(Value = "IMPORTED")]
            IMPORTED,
            
            /// <summary>
            /// Enum ERROR for "ERROR"
            /// </summary>
            [EnumMember(Value = "ERROR")]
            ERROR
        }

        /// <summary>
        /// The files's current status
        /// </summary>
        /// <value>The files's current status</value>
        [DataMember(Name="status", EmitDefaultValue=false)]
        public StatusEnum? Status { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="FileMetaDto" /> class.
        /// </summary>
        /// <param name="ColumnMappings">Maps the columns in the physical file (CSV or JSON) to the columns in fact table &#x3D; {\&quot;physical_col1\&quot;:\&quot;table_col1\&quot;, \&quot;physical_col2\&quot;:\&quot;table_col2\&quot;}.</param>
        /// <param name="Metadata">The file&#39;s meta data.</param>
        /// <param name="Tags">The tags associated with the file.</param>
        public FileMetaDto(Dictionary<string, string> ColumnMappings = null, Dictionary<string, Dictionary<string, Object>> Metadata = null, Dictionary<string, string> Tags = null)
        {
            this.ColumnMappings = ColumnMappings;
            this.Metadata = Metadata;
            this.Tags = Tags;
        }
        
        /// <summary>
        /// Maps the columns in the physical file (CSV or JSON) to the columns in fact table &#x3D; {\&quot;physical_col1\&quot;:\&quot;table_col1\&quot;, \&quot;physical_col2\&quot;:\&quot;table_col2\&quot;}
        /// </summary>
        /// <value>Maps the columns in the physical file (CSV or JSON) to the columns in fact table &#x3D; {\&quot;physical_col1\&quot;:\&quot;table_col1\&quot;, \&quot;physical_col2\&quot;:\&quot;table_col2\&quot;}</value>
        [DataMember(Name="columnMappings", EmitDefaultValue=false)]
        public Dictionary<string, string> ColumnMappings { get; set; }
        /// <summary>
        /// When the entity was created
        /// </summary>
        /// <value>When the entity was created</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The character to use as a delimiter within the file to separate one field from another.  The default is comma
        /// </summary>
        /// <value>The character to use as a delimiter within the file to separate one field from another.  The default is comma</value>
        [DataMember(Name="delimiter", EmitDefaultValue=false)]
        public string Delimiter { get; private set; }
        /// <summary>
        /// The entity&#39;s unique identifier
        /// </summary>
        /// <value>The entity&#39;s unique identifier</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; private set; }
        /// <summary>
        /// The key is here for backwards compatibility only and will always be an empty string.
        /// </summary>
        /// <value>The key is here for backwards compatibility only and will always be an empty string.</value>
        [DataMember(Name="key", EmitDefaultValue=false)]
        public string Key { get; private set; }
        /// <summary>
        /// The file&#39;s meta data
        /// </summary>
        /// <value>The file&#39;s meta data</value>
        [DataMember(Name="metadata", EmitDefaultValue=false)]
        public Dictionary<string, Dictionary<string, Object>> Metadata { get; set; }
        /// <summary>
        /// The name of the file
        /// </summary>
        /// <value>The name of the file</value>
        [DataMember(Name="name", EmitDefaultValue=false)]
        public string Name { get; private set; }
        /// <summary>
        /// Number of errors found in the file
        /// </summary>
        /// <value>Number of errors found in the file</value>
        [DataMember(Name="numErrors", EmitDefaultValue=false)]
        public long? NumErrors { get; private set; }
        /// <summary>
        /// Number of records imported from this file.  This will only be non-zero if the file is in the IMPORTED status.
        /// </summary>
        /// <value>Number of records imported from this file.  This will only be non-zero if the file is in the IMPORTED status.</value>
        [DataMember(Name="numRecords", EmitDefaultValue=false)]
        public long? NumRecords { get; private set; }
        /// <summary>
        /// Size of the original file that was uploaded.
        /// </summary>
        /// <value>Size of the original file that was uploaded.</value>
        [DataMember(Name="originalFileSize", EmitDefaultValue=false)]
        public long? OriginalFileSize { get; private set; }
        /// <summary>
        /// URI that describes the source location of this file if imported from another system. For instance, this will have a spreadsheet URL if this file was imported from spreadsheets. This will be null if the file was uploaded using the data prep API.
        /// </summary>
        /// <value>URI that describes the source location of this file if imported from another system. For instance, this will have a spreadsheet URL if this file was imported from spreadsheets. This will be null if the file was uploaded using the data prep API.</value>
        [DataMember(Name="source", EmitDefaultValue=false)]
        public string Source { get; private set; }
        /// <summary>
        /// The unique identifier for the table
        /// </summary>
        /// <value>The unique identifier for the table</value>
        [DataMember(Name="tableId", EmitDefaultValue=false)]
        public string TableId { get; private set; }
        /// <summary>
        /// The tags associated with the file
        /// </summary>
        /// <value>The tags associated with the file</value>
        [DataMember(Name="tags", EmitDefaultValue=false)]
        public Dictionary<string, string> Tags { get; set; }
        /// <summary>
        /// When the entity was last updated
        /// </summary>
        /// <value>When the entity was last updated</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The owner of the entity
        /// </summary>
        /// <value>The owner of the entity</value>
        [DataMember(Name="userId", EmitDefaultValue=false)]
        public string UserId { get; private set; }
        /// <summary>
        /// The version of the current representation of the entity
        /// </summary>
        /// <value>The version of the current representation of the entity</value>
        [DataMember(Name="version", EmitDefaultValue=false)]
        public long? Version { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class FileMetaDto {\n");
            sb.Append("  ColumnMappings: ").Append(ColumnMappings).Append("\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  Delimiter: ").Append(Delimiter).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  Key: ").Append(Key).Append("\n");
            sb.Append("  Metadata: ").Append(Metadata).Append("\n");
            sb.Append("  Name: ").Append(Name).Append("\n");
            sb.Append("  NumErrors: ").Append(NumErrors).Append("\n");
            sb.Append("  NumRecords: ").Append(NumRecords).Append("\n");
            sb.Append("  OriginalFileSize: ").Append(OriginalFileSize).Append("\n");
            sb.Append("  Source: ").Append(Source).Append("\n");
            sb.Append("  Status: ").Append(Status).Append("\n");
            sb.Append("  TableId: ").Append(TableId).Append("\n");
            sb.Append("  Tags: ").Append(Tags).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  UserId: ").Append(UserId).Append("\n");
            sb.Append("  Version: ").Append(Version).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as FileMetaDto);
        }

        /// <summary>
        /// Returns true if FileMetaDto instances are equal
        /// </summary>
        /// <param name="other">Instance of FileMetaDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(FileMetaDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.ColumnMappings == other.ColumnMappings ||
                    this.ColumnMappings != null &&
                    this.ColumnMappings.SequenceEqual(other.ColumnMappings)
                ) && 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.Delimiter == other.Delimiter ||
                    this.Delimiter != null &&
                    this.Delimiter.Equals(other.Delimiter)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.Key == other.Key ||
                    this.Key != null &&
                    this.Key.Equals(other.Key)
                ) && 
                (
                    this.Metadata == other.Metadata ||
                    this.Metadata != null &&
                    this.Metadata.SequenceEqual(other.Metadata)
                ) && 
                (
                    this.Name == other.Name ||
                    this.Name != null &&
                    this.Name.Equals(other.Name)
                ) && 
                (
                    this.NumErrors == other.NumErrors ||
                    this.NumErrors != null &&
                    this.NumErrors.Equals(other.NumErrors)
                ) && 
                (
                    this.NumRecords == other.NumRecords ||
                    this.NumRecords != null &&
                    this.NumRecords.Equals(other.NumRecords)
                ) && 
                (
                    this.OriginalFileSize == other.OriginalFileSize ||
                    this.OriginalFileSize != null &&
                    this.OriginalFileSize.Equals(other.OriginalFileSize)
                ) && 
                (
                    this.Source == other.Source ||
                    this.Source != null &&
                    this.Source.Equals(other.Source)
                ) && 
                (
                    this.Status == other.Status ||
                    this.Status != null &&
                    this.Status.Equals(other.Status)
                ) && 
                (
                    this.TableId == other.TableId ||
                    this.TableId != null &&
                    this.TableId.Equals(other.TableId)
                ) && 
                (
                    this.Tags == other.Tags ||
                    this.Tags != null &&
                    this.Tags.SequenceEqual(other.Tags)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.UserId == other.UserId ||
                    this.UserId != null &&
                    this.UserId.Equals(other.UserId)
                ) && 
                (
                    this.Version == other.Version ||
                    this.Version != null &&
                    this.Version.Equals(other.Version)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.ColumnMappings != null)
                    hash = hash * 59 + this.ColumnMappings.GetHashCode();
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.Delimiter != null)
                    hash = hash * 59 + this.Delimiter.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.Key != null)
                    hash = hash * 59 + this.Key.GetHashCode();
                if (this.Metadata != null)
                    hash = hash * 59 + this.Metadata.GetHashCode();
                if (this.Name != null)
                    hash = hash * 59 + this.Name.GetHashCode();
                if (this.NumErrors != null)
                    hash = hash * 59 + this.NumErrors.GetHashCode();
                if (this.NumRecords != null)
                    hash = hash * 59 + this.NumRecords.GetHashCode();
                if (this.OriginalFileSize != null)
                    hash = hash * 59 + this.OriginalFileSize.GetHashCode();
                if (this.Source != null)
                    hash = hash * 59 + this.Source.GetHashCode();
                if (this.Status != null)
                    hash = hash * 59 + this.Status.GetHashCode();
                if (this.TableId != null)
                    hash = hash * 59 + this.TableId.GetHashCode();
                if (this.Tags != null)
                    hash = hash * 59 + this.Tags.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.UserId != null)
                    hash = hash * 59 + this.UserId.GetHashCode();
                if (this.Version != null)
                    hash = hash * 59 + this.Version.GetHashCode();
                return hash;
            }
        }
    }

}
