/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// FolderableDto
    /// </summary>
    [DataContract]
    public partial class FolderableDto :  IEquatable<FolderableDto>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="FolderableDto" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected FolderableDto() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="FolderableDto" /> class.
        /// </summary>
        /// <param name="Id">The UUID unique identifier for the entity. (required).</param>
        /// <param name="Metadata">Contains additional metadata about the entity returned. For example, a table entity might have a type attribute..</param>
        /// <param name="Type">The numerical identifier for the entity&#39;s type:  Query&#x3D;100, Table&#x3D;200, Pivot View&#x3D;500, Folder&#x3D;600, Shared Table&#x3D;700 (required).</param>
        public FolderableDto(string Id = null, Object Metadata = null, int? Type = null)
        {
            // to ensure "Id" is required (not null)
            if (Id == null)
            {
                throw new InvalidDataException("Id is a required property for FolderableDto and cannot be null");
            }
            else
            {
                this.Id = Id;
            }
            // to ensure "Type" is required (not null)
            if (Type == null)
            {
                throw new InvalidDataException("Type is a required property for FolderableDto and cannot be null");
            }
            else
            {
                this.Type = Type;
            }
            this.Metadata = Metadata;
        }
        
        /// <summary>
        /// When the entity was created
        /// </summary>
        /// <value>When the entity was created</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// A description of the folderable entity
        /// </summary>
        /// <value>A description of the folderable entity</value>
        [DataMember(Name="description", EmitDefaultValue=false)]
        public string Description { get; private set; }
        /// <summary>
        /// The UUID unique identifier for the entity.
        /// </summary>
        /// <value>The UUID unique identifier for the entity.</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; set; }
        /// <summary>
        /// Contains additional metadata about the entity returned. For example, a table entity might have a type attribute.
        /// </summary>
        /// <value>Contains additional metadata about the entity returned. For example, a table entity might have a type attribute.</value>
        [DataMember(Name="metadata", EmitDefaultValue=false)]
        public Object Metadata { get; set; }
        /// <summary>
        /// When a significant event happened on the data object.  For example, for queries, this is when the last run occurred; for tables, this is when the last upload occurred.
        /// </summary>
        /// <value>When a significant event happened on the data object.  For example, for queries, this is when the last run occurred; for tables, this is when the last upload occurred.</value>
        [DataMember(Name="modified", EmitDefaultValue=false)]
        public DateTime? Modified { get; private set; }
        /// <summary>
        /// The identifier of the user who last modified the entity
        /// </summary>
        /// <value>The identifier of the user who last modified the entity</value>
        [DataMember(Name="modifiedBy", EmitDefaultValue=false)]
        public string ModifiedBy { get; private set; }
        /// <summary>
        /// The name of the folderable entity
        /// </summary>
        /// <value>The name of the folderable entity</value>
        [DataMember(Name="name", EmitDefaultValue=false)]
        public string Name { get; private set; }
        /// <summary>
        /// The ID of the folder to which this entity belongs. This can be null if the entity is not in a folder.
        /// </summary>
        /// <value>The ID of the folder to which this entity belongs. This can be null if the entity is not in a folder.</value>
        [DataMember(Name="parentId", EmitDefaultValue=false)]
        public string ParentId { get; private set; }
        /// <summary>
        /// The numerical identifier for the entity&#39;s type:  Query&#x3D;100, Table&#x3D;200, Pivot View&#x3D;500, Folder&#x3D;600, Shared Table&#x3D;700
        /// </summary>
        /// <value>The numerical identifier for the entity&#39;s type:  Query&#x3D;100, Table&#x3D;200, Pivot View&#x3D;500, Folder&#x3D;600, Shared Table&#x3D;700</value>
        [DataMember(Name="type", EmitDefaultValue=false)]
        public int? Type { get; set; }
        /// <summary>
        /// When the data object was last updated
        /// </summary>
        /// <value>When the data object was last updated</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The identifier of the user who last updated the entity
        /// </summary>
        /// <value>The identifier of the user who last updated the entity</value>
        [DataMember(Name="updatedBy", EmitDefaultValue=false)]
        public string UpdatedBy { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class FolderableDto {\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  Description: ").Append(Description).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  Metadata: ").Append(Metadata).Append("\n");
            sb.Append("  Modified: ").Append(Modified).Append("\n");
            sb.Append("  ModifiedBy: ").Append(ModifiedBy).Append("\n");
            sb.Append("  Name: ").Append(Name).Append("\n");
            sb.Append("  ParentId: ").Append(ParentId).Append("\n");
            sb.Append("  Type: ").Append(Type).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  UpdatedBy: ").Append(UpdatedBy).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as FolderableDto);
        }

        /// <summary>
        /// Returns true if FolderableDto instances are equal
        /// </summary>
        /// <param name="other">Instance of FolderableDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(FolderableDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.Description == other.Description ||
                    this.Description != null &&
                    this.Description.Equals(other.Description)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.Metadata == other.Metadata ||
                    this.Metadata != null &&
                    this.Metadata.Equals(other.Metadata)
                ) && 
                (
                    this.Modified == other.Modified ||
                    this.Modified != null &&
                    this.Modified.Equals(other.Modified)
                ) && 
                (
                    this.ModifiedBy == other.ModifiedBy ||
                    this.ModifiedBy != null &&
                    this.ModifiedBy.Equals(other.ModifiedBy)
                ) && 
                (
                    this.Name == other.Name ||
                    this.Name != null &&
                    this.Name.Equals(other.Name)
                ) && 
                (
                    this.ParentId == other.ParentId ||
                    this.ParentId != null &&
                    this.ParentId.Equals(other.ParentId)
                ) && 
                (
                    this.Type == other.Type ||
                    this.Type != null &&
                    this.Type.Equals(other.Type)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.UpdatedBy == other.UpdatedBy ||
                    this.UpdatedBy != null &&
                    this.UpdatedBy.Equals(other.UpdatedBy)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.Description != null)
                    hash = hash * 59 + this.Description.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.Metadata != null)
                    hash = hash * 59 + this.Metadata.GetHashCode();
                if (this.Modified != null)
                    hash = hash * 59 + this.Modified.GetHashCode();
                if (this.ModifiedBy != null)
                    hash = hash * 59 + this.ModifiedBy.GetHashCode();
                if (this.Name != null)
                    hash = hash * 59 + this.Name.GetHashCode();
                if (this.ParentId != null)
                    hash = hash * 59 + this.ParentId.GetHashCode();
                if (this.Type != null)
                    hash = hash * 59 + this.Type.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.UpdatedBy != null)
                    hash = hash * 59 + this.UpdatedBy.GetHashCode();
                return hash;
            }
        }
    }

}
