/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// GlobalParameterDto
    /// </summary>
    [DataContract]
    public partial class GlobalParameterDto :  IEquatable<GlobalParameterDto>
    {
        /// <summary>
        /// The mode of the parameter
        /// </summary>
        /// <value>The mode of the parameter</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum ModeEnum
        {
            
            /// <summary>
            /// Enum Scalar for "scalar"
            /// </summary>
            [EnumMember(Value = "scalar")]
            Scalar,
            
            /// <summary>
            /// Enum SingleSelect for "singleSelect"
            /// </summary>
            [EnumMember(Value = "singleSelect")]
            SingleSelect,
            
            /// <summary>
            /// Enum MultiSelect for "multiSelect"
            /// </summary>
            [EnumMember(Value = "multiSelect")]
            MultiSelect
        }

        /// <summary>
        /// The type of the parameter
        /// </summary>
        /// <value>The type of the parameter</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum TypeEnum
        {
            
            /// <summary>
            /// Enum String for "string"
            /// </summary>
            [EnumMember(Value = "string")]
            String,
            
            /// <summary>
            /// Enum Bytes for "bytes"
            /// </summary>
            [EnumMember(Value = "bytes")]
            Bytes,
            
            /// <summary>
            /// Enum Integer for "integer"
            /// </summary>
            [EnumMember(Value = "integer")]
            Integer,
            
            /// <summary>
            /// Enum Float for "float"
            /// </summary>
            [EnumMember(Value = "float")]
            Float,
            
            /// <summary>
            /// Enum Boolean for "boolean"
            /// </summary>
            [EnumMember(Value = "boolean")]
            Boolean,
            
            /// <summary>
            /// Enum Timestamp for "timestamp"
            /// </summary>
            [EnumMember(Value = "timestamp")]
            Timestamp,
            
            /// <summary>
            /// Enum Date for "date"
            /// </summary>
            [EnumMember(Value = "date")]
            Date,
            
            /// <summary>
            /// Enum Time for "time"
            /// </summary>
            [EnumMember(Value = "time")]
            Time,
            
            /// <summary>
            /// Enum Datetime for "datetime"
            /// </summary>
            [EnumMember(Value = "datetime")]
            Datetime,
            
            /// <summary>
            /// Enum Globalparameter for "global_parameter"
            /// </summary>
            [EnumMember(Value = "global_parameter")]
            Globalparameter,
            
            /// <summary>
            /// Enum Nestedqueryparameter for "nested_query_parameter"
            /// </summary>
            [EnumMember(Value = "nested_query_parameter")]
            Nestedqueryparameter
        }

        /// <summary>
        /// The mode of the parameter
        /// </summary>
        /// <value>The mode of the parameter</value>
        [DataMember(Name="mode", EmitDefaultValue=false)]
        public ModeEnum? Mode { get; set; }
        /// <summary>
        /// The type of the parameter
        /// </summary>
        /// <value>The type of the parameter</value>
        [DataMember(Name="type", EmitDefaultValue=false)]
        public TypeEnum? Type { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="GlobalParameterDto" /> class.
        /// </summary>
        /// <param name="Choices">If the parameter is of type select, this is a list of possible choices. This is read only and is for listing and viewing reports to help the user..</param>
        /// <param name="Description">The description of the parameter.</param>
        /// <param name="Label">The label for the query parameter.</param>
        /// <param name="Mode">The mode of the parameter.</param>
        /// <param name="Name">The name of the parameter.</param>
        /// <param name="Overridable">Denotes if this parameter can be overridden later in the process, either when the query is created or executed.  The default is true; it can be overridden..</param>
        /// <param name="SelectListId">If mode is select, this must be populated and is a reference to a select list from which choices will be derived..</param>
        /// <param name="Type">The type of the parameter.</param>
        /// <param name="Value">The default value of the parameter.</param>
        public GlobalParameterDto(List<Object> Choices = null, string Description = null, string Label = null, ModeEnum? Mode = null, string Name = null, bool? Overridable = null, string SelectListId = null, TypeEnum? Type = null, Object Value = null)
        {
            this.Choices = Choices;
            this.Description = Description;
            this.Label = Label;
            this.Mode = Mode;
            this.Name = Name;
            this.Overridable = Overridable;
            this.SelectListId = SelectListId;
            this.Type = Type;
            this.Value = Value;
        }
        
        /// <summary>
        /// If the parameter is of type select, this is a list of possible choices. This is read only and is for listing and viewing reports to help the user.
        /// </summary>
        /// <value>If the parameter is of type select, this is a list of possible choices. This is read only and is for listing and viewing reports to help the user.</value>
        [DataMember(Name="choices", EmitDefaultValue=false)]
        public List<Object> Choices { get; set; }
        /// <summary>
        /// When the entity was created
        /// </summary>
        /// <value>When the entity was created</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The unique identifier of the database where this parameter can be used to filter query results
        /// </summary>
        /// <value>The unique identifier of the database where this parameter can be used to filter query results</value>
        [DataMember(Name="databaseId", EmitDefaultValue=false)]
        public string DatabaseId { get; private set; }
        /// <summary>
        /// The description of the parameter
        /// </summary>
        /// <value>The description of the parameter</value>
        [DataMember(Name="description", EmitDefaultValue=false)]
        public string Description { get; set; }
        /// <summary>
        /// The entity&#39;s unique identifier
        /// </summary>
        /// <value>The entity&#39;s unique identifier</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; private set; }
        /// <summary>
        /// The label for the query parameter
        /// </summary>
        /// <value>The label for the query parameter</value>
        [DataMember(Name="label", EmitDefaultValue=false)]
        public string Label { get; set; }
        /// <summary>
        /// The name of the parameter
        /// </summary>
        /// <value>The name of the parameter</value>
        [DataMember(Name="name", EmitDefaultValue=false)]
        public string Name { get; set; }
        /// <summary>
        /// Denotes if this parameter can be overridden later in the process, either when the query is created or executed.  The default is true; it can be overridden.
        /// </summary>
        /// <value>Denotes if this parameter can be overridden later in the process, either when the query is created or executed.  The default is true; it can be overridden.</value>
        [DataMember(Name="overridable", EmitDefaultValue=false)]
        public bool? Overridable { get; set; }
        /// <summary>
        /// If mode is select, this must be populated and is a reference to a select list from which choices will be derived.
        /// </summary>
        /// <value>If mode is select, this must be populated and is a reference to a select list from which choices will be derived.</value>
        [DataMember(Name="selectListId", EmitDefaultValue=false)]
        public string SelectListId { get; set; }
        /// <summary>
        /// When the entity was last updated
        /// </summary>
        /// <value>When the entity was last updated</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The owner of the entity
        /// </summary>
        /// <value>The owner of the entity</value>
        [DataMember(Name="userId", EmitDefaultValue=false)]
        public string UserId { get; private set; }
        /// <summary>
        /// The default value of the parameter
        /// </summary>
        /// <value>The default value of the parameter</value>
        [DataMember(Name="value", EmitDefaultValue=false)]
        public Object Value { get; set; }
        /// <summary>
        /// The version of the current representation of the entity
        /// </summary>
        /// <value>The version of the current representation of the entity</value>
        [DataMember(Name="version", EmitDefaultValue=false)]
        public long? Version { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class GlobalParameterDto {\n");
            sb.Append("  Choices: ").Append(Choices).Append("\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  DatabaseId: ").Append(DatabaseId).Append("\n");
            sb.Append("  Description: ").Append(Description).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  Label: ").Append(Label).Append("\n");
            sb.Append("  Mode: ").Append(Mode).Append("\n");
            sb.Append("  Name: ").Append(Name).Append("\n");
            sb.Append("  Overridable: ").Append(Overridable).Append("\n");
            sb.Append("  SelectListId: ").Append(SelectListId).Append("\n");
            sb.Append("  Type: ").Append(Type).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  UserId: ").Append(UserId).Append("\n");
            sb.Append("  Value: ").Append(Value).Append("\n");
            sb.Append("  Version: ").Append(Version).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as GlobalParameterDto);
        }

        /// <summary>
        /// Returns true if GlobalParameterDto instances are equal
        /// </summary>
        /// <param name="other">Instance of GlobalParameterDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(GlobalParameterDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.Choices == other.Choices ||
                    this.Choices != null &&
                    this.Choices.SequenceEqual(other.Choices)
                ) && 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.DatabaseId == other.DatabaseId ||
                    this.DatabaseId != null &&
                    this.DatabaseId.Equals(other.DatabaseId)
                ) && 
                (
                    this.Description == other.Description ||
                    this.Description != null &&
                    this.Description.Equals(other.Description)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.Label == other.Label ||
                    this.Label != null &&
                    this.Label.Equals(other.Label)
                ) && 
                (
                    this.Mode == other.Mode ||
                    this.Mode != null &&
                    this.Mode.Equals(other.Mode)
                ) && 
                (
                    this.Name == other.Name ||
                    this.Name != null &&
                    this.Name.Equals(other.Name)
                ) && 
                (
                    this.Overridable == other.Overridable ||
                    this.Overridable != null &&
                    this.Overridable.Equals(other.Overridable)
                ) && 
                (
                    this.SelectListId == other.SelectListId ||
                    this.SelectListId != null &&
                    this.SelectListId.Equals(other.SelectListId)
                ) && 
                (
                    this.Type == other.Type ||
                    this.Type != null &&
                    this.Type.Equals(other.Type)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.UserId == other.UserId ||
                    this.UserId != null &&
                    this.UserId.Equals(other.UserId)
                ) && 
                (
                    this.Value == other.Value ||
                    this.Value != null &&
                    this.Value.Equals(other.Value)
                ) && 
                (
                    this.Version == other.Version ||
                    this.Version != null &&
                    this.Version.Equals(other.Version)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.Choices != null)
                    hash = hash * 59 + this.Choices.GetHashCode();
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.DatabaseId != null)
                    hash = hash * 59 + this.DatabaseId.GetHashCode();
                if (this.Description != null)
                    hash = hash * 59 + this.Description.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.Label != null)
                    hash = hash * 59 + this.Label.GetHashCode();
                if (this.Mode != null)
                    hash = hash * 59 + this.Mode.GetHashCode();
                if (this.Name != null)
                    hash = hash * 59 + this.Name.GetHashCode();
                if (this.Overridable != null)
                    hash = hash * 59 + this.Overridable.GetHashCode();
                if (this.SelectListId != null)
                    hash = hash * 59 + this.SelectListId.GetHashCode();
                if (this.Type != null)
                    hash = hash * 59 + this.Type.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.UserId != null)
                    hash = hash * 59 + this.UserId.GetHashCode();
                if (this.Value != null)
                    hash = hash * 59 + this.Value.GetHashCode();
                if (this.Version != null)
                    hash = hash * 59 + this.Version.GetHashCode();
                return hash;
            }
        }
    }

}
