/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// ImportDto
    /// </summary>
    [DataContract]
    public partial class ImportDto :  IEquatable<ImportDto>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ImportDto" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected ImportDto() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="ImportDto" /> class.
        /// </summary>
        /// <param name="ColumnMappings">a map of import column names to table column ids.</param>
        /// <param name="Delimiter">For overriding the file metadata&#39;s delimiter. The file delimiter is the character to use within the file to separate one field from another. If this value is not set, the import will use the file&#39;s set delimiter. If this value is set, the file metadata&#39;s delimiter will be updated on the file object..</param>
        /// <param name="FileId">id of the file to import to the table (required).</param>
        /// <param name="Metadata">For overriding column metadata specifically for this import. The keys in this object are column identifiers with the values being metadata objects..</param>
        /// <param name="Tags">an object containing keys and values, which becomes the tag map.</param>
        public ImportDto(Dictionary<string, string> ColumnMappings = null, string Delimiter = null, string FileId = null, Dictionary<string, Dictionary<string, Object>> Metadata = null, Dictionary<string, string> Tags = null)
        {
            // to ensure "FileId" is required (not null)
            if (FileId == null)
            {
                throw new InvalidDataException("FileId is a required property for ImportDto and cannot be null");
            }
            else
            {
                this.FileId = FileId;
            }
            this.ColumnMappings = ColumnMappings;
            this.Delimiter = Delimiter;
            this.Metadata = Metadata;
            this.Tags = Tags;
        }
        
        /// <summary>
        /// a map of import column names to table column ids
        /// </summary>
        /// <value>a map of import column names to table column ids</value>
        [DataMember(Name="columnMappings", EmitDefaultValue=false)]
        public Dictionary<string, string> ColumnMappings { get; set; }
        /// <summary>
        /// For overriding the file metadata&#39;s delimiter. The file delimiter is the character to use within the file to separate one field from another. If this value is not set, the import will use the file&#39;s set delimiter. If this value is set, the file metadata&#39;s delimiter will be updated on the file object.
        /// </summary>
        /// <value>For overriding the file metadata&#39;s delimiter. The file delimiter is the character to use within the file to separate one field from another. If this value is not set, the import will use the file&#39;s set delimiter. If this value is set, the file metadata&#39;s delimiter will be updated on the file object.</value>
        [DataMember(Name="delimiter", EmitDefaultValue=false)]
        public string Delimiter { get; set; }
        /// <summary>
        /// id of the file to import to the table
        /// </summary>
        /// <value>id of the file to import to the table</value>
        [DataMember(Name="fileId", EmitDefaultValue=false)]
        public string FileId { get; set; }
        /// <summary>
        /// For overriding column metadata specifically for this import. The keys in this object are column identifiers with the values being metadata objects.
        /// </summary>
        /// <value>For overriding column metadata specifically for this import. The keys in this object are column identifiers with the values being metadata objects.</value>
        [DataMember(Name="metadata", EmitDefaultValue=false)]
        public Dictionary<string, Dictionary<string, Object>> Metadata { get; set; }
        /// <summary>
        /// an object containing keys and values, which becomes the tag map
        /// </summary>
        /// <value>an object containing keys and values, which becomes the tag map</value>
        [DataMember(Name="tags", EmitDefaultValue=false)]
        public Dictionary<string, string> Tags { get; set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class ImportDto {\n");
            sb.Append("  ColumnMappings: ").Append(ColumnMappings).Append("\n");
            sb.Append("  Delimiter: ").Append(Delimiter).Append("\n");
            sb.Append("  FileId: ").Append(FileId).Append("\n");
            sb.Append("  Metadata: ").Append(Metadata).Append("\n");
            sb.Append("  Tags: ").Append(Tags).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as ImportDto);
        }

        /// <summary>
        /// Returns true if ImportDto instances are equal
        /// </summary>
        /// <param name="other">Instance of ImportDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(ImportDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.ColumnMappings == other.ColumnMappings ||
                    this.ColumnMappings != null &&
                    this.ColumnMappings.SequenceEqual(other.ColumnMappings)
                ) && 
                (
                    this.Delimiter == other.Delimiter ||
                    this.Delimiter != null &&
                    this.Delimiter.Equals(other.Delimiter)
                ) && 
                (
                    this.FileId == other.FileId ||
                    this.FileId != null &&
                    this.FileId.Equals(other.FileId)
                ) && 
                (
                    this.Metadata == other.Metadata ||
                    this.Metadata != null &&
                    this.Metadata.SequenceEqual(other.Metadata)
                ) && 
                (
                    this.Tags == other.Tags ||
                    this.Tags != null &&
                    this.Tags.SequenceEqual(other.Tags)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.ColumnMappings != null)
                    hash = hash * 59 + this.ColumnMappings.GetHashCode();
                if (this.Delimiter != null)
                    hash = hash * 59 + this.Delimiter.GetHashCode();
                if (this.FileId != null)
                    hash = hash * 59 + this.FileId.GetHashCode();
                if (this.Metadata != null)
                    hash = hash * 59 + this.Metadata.GetHashCode();
                if (this.Tags != null)
                    hash = hash * 59 + this.Tags.GetHashCode();
                return hash;
            }
        }
    }

}
