/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// PivotDefinitionDto
    /// </summary>
    [DataContract]
    public partial class PivotDefinitionDto :  IEquatable<PivotDefinitionDto>
    {
        /// <summary>
        /// The level to which Grand Totals are enabled.  It is defaulted to DISABLED.
        /// </summary>
        /// <value>The level to which Grand Totals are enabled.  It is defaulted to DISABLED.</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum GrandTotalEnabledEnum
        {
            
            /// <summary>
            /// Enum ENABLED for "ENABLED"
            /// </summary>
            [EnumMember(Value = "ENABLED")]
            ENABLED,
            
            /// <summary>
            /// Enum ROW for "ROW"
            /// </summary>
            [EnumMember(Value = "ROW")]
            ROW,
            
            /// <summary>
            /// Enum COLUMN for "COLUMN"
            /// </summary>
            [EnumMember(Value = "COLUMN")]
            COLUMN,
            
            /// <summary>
            /// Enum DISABLED for "DISABLED"
            /// </summary>
            [EnumMember(Value = "DISABLED")]
            DISABLED
        }

        /// <summary>
        /// The type of pivot view. Options are currently Classic and Compact.
        /// </summary>
        /// <value>The type of pivot view. Options are currently Classic and Compact.</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum PivotViewTypeEnum
        {
            
            /// <summary>
            /// Enum CLASSIC for "CLASSIC"
            /// </summary>
            [EnumMember(Value = "CLASSIC")]
            CLASSIC,
            
            /// <summary>
            /// Enum COMPACT for "COMPACT"
            /// </summary>
            [EnumMember(Value = "COMPACT")]
            COMPACT,
            
            /// <summary>
            /// Enum FLAT for "FLAT"
            /// </summary>
            [EnumMember(Value = "FLAT")]
            FLAT
        }

        /// <summary>
        /// The level to which Subtotals are enabled.  It is defaulted to DISABLED.
        /// </summary>
        /// <value>The level to which Subtotals are enabled.  It is defaulted to DISABLED.</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum SubtotalEnabledEnum
        {
            
            /// <summary>
            /// Enum ENABLED for "ENABLED"
            /// </summary>
            [EnumMember(Value = "ENABLED")]
            ENABLED,
            
            /// <summary>
            /// Enum ROW for "ROW"
            /// </summary>
            [EnumMember(Value = "ROW")]
            ROW,
            
            /// <summary>
            /// Enum COLUMN for "COLUMN"
            /// </summary>
            [EnumMember(Value = "COLUMN")]
            COLUMN,
            
            /// <summary>
            /// Enum DISABLED for "DISABLED"
            /// </summary>
            [EnumMember(Value = "DISABLED")]
            DISABLED
        }

        /// <summary>
        /// The level to which Grand Totals are enabled.  It is defaulted to DISABLED.
        /// </summary>
        /// <value>The level to which Grand Totals are enabled.  It is defaulted to DISABLED.</value>
        [DataMember(Name="grandTotalEnabled", EmitDefaultValue=false)]
        public GrandTotalEnabledEnum? GrandTotalEnabled { get; set; }
        /// <summary>
        /// The type of pivot view. Options are currently Classic and Compact.
        /// </summary>
        /// <value>The type of pivot view. Options are currently Classic and Compact.</value>
        [DataMember(Name="pivotViewType", EmitDefaultValue=false)]
        public PivotViewTypeEnum? PivotViewType { get; set; }
        /// <summary>
        /// The level to which Subtotals are enabled.  It is defaulted to DISABLED.
        /// </summary>
        /// <value>The level to which Subtotals are enabled.  It is defaulted to DISABLED.</value>
        [DataMember(Name="subtotalEnabled", EmitDefaultValue=false)]
        public SubtotalEnabledEnum? SubtotalEnabled { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="PivotDefinitionDto" /> class.
        /// </summary>
        /// <param name="Columns">The colmnnns associated with the pivot view.</param>
        /// <param name="DecimalPlaces">Numeric data values are rounded to the number of decimal places.  The default number to round to and show is 2 decimal places, and the maximum number is capped at 16..</param>
        /// <param name="Filters">The filters associated with the pivot view.</param>
        /// <param name="GrandTotalEnabled">The level to which Grand Totals are enabled.  It is defaulted to DISABLED..</param>
        /// <param name="Id">The pivot view&#39;s definition&#39;s id.</param>
        /// <param name="MultipleHeaders">Denotes whether a pivot is created in multi-line header mode. Default is false..</param>
        /// <param name="PivotViewType">The type of pivot view. Options are currently Classic and Compact..</param>
        /// <param name="Rows">The rows associated with the pivot view.</param>
        /// <param name="SortColumns">Columns with which to sort the crosstab query.</param>
        /// <param name="SubtotalEnabled">The level to which Subtotals are enabled.  It is defaulted to DISABLED..</param>
        /// <param name="Values">The values associated with the pivot view.</param>
        public PivotDefinitionDto(List<PivotViewDefinitionColumnDto> Columns = null, int? DecimalPlaces = null, List<PivotViewDefinitionFilterDto> Filters = null, GrandTotalEnabledEnum? GrandTotalEnabled = null, string Id = null, bool? MultipleHeaders = null, PivotViewTypeEnum? PivotViewType = null, List<PivotViewDefinitionRowDto> Rows = null, List<string> SortColumns = null, SubtotalEnabledEnum? SubtotalEnabled = null, List<PivotViewDefinitionValueDto> Values = null)
        {
            this.Columns = Columns;
            this.DecimalPlaces = DecimalPlaces;
            this.Filters = Filters;
            this.GrandTotalEnabled = GrandTotalEnabled;
            this.Id = Id;
            this.MultipleHeaders = MultipleHeaders;
            this.PivotViewType = PivotViewType;
            this.Rows = Rows;
            this.SortColumns = SortColumns;
            this.SubtotalEnabled = SubtotalEnabled;
            this.Values = Values;
        }
        
        /// <summary>
        /// The colmnnns associated with the pivot view
        /// </summary>
        /// <value>The colmnnns associated with the pivot view</value>
        [DataMember(Name="columns", EmitDefaultValue=false)]
        public List<PivotViewDefinitionColumnDto> Columns { get; set; }
        /// <summary>
        /// Numeric data values are rounded to the number of decimal places.  The default number to round to and show is 2 decimal places, and the maximum number is capped at 16.
        /// </summary>
        /// <value>Numeric data values are rounded to the number of decimal places.  The default number to round to and show is 2 decimal places, and the maximum number is capped at 16.</value>
        [DataMember(Name="decimalPlaces", EmitDefaultValue=false)]
        public int? DecimalPlaces { get; set; }
        /// <summary>
        /// The filters associated with the pivot view
        /// </summary>
        /// <value>The filters associated with the pivot view</value>
        [DataMember(Name="filters", EmitDefaultValue=false)]
        public List<PivotViewDefinitionFilterDto> Filters { get; set; }
        /// <summary>
        /// The pivot view&#39;s definition&#39;s id
        /// </summary>
        /// <value>The pivot view&#39;s definition&#39;s id</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; set; }
        /// <summary>
        /// Denotes whether a pivot is created in multi-line header mode. Default is false.
        /// </summary>
        /// <value>Denotes whether a pivot is created in multi-line header mode. Default is false.</value>
        [DataMember(Name="multipleHeaders", EmitDefaultValue=false)]
        public bool? MultipleHeaders { get; set; }
        /// <summary>
        /// The rows associated with the pivot view
        /// </summary>
        /// <value>The rows associated with the pivot view</value>
        [DataMember(Name="rows", EmitDefaultValue=false)]
        public List<PivotViewDefinitionRowDto> Rows { get; set; }
        /// <summary>
        /// Columns with which to sort the crosstab query
        /// </summary>
        /// <value>Columns with which to sort the crosstab query</value>
        [DataMember(Name="sortColumns", EmitDefaultValue=false)]
        public List<string> SortColumns { get; set; }
        /// <summary>
        /// The values associated with the pivot view
        /// </summary>
        /// <value>The values associated with the pivot view</value>
        [DataMember(Name="values", EmitDefaultValue=false)]
        public List<PivotViewDefinitionValueDto> Values { get; set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class PivotDefinitionDto {\n");
            sb.Append("  Columns: ").Append(Columns).Append("\n");
            sb.Append("  DecimalPlaces: ").Append(DecimalPlaces).Append("\n");
            sb.Append("  Filters: ").Append(Filters).Append("\n");
            sb.Append("  GrandTotalEnabled: ").Append(GrandTotalEnabled).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  MultipleHeaders: ").Append(MultipleHeaders).Append("\n");
            sb.Append("  PivotViewType: ").Append(PivotViewType).Append("\n");
            sb.Append("  Rows: ").Append(Rows).Append("\n");
            sb.Append("  SortColumns: ").Append(SortColumns).Append("\n");
            sb.Append("  SubtotalEnabled: ").Append(SubtotalEnabled).Append("\n");
            sb.Append("  Values: ").Append(Values).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as PivotDefinitionDto);
        }

        /// <summary>
        /// Returns true if PivotDefinitionDto instances are equal
        /// </summary>
        /// <param name="other">Instance of PivotDefinitionDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(PivotDefinitionDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.Columns == other.Columns ||
                    this.Columns != null &&
                    this.Columns.SequenceEqual(other.Columns)
                ) && 
                (
                    this.DecimalPlaces == other.DecimalPlaces ||
                    this.DecimalPlaces != null &&
                    this.DecimalPlaces.Equals(other.DecimalPlaces)
                ) && 
                (
                    this.Filters == other.Filters ||
                    this.Filters != null &&
                    this.Filters.SequenceEqual(other.Filters)
                ) && 
                (
                    this.GrandTotalEnabled == other.GrandTotalEnabled ||
                    this.GrandTotalEnabled != null &&
                    this.GrandTotalEnabled.Equals(other.GrandTotalEnabled)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.MultipleHeaders == other.MultipleHeaders ||
                    this.MultipleHeaders != null &&
                    this.MultipleHeaders.Equals(other.MultipleHeaders)
                ) && 
                (
                    this.PivotViewType == other.PivotViewType ||
                    this.PivotViewType != null &&
                    this.PivotViewType.Equals(other.PivotViewType)
                ) && 
                (
                    this.Rows == other.Rows ||
                    this.Rows != null &&
                    this.Rows.SequenceEqual(other.Rows)
                ) && 
                (
                    this.SortColumns == other.SortColumns ||
                    this.SortColumns != null &&
                    this.SortColumns.SequenceEqual(other.SortColumns)
                ) && 
                (
                    this.SubtotalEnabled == other.SubtotalEnabled ||
                    this.SubtotalEnabled != null &&
                    this.SubtotalEnabled.Equals(other.SubtotalEnabled)
                ) && 
                (
                    this.Values == other.Values ||
                    this.Values != null &&
                    this.Values.SequenceEqual(other.Values)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.Columns != null)
                    hash = hash * 59 + this.Columns.GetHashCode();
                if (this.DecimalPlaces != null)
                    hash = hash * 59 + this.DecimalPlaces.GetHashCode();
                if (this.Filters != null)
                    hash = hash * 59 + this.Filters.GetHashCode();
                if (this.GrandTotalEnabled != null)
                    hash = hash * 59 + this.GrandTotalEnabled.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.MultipleHeaders != null)
                    hash = hash * 59 + this.MultipleHeaders.GetHashCode();
                if (this.PivotViewType != null)
                    hash = hash * 59 + this.PivotViewType.GetHashCode();
                if (this.Rows != null)
                    hash = hash * 59 + this.Rows.GetHashCode();
                if (this.SortColumns != null)
                    hash = hash * 59 + this.SortColumns.GetHashCode();
                if (this.SubtotalEnabled != null)
                    hash = hash * 59 + this.SubtotalEnabled.GetHashCode();
                if (this.Values != null)
                    hash = hash * 59 + this.Values.GetHashCode();
                return hash;
            }
        }
    }

}
