/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// PivotViewDto
    /// </summary>
    [DataContract]
    public partial class PivotViewDto :  IEquatable<PivotViewDto>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="PivotViewDto" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected PivotViewDto() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="PivotViewDto" /> class.
        /// </summary>
        /// <param name="AdditionalMeta">User-defined metadata to attach to the pivot view. This is any arbitrary JSON object and is not required..</param>
        /// <param name="Description">The description of the pivot view.</param>
        /// <param name="Name">Name of the pivot view. The maximum size is 255 characters. (required).</param>
        /// <param name="QueryId">The query to associate with this pivot view. This value is required and cannot be updated after the pivot is created. Any attempt to update the query ID is ignored. (required).</param>
        /// <param name="QueryResultId">An optional query result id to associate with this pivot view. If associated, saving a pivot view will cause an existence check on the related query result.  This value is not required. The query id on the query result must match this pivot&#39;s query ID..</param>
        public PivotViewDto(Dictionary<string, Object> AdditionalMeta = null, string Description = null, string Name = null, string QueryId = null, string QueryResultId = null)
        {
            // to ensure "Name" is required (not null)
            if (Name == null)
            {
                throw new InvalidDataException("Name is a required property for PivotViewDto and cannot be null");
            }
            else
            {
                this.Name = Name;
            }
            // to ensure "QueryId" is required (not null)
            if (QueryId == null)
            {
                throw new InvalidDataException("QueryId is a required property for PivotViewDto and cannot be null");
            }
            else
            {
                this.QueryId = QueryId;
            }
            this.AdditionalMeta = AdditionalMeta;
            this.Description = Description;
            this.QueryResultId = QueryResultId;
        }
        
        /// <summary>
        /// User-defined metadata to attach to the pivot view. This is any arbitrary JSON object and is not required.
        /// </summary>
        /// <value>User-defined metadata to attach to the pivot view. This is any arbitrary JSON object and is not required.</value>
        [DataMember(Name="additionalMeta", EmitDefaultValue=false)]
        public Dictionary<string, Object> AdditionalMeta { get; set; }
        /// <summary>
        /// When the entity was created
        /// </summary>
        /// <value>When the entity was created</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The description of the pivot view
        /// </summary>
        /// <value>The description of the pivot view</value>
        [DataMember(Name="description", EmitDefaultValue=false)]
        public string Description { get; set; }
        /// <summary>
        /// The entity&#39;s unique identifier
        /// </summary>
        /// <value>The entity&#39;s unique identifier</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; private set; }
        /// <summary>
        /// Name of the pivot view. The maximum size is 255 characters.
        /// </summary>
        /// <value>Name of the pivot view. The maximum size is 255 characters.</value>
        [DataMember(Name="name", EmitDefaultValue=false)]
        public string Name { get; set; }
        /// <summary>
        /// If non-null, indicates the parent of this entity. Must be modified through the folder api.
        /// </summary>
        /// <value>If non-null, indicates the parent of this entity. Must be modified through the folder api.</value>
        [DataMember(Name="parentId", EmitDefaultValue=false)]
        public string ParentId { get; private set; }
        /// <summary>
        /// The query to associate with this pivot view. This value is required and cannot be updated after the pivot is created. Any attempt to update the query ID is ignored.
        /// </summary>
        /// <value>The query to associate with this pivot view. This value is required and cannot be updated after the pivot is created. Any attempt to update the query ID is ignored.</value>
        [DataMember(Name="queryId", EmitDefaultValue=false)]
        public string QueryId { get; set; }
        /// <summary>
        /// An optional query result id to associate with this pivot view. If associated, saving a pivot view will cause an existence check on the related query result.  This value is not required. The query id on the query result must match this pivot&#39;s query ID.
        /// </summary>
        /// <value>An optional query result id to associate with this pivot view. If associated, saving a pivot view will cause an existence check on the related query result.  This value is not required. The query id on the query result must match this pivot&#39;s query ID.</value>
        [DataMember(Name="queryResultId", EmitDefaultValue=false)]
        public string QueryResultId { get; set; }
        /// <summary>
        /// When the entity was last updated
        /// </summary>
        /// <value>When the entity was last updated</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The owner of the entity
        /// </summary>
        /// <value>The owner of the entity</value>
        [DataMember(Name="userId", EmitDefaultValue=false)]
        public string UserId { get; private set; }
        /// <summary>
        /// The version of the current representation of the entity
        /// </summary>
        /// <value>The version of the current representation of the entity</value>
        [DataMember(Name="version", EmitDefaultValue=false)]
        public long? Version { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class PivotViewDto {\n");
            sb.Append("  AdditionalMeta: ").Append(AdditionalMeta).Append("\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  Description: ").Append(Description).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  Name: ").Append(Name).Append("\n");
            sb.Append("  ParentId: ").Append(ParentId).Append("\n");
            sb.Append("  QueryId: ").Append(QueryId).Append("\n");
            sb.Append("  QueryResultId: ").Append(QueryResultId).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  UserId: ").Append(UserId).Append("\n");
            sb.Append("  Version: ").Append(Version).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as PivotViewDto);
        }

        /// <summary>
        /// Returns true if PivotViewDto instances are equal
        /// </summary>
        /// <param name="other">Instance of PivotViewDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(PivotViewDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.AdditionalMeta == other.AdditionalMeta ||
                    this.AdditionalMeta != null &&
                    this.AdditionalMeta.SequenceEqual(other.AdditionalMeta)
                ) && 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.Description == other.Description ||
                    this.Description != null &&
                    this.Description.Equals(other.Description)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.Name == other.Name ||
                    this.Name != null &&
                    this.Name.Equals(other.Name)
                ) && 
                (
                    this.ParentId == other.ParentId ||
                    this.ParentId != null &&
                    this.ParentId.Equals(other.ParentId)
                ) && 
                (
                    this.QueryId == other.QueryId ||
                    this.QueryId != null &&
                    this.QueryId.Equals(other.QueryId)
                ) && 
                (
                    this.QueryResultId == other.QueryResultId ||
                    this.QueryResultId != null &&
                    this.QueryResultId.Equals(other.QueryResultId)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.UserId == other.UserId ||
                    this.UserId != null &&
                    this.UserId.Equals(other.UserId)
                ) && 
                (
                    this.Version == other.Version ||
                    this.Version != null &&
                    this.Version.Equals(other.Version)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.AdditionalMeta != null)
                    hash = hash * 59 + this.AdditionalMeta.GetHashCode();
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.Description != null)
                    hash = hash * 59 + this.Description.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.Name != null)
                    hash = hash * 59 + this.Name.GetHashCode();
                if (this.ParentId != null)
                    hash = hash * 59 + this.ParentId.GetHashCode();
                if (this.QueryId != null)
                    hash = hash * 59 + this.QueryId.GetHashCode();
                if (this.QueryResultId != null)
                    hash = hash * 59 + this.QueryResultId.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.UserId != null)
                    hash = hash * 59 + this.UserId.GetHashCode();
                if (this.Version != null)
                    hash = hash * 59 + this.Version.GetHashCode();
                return hash;
            }
        }
    }

}
