/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// The query text associated with any persisted query contains references to tables upon which that query relies. This model represents those dependencies. Every dependency contains a database and table identifier as in a traditional SQL database.
    /// </summary>
    [DataContract]
    public partial class QueryDependencyDto :  IEquatable<QueryDependencyDto>
    {
        /// <summary>
        /// The name of the system holding this reference.
        /// </summary>
        /// <value>The name of the system holding this reference.</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum SystemEnum
        {
            
            /// <summary>
            /// Enum Prep for "prep"
            /// </summary>
            [EnumMember(Value = "prep")]
            Prep,
            
            /// <summary>
            /// Enum Spreadsheets for "spreadsheets"
            /// </summary>
            [EnumMember(Value = "spreadsheets")]
            Spreadsheets,
            
            /// <summary>
            /// Enum Queries for "queries"
            /// </summary>
            [EnumMember(Value = "queries")]
            Queries,
            
            /// <summary>
            /// Enum Program for "program"
            /// </summary>
            [EnumMember(Value = "program")]
            Program,
            
            /// <summary>
            /// Enum Com for "com"
            /// </summary>
            [EnumMember(Value = "com")]
            Com,
            
            /// <summary>
            /// Enum Iam for "iam"
            /// </summary>
            [EnumMember(Value = "iam")]
            Iam,
            
            /// <summary>
            /// Enum Graph for "graph"
            /// </summary>
            [EnumMember(Value = "graph")]
            Graph,
            
            /// <summary>
            /// Enum Explorer for "explorer"
            /// </summary>
            [EnumMember(Value = "explorer")]
            Explorer,
            
            /// <summary>
            /// Enum Programv2 for "program_v2"
            /// </summary>
            [EnumMember(Value = "program_v2")]
            Programv2,
            
            /// <summary>
            /// Enum Explorerv2 for "explorer_v2"
            /// </summary>
            [EnumMember(Value = "explorer_v2")]
            Explorerv2
        }

        /// <summary>
        /// The name of the system holding this reference.
        /// </summary>
        /// <value>The name of the system holding this reference.</value>
        [DataMember(Name="system", EmitDefaultValue=false)]
        public SystemEnum? System { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="QueryDependencyDto" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        public QueryDependencyDto()
        {
        }
        
        /// <summary>
        /// The database in which this dependency exists.
        /// </summary>
        /// <value>The database in which this dependency exists.</value>
        [DataMember(Name="databaseId", EmitDefaultValue=false)]
        public string DatabaseId { get; private set; }
        /// <summary>
        /// The id of the table this dependency represents.
        /// </summary>
        /// <value>The id of the table this dependency represents.</value>
        [DataMember(Name="tableId", EmitDefaultValue=false)]
        public string TableId { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class QueryDependencyDto {\n");
            sb.Append("  DatabaseId: ").Append(DatabaseId).Append("\n");
            sb.Append("  System: ").Append(System).Append("\n");
            sb.Append("  TableId: ").Append(TableId).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as QueryDependencyDto);
        }

        /// <summary>
        /// Returns true if QueryDependencyDto instances are equal
        /// </summary>
        /// <param name="other">Instance of QueryDependencyDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(QueryDependencyDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.DatabaseId == other.DatabaseId ||
                    this.DatabaseId != null &&
                    this.DatabaseId.Equals(other.DatabaseId)
                ) && 
                (
                    this.System == other.System ||
                    this.System != null &&
                    this.System.Equals(other.System)
                ) && 
                (
                    this.TableId == other.TableId ||
                    this.TableId != null &&
                    this.TableId.Equals(other.TableId)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.DatabaseId != null)
                    hash = hash * 59 + this.DatabaseId.GetHashCode();
                if (this.System != null)
                    hash = hash * 59 + this.System.GetHashCode();
                if (this.TableId != null)
                    hash = hash * 59 + this.TableId.GetHashCode();
                return hash;
            }
        }
    }

}
