/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// QueryDto
    /// </summary>
    [DataContract]
    public partial class QueryDto :  IEquatable<QueryDto>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="QueryDto" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected QueryDto() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="QueryDto" /> class.
        /// </summary>
        /// <param name="Definition">The pivot view&#39;s definition.</param>
        /// <param name="Dependencies">A structured list of dependencies that this query relies upon. This list is populated by the server from the query text. Each dependency model contains enough information to find the source object..</param>
        /// <param name="Description">The description of the query.</param>
        /// <param name="HistoryRevision">Historical revision number of this entity.</param>
        /// <param name="Name">The name of the query.</param>
        /// <param name="Parameters">The query parameters.</param>
        /// <param name="PrimaryQueryResultId">The identifier of the primary query result.</param>
        /// <param name="QueryText">Max size is 30000 characters.  Is required.  Must be a valid DML statement. (required).</param>
        /// <param name="Temporary">Denotes if this query is meant to be temporary.  Default is false..</param>
        /// <param name="Type">This field exists for backwards compatibility only and will always be an empty string..</param>
        public QueryDto(PivotDefinitionDto Definition = null, List<QueryDependencyDto> Dependencies = null, string Description = null, long? HistoryRevision = null, string Name = null, List<QueryParameterDto> Parameters = null, string PrimaryQueryResultId = null, string QueryText = null, bool? Temporary = null, string Type = null)
        {
            // to ensure "QueryText" is required (not null)
            if (QueryText == null)
            {
                throw new InvalidDataException("QueryText is a required property for QueryDto and cannot be null");
            }
            else
            {
                this.QueryText = QueryText;
            }
            this.Definition = Definition;
            this.Dependencies = Dependencies;
            this.Description = Description;
            this.HistoryRevision = HistoryRevision;
            this.Name = Name;
            this.Parameters = Parameters;
            this.PrimaryQueryResultId = PrimaryQueryResultId;
            this.Temporary = Temporary;
            this.Type = Type;
        }
        
        /// <summary>
        /// When the entity was created
        /// </summary>
        /// <value>When the entity was created</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The pivot view&#39;s definition
        /// </summary>
        /// <value>The pivot view&#39;s definition</value>
        [DataMember(Name="definition", EmitDefaultValue=false)]
        public PivotDefinitionDto Definition { get; set; }
        /// <summary>
        /// A structured list of dependencies that this query relies upon. This list is populated by the server from the query text. Each dependency model contains enough information to find the source object.
        /// </summary>
        /// <value>A structured list of dependencies that this query relies upon. This list is populated by the server from the query text. Each dependency model contains enough information to find the source object.</value>
        [DataMember(Name="dependencies", EmitDefaultValue=false)]
        public List<QueryDependencyDto> Dependencies { get; set; }
        /// <summary>
        /// The description of the query
        /// </summary>
        /// <value>The description of the query</value>
        [DataMember(Name="description", EmitDefaultValue=false)]
        public string Description { get; set; }
        /// <summary>
        /// Historical revision number of this entity
        /// </summary>
        /// <value>Historical revision number of this entity</value>
        [DataMember(Name="historyRevision", EmitDefaultValue=false)]
        public long? HistoryRevision { get; set; }
        /// <summary>
        /// The entity&#39;s unique identifier
        /// </summary>
        /// <value>The entity&#39;s unique identifier</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; private set; }
        /// <summary>
        /// If non-null, indicates the last time this query was run.
        /// </summary>
        /// <value>If non-null, indicates the last time this query was run.</value>
        [DataMember(Name="lastRun", EmitDefaultValue=false)]
        public DateTime? LastRun { get; private set; }
        /// <summary>
        /// If non-null, indicates the last user that ran the query.
        /// </summary>
        /// <value>If non-null, indicates the last user that ran the query.</value>
        [DataMember(Name="lastRunBy", EmitDefaultValue=false)]
        public string LastRunBy { get; private set; }
        /// <summary>
        /// The name of the query
        /// </summary>
        /// <value>The name of the query</value>
        [DataMember(Name="name", EmitDefaultValue=false)]
        public string Name { get; set; }
        /// <summary>
        /// The query parameters
        /// </summary>
        /// <value>The query parameters</value>
        [DataMember(Name="parameters", EmitDefaultValue=false)]
        public List<QueryParameterDto> Parameters { get; set; }
        /// <summary>
        /// If non-null, indicates the parent of this entity. Must be modified through the folder api.
        /// </summary>
        /// <value>If non-null, indicates the parent of this entity. Must be modified through the folder api.</value>
        [DataMember(Name="parentId", EmitDefaultValue=false)]
        public string ParentId { get; private set; }
        /// <summary>
        /// The identifier of the primary query result
        /// </summary>
        /// <value>The identifier of the primary query result</value>
        [DataMember(Name="primaryQueryResultId", EmitDefaultValue=false)]
        public string PrimaryQueryResultId { get; set; }
        /// <summary>
        /// Max size is 30000 characters.  Is required.  Must be a valid DML statement.
        /// </summary>
        /// <value>Max size is 30000 characters.  Is required.  Must be a valid DML statement.</value>
        [DataMember(Name="queryText", EmitDefaultValue=false)]
        public string QueryText { get; set; }
        /// <summary>
        /// Denotes if this query is meant to be temporary.  Default is false.
        /// </summary>
        /// <value>Denotes if this query is meant to be temporary.  Default is false.</value>
        [DataMember(Name="temporary", EmitDefaultValue=false)]
        public bool? Temporary { get; set; }
        /// <summary>
        /// This field exists for backwards compatibility only and will always be an empty string.
        /// </summary>
        /// <value>This field exists for backwards compatibility only and will always be an empty string.</value>
        [DataMember(Name="type", EmitDefaultValue=false)]
        public string Type { get; set; }
        /// <summary>
        /// When the entity was last updated
        /// </summary>
        /// <value>When the entity was last updated</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The owner of the entity
        /// </summary>
        /// <value>The owner of the entity</value>
        [DataMember(Name="userId", EmitDefaultValue=false)]
        public string UserId { get; private set; }
        /// <summary>
        /// The version of the current representation of the entity
        /// </summary>
        /// <value>The version of the current representation of the entity</value>
        [DataMember(Name="version", EmitDefaultValue=false)]
        public long? Version { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class QueryDto {\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  Definition: ").Append(Definition).Append("\n");
            sb.Append("  Dependencies: ").Append(Dependencies).Append("\n");
            sb.Append("  Description: ").Append(Description).Append("\n");
            sb.Append("  HistoryRevision: ").Append(HistoryRevision).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  LastRun: ").Append(LastRun).Append("\n");
            sb.Append("  LastRunBy: ").Append(LastRunBy).Append("\n");
            sb.Append("  Name: ").Append(Name).Append("\n");
            sb.Append("  Parameters: ").Append(Parameters).Append("\n");
            sb.Append("  ParentId: ").Append(ParentId).Append("\n");
            sb.Append("  PrimaryQueryResultId: ").Append(PrimaryQueryResultId).Append("\n");
            sb.Append("  QueryText: ").Append(QueryText).Append("\n");
            sb.Append("  Temporary: ").Append(Temporary).Append("\n");
            sb.Append("  Type: ").Append(Type).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  UserId: ").Append(UserId).Append("\n");
            sb.Append("  Version: ").Append(Version).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as QueryDto);
        }

        /// <summary>
        /// Returns true if QueryDto instances are equal
        /// </summary>
        /// <param name="other">Instance of QueryDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(QueryDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.Definition == other.Definition ||
                    this.Definition != null &&
                    this.Definition.Equals(other.Definition)
                ) && 
                (
                    this.Dependencies == other.Dependencies ||
                    this.Dependencies != null &&
                    this.Dependencies.SequenceEqual(other.Dependencies)
                ) && 
                (
                    this.Description == other.Description ||
                    this.Description != null &&
                    this.Description.Equals(other.Description)
                ) && 
                (
                    this.HistoryRevision == other.HistoryRevision ||
                    this.HistoryRevision != null &&
                    this.HistoryRevision.Equals(other.HistoryRevision)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.LastRun == other.LastRun ||
                    this.LastRun != null &&
                    this.LastRun.Equals(other.LastRun)
                ) && 
                (
                    this.LastRunBy == other.LastRunBy ||
                    this.LastRunBy != null &&
                    this.LastRunBy.Equals(other.LastRunBy)
                ) && 
                (
                    this.Name == other.Name ||
                    this.Name != null &&
                    this.Name.Equals(other.Name)
                ) && 
                (
                    this.Parameters == other.Parameters ||
                    this.Parameters != null &&
                    this.Parameters.SequenceEqual(other.Parameters)
                ) && 
                (
                    this.ParentId == other.ParentId ||
                    this.ParentId != null &&
                    this.ParentId.Equals(other.ParentId)
                ) && 
                (
                    this.PrimaryQueryResultId == other.PrimaryQueryResultId ||
                    this.PrimaryQueryResultId != null &&
                    this.PrimaryQueryResultId.Equals(other.PrimaryQueryResultId)
                ) && 
                (
                    this.QueryText == other.QueryText ||
                    this.QueryText != null &&
                    this.QueryText.Equals(other.QueryText)
                ) && 
                (
                    this.Temporary == other.Temporary ||
                    this.Temporary != null &&
                    this.Temporary.Equals(other.Temporary)
                ) && 
                (
                    this.Type == other.Type ||
                    this.Type != null &&
                    this.Type.Equals(other.Type)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.UserId == other.UserId ||
                    this.UserId != null &&
                    this.UserId.Equals(other.UserId)
                ) && 
                (
                    this.Version == other.Version ||
                    this.Version != null &&
                    this.Version.Equals(other.Version)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.Definition != null)
                    hash = hash * 59 + this.Definition.GetHashCode();
                if (this.Dependencies != null)
                    hash = hash * 59 + this.Dependencies.GetHashCode();
                if (this.Description != null)
                    hash = hash * 59 + this.Description.GetHashCode();
                if (this.HistoryRevision != null)
                    hash = hash * 59 + this.HistoryRevision.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.LastRun != null)
                    hash = hash * 59 + this.LastRun.GetHashCode();
                if (this.LastRunBy != null)
                    hash = hash * 59 + this.LastRunBy.GetHashCode();
                if (this.Name != null)
                    hash = hash * 59 + this.Name.GetHashCode();
                if (this.Parameters != null)
                    hash = hash * 59 + this.Parameters.GetHashCode();
                if (this.ParentId != null)
                    hash = hash * 59 + this.ParentId.GetHashCode();
                if (this.PrimaryQueryResultId != null)
                    hash = hash * 59 + this.PrimaryQueryResultId.GetHashCode();
                if (this.QueryText != null)
                    hash = hash * 59 + this.QueryText.GetHashCode();
                if (this.Temporary != null)
                    hash = hash * 59 + this.Temporary.GetHashCode();
                if (this.Type != null)
                    hash = hash * 59 + this.Type.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.UserId != null)
                    hash = hash * 59 + this.UserId.GetHashCode();
                if (this.Version != null)
                    hash = hash * 59 + this.Version.GetHashCode();
                return hash;
            }
        }
    }

}
