/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// QueryParameterDto
    /// </summary>
    [DataContract]
    public partial class QueryParameterDto :  IEquatable<QueryParameterDto>
    {
        /// <summary>
        /// The mode of the query parameter
        /// </summary>
        /// <value>The mode of the query parameter</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum ModeEnum
        {
            
            /// <summary>
            /// Enum Scalar for "scalar"
            /// </summary>
            [EnumMember(Value = "scalar")]
            Scalar,
            
            /// <summary>
            /// Enum SingleSelect for "singleSelect"
            /// </summary>
            [EnumMember(Value = "singleSelect")]
            SingleSelect,
            
            /// <summary>
            /// Enum MultiSelect for "multiSelect"
            /// </summary>
            [EnumMember(Value = "multiSelect")]
            MultiSelect,
            
            /// <summary>
            /// Enum Reference for "reference"
            /// </summary>
            [EnumMember(Value = "reference")]
            Reference
        }

        /// <summary>
        /// The type of the query parameter
        /// </summary>
        /// <value>The type of the query parameter</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum TypeEnum
        {
            
            /// <summary>
            /// Enum String for "string"
            /// </summary>
            [EnumMember(Value = "string")]
            String,
            
            /// <summary>
            /// Enum Bytes for "bytes"
            /// </summary>
            [EnumMember(Value = "bytes")]
            Bytes,
            
            /// <summary>
            /// Enum Integer for "integer"
            /// </summary>
            [EnumMember(Value = "integer")]
            Integer,
            
            /// <summary>
            /// Enum Float for "float"
            /// </summary>
            [EnumMember(Value = "float")]
            Float,
            
            /// <summary>
            /// Enum Boolean for "boolean"
            /// </summary>
            [EnumMember(Value = "boolean")]
            Boolean,
            
            /// <summary>
            /// Enum Timestamp for "timestamp"
            /// </summary>
            [EnumMember(Value = "timestamp")]
            Timestamp,
            
            /// <summary>
            /// Enum Date for "date"
            /// </summary>
            [EnumMember(Value = "date")]
            Date,
            
            /// <summary>
            /// Enum Time for "time"
            /// </summary>
            [EnumMember(Value = "time")]
            Time,
            
            /// <summary>
            /// Enum Datetime for "datetime"
            /// </summary>
            [EnumMember(Value = "datetime")]
            Datetime,
            
            /// <summary>
            /// Enum Globalparameter for "global_parameter"
            /// </summary>
            [EnumMember(Value = "global_parameter")]
            Globalparameter,
            
            /// <summary>
            /// Enum Nestedqueryparameter for "nested_query_parameter"
            /// </summary>
            [EnumMember(Value = "nested_query_parameter")]
            Nestedqueryparameter
        }

        /// <summary>
        /// The mode of the query parameter
        /// </summary>
        /// <value>The mode of the query parameter</value>
        [DataMember(Name="mode", EmitDefaultValue=false)]
        public ModeEnum? Mode { get; set; }
        /// <summary>
        /// The type of the query parameter
        /// </summary>
        /// <value>The type of the query parameter</value>
        [DataMember(Name="type", EmitDefaultValue=false)]
        public TypeEnum? Type { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="QueryParameterDto" /> class.
        /// </summary>
        /// <param name="Alias">The alias of the query parameter, used to avoid name collisions for nested query parameter references.</param>
        /// <param name="Choices">If the query parameter is of type select, this is a list of possible choices. This  is read only and is for listing and viewing reports to help the user..</param>
        /// <param name="Id">The entity&#39;s unique identifier, set if it is a reference kind..</param>
        /// <param name="Label">The label for the query parameter.</param>
        /// <param name="Mode">The mode of the query parameter.</param>
        /// <param name="Name">The name of the query parameter.</param>
        /// <param name="Reference">The hydrated reference object.</param>
        /// <param name="SelectListId">If mode is select, this must be populated and is a reference to a select list from which choices will be derived..</param>
        /// <param name="Type">The type of the query parameter.</param>
        /// <param name="Value">The value of the query parameter.</param>
        public QueryParameterDto(string Alias = null, List<Object> Choices = null, string Id = null, string Label = null, ModeEnum? Mode = null, string Name = null, Object Reference = null, string SelectListId = null, TypeEnum? Type = null, Object Value = null)
        {
            this.Alias = Alias;
            this.Choices = Choices;
            this.Id = Id;
            this.Label = Label;
            this.Mode = Mode;
            this.Name = Name;
            this.Reference = Reference;
            this.SelectListId = SelectListId;
            this.Type = Type;
            this.Value = Value;
        }
        
        /// <summary>
        /// The alias of the query parameter, used to avoid name collisions for nested query parameter references
        /// </summary>
        /// <value>The alias of the query parameter, used to avoid name collisions for nested query parameter references</value>
        [DataMember(Name="alias", EmitDefaultValue=false)]
        public string Alias { get; set; }
        /// <summary>
        /// If the query parameter is of type select, this is a list of possible choices. This  is read only and is for listing and viewing reports to help the user.
        /// </summary>
        /// <value>If the query parameter is of type select, this is a list of possible choices. This  is read only and is for listing and viewing reports to help the user.</value>
        [DataMember(Name="choices", EmitDefaultValue=false)]
        public List<Object> Choices { get; set; }
        /// <summary>
        /// The entity&#39;s unique identifier, set if it is a reference kind.
        /// </summary>
        /// <value>The entity&#39;s unique identifier, set if it is a reference kind.</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; set; }
        /// <summary>
        /// The label for the query parameter
        /// </summary>
        /// <value>The label for the query parameter</value>
        [DataMember(Name="label", EmitDefaultValue=false)]
        public string Label { get; set; }
        /// <summary>
        /// The name of the query parameter
        /// </summary>
        /// <value>The name of the query parameter</value>
        [DataMember(Name="name", EmitDefaultValue=false)]
        public string Name { get; set; }
        /// <summary>
        /// Whether the parameter can be overridden, defaults to true.
        /// </summary>
        /// <value>Whether the parameter can be overridden, defaults to true.</value>
        [DataMember(Name="overridable", EmitDefaultValue=false)]
        public bool? Overridable { get; private set; }
        /// <summary>
        /// The hydrated reference object
        /// </summary>
        /// <value>The hydrated reference object</value>
        [DataMember(Name="reference", EmitDefaultValue=false)]
        public Object Reference { get; set; }
        /// <summary>
        /// If mode is select, this must be populated and is a reference to a select list from which choices will be derived.
        /// </summary>
        /// <value>If mode is select, this must be populated and is a reference to a select list from which choices will be derived.</value>
        [DataMember(Name="selectListId", EmitDefaultValue=false)]
        public string SelectListId { get; set; }
        /// <summary>
        /// The value of the query parameter
        /// </summary>
        /// <value>The value of the query parameter</value>
        [DataMember(Name="value", EmitDefaultValue=false)]
        public Object Value { get; set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class QueryParameterDto {\n");
            sb.Append("  Alias: ").Append(Alias).Append("\n");
            sb.Append("  Choices: ").Append(Choices).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  Label: ").Append(Label).Append("\n");
            sb.Append("  Mode: ").Append(Mode).Append("\n");
            sb.Append("  Name: ").Append(Name).Append("\n");
            sb.Append("  Overridable: ").Append(Overridable).Append("\n");
            sb.Append("  Reference: ").Append(Reference).Append("\n");
            sb.Append("  SelectListId: ").Append(SelectListId).Append("\n");
            sb.Append("  Type: ").Append(Type).Append("\n");
            sb.Append("  Value: ").Append(Value).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as QueryParameterDto);
        }

        /// <summary>
        /// Returns true if QueryParameterDto instances are equal
        /// </summary>
        /// <param name="other">Instance of QueryParameterDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(QueryParameterDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.Alias == other.Alias ||
                    this.Alias != null &&
                    this.Alias.Equals(other.Alias)
                ) && 
                (
                    this.Choices == other.Choices ||
                    this.Choices != null &&
                    this.Choices.SequenceEqual(other.Choices)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.Label == other.Label ||
                    this.Label != null &&
                    this.Label.Equals(other.Label)
                ) && 
                (
                    this.Mode == other.Mode ||
                    this.Mode != null &&
                    this.Mode.Equals(other.Mode)
                ) && 
                (
                    this.Name == other.Name ||
                    this.Name != null &&
                    this.Name.Equals(other.Name)
                ) && 
                (
                    this.Overridable == other.Overridable ||
                    this.Overridable != null &&
                    this.Overridable.Equals(other.Overridable)
                ) && 
                (
                    this.Reference == other.Reference ||
                    this.Reference != null &&
                    this.Reference.Equals(other.Reference)
                ) && 
                (
                    this.SelectListId == other.SelectListId ||
                    this.SelectListId != null &&
                    this.SelectListId.Equals(other.SelectListId)
                ) && 
                (
                    this.Type == other.Type ||
                    this.Type != null &&
                    this.Type.Equals(other.Type)
                ) && 
                (
                    this.Value == other.Value ||
                    this.Value != null &&
                    this.Value.Equals(other.Value)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.Alias != null)
                    hash = hash * 59 + this.Alias.GetHashCode();
                if (this.Choices != null)
                    hash = hash * 59 + this.Choices.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.Label != null)
                    hash = hash * 59 + this.Label.GetHashCode();
                if (this.Mode != null)
                    hash = hash * 59 + this.Mode.GetHashCode();
                if (this.Name != null)
                    hash = hash * 59 + this.Name.GetHashCode();
                if (this.Overridable != null)
                    hash = hash * 59 + this.Overridable.GetHashCode();
                if (this.Reference != null)
                    hash = hash * 59 + this.Reference.GetHashCode();
                if (this.SelectListId != null)
                    hash = hash * 59 + this.SelectListId.GetHashCode();
                if (this.Type != null)
                    hash = hash * 59 + this.Type.GetHashCode();
                if (this.Value != null)
                    hash = hash * 59 + this.Value.GetHashCode();
                return hash;
            }
        }
    }

}
