/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// QueryResultDto
    /// </summary>
    [DataContract]
    public partial class QueryResultDto :  IEquatable<QueryResultDto>
    {
        /// <summary>
        /// The current status of the pivot execution
        /// </summary>
        /// <value>The current status of the pivot execution</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum PivotStatusEnum
        {
            
            /// <summary>
            /// Enum NOTSTARTED for "NOT_STARTED"
            /// </summary>
            [EnumMember(Value = "NOT_STARTED")]
            NOTSTARTED,
            
            /// <summary>
            /// Enum RUNNING for "RUNNING"
            /// </summary>
            [EnumMember(Value = "RUNNING")]
            RUNNING,
            
            /// <summary>
            /// Enum COMPLETE for "COMPLETE"
            /// </summary>
            [EnumMember(Value = "COMPLETE")]
            COMPLETE,
            
            /// <summary>
            /// Enum ERROR for "ERROR"
            /// </summary>
            [EnumMember(Value = "ERROR")]
            ERROR,
            
            /// <summary>
            /// Enum CANCELLED for "CANCELLED"
            /// </summary>
            [EnumMember(Value = "CANCELLED")]
            CANCELLED,
            
            /// <summary>
            /// Enum RUNNINGQUERY for "RUNNING_QUERY"
            /// </summary>
            [EnumMember(Value = "RUNNING_QUERY")]
            RUNNINGQUERY,
            
            /// <summary>
            /// Enum PIVOTQUEUED for "PIVOT_QUEUED"
            /// </summary>
            [EnumMember(Value = "PIVOT_QUEUED")]
            PIVOTQUEUED,
            
            /// <summary>
            /// Enum RUNNINGPIVOT for "RUNNING_PIVOT"
            /// </summary>
            [EnumMember(Value = "RUNNING_PIVOT")]
            RUNNINGPIVOT,
            
            /// <summary>
            /// Enum QUERYCOMPLETE for "QUERY_COMPLETE"
            /// </summary>
            [EnumMember(Value = "QUERY_COMPLETE")]
            QUERYCOMPLETE,
            
            /// <summary>
            /// Enum NOTAPPLICABLE for "NOT_APPLICABLE"
            /// </summary>
            [EnumMember(Value = "NOT_APPLICABLE")]
            NOTAPPLICABLE,
            
            /// <summary>
            /// Enum PIVOTERROR for "PIVOT_ERROR"
            /// </summary>
            [EnumMember(Value = "PIVOT_ERROR")]
            PIVOTERROR
        }

        /// <summary>
        /// The current status of the query execution
        /// </summary>
        /// <value>The current status of the query execution</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum StatusEnum
        {
            
            /// <summary>
            /// Enum NOTSTARTED for "NOT_STARTED"
            /// </summary>
            [EnumMember(Value = "NOT_STARTED")]
            NOTSTARTED,
            
            /// <summary>
            /// Enum RUNNING for "RUNNING"
            /// </summary>
            [EnumMember(Value = "RUNNING")]
            RUNNING,
            
            /// <summary>
            /// Enum COMPLETE for "COMPLETE"
            /// </summary>
            [EnumMember(Value = "COMPLETE")]
            COMPLETE,
            
            /// <summary>
            /// Enum ERROR for "ERROR"
            /// </summary>
            [EnumMember(Value = "ERROR")]
            ERROR,
            
            /// <summary>
            /// Enum CANCELLED for "CANCELLED"
            /// </summary>
            [EnumMember(Value = "CANCELLED")]
            CANCELLED
        }

        /// <summary>
        /// The current status of the pivot execution
        /// </summary>
        /// <value>The current status of the pivot execution</value>
        [DataMember(Name="pivotStatus", EmitDefaultValue=false)]
        public PivotStatusEnum? PivotStatus { get; set; }
        /// <summary>
        /// The current status of the query execution
        /// </summary>
        /// <value>The current status of the query execution</value>
        [DataMember(Name="status", EmitDefaultValue=false)]
        public StatusEnum? Status { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="QueryResultDto" /> class.
        /// </summary>
        /// <param name="Columns">If the query has successfully completed, contains a list of columns and their associated computed types from the query..</param>
        /// <param name="IsExplain">Determines if this query is to be explained and not executed.</param>
        /// <param name="Parameters">The query parameter map.</param>
        /// <param name="QueryDto">Associated queryDto.</param>
        /// <param name="QueryId">The identifier of the original query.</param>
        /// <param name="QueryParameters">Contains the parameters available to the query at the time it was run. This allows consumers to go back in time and view the state of the query at runtime. For older query runs, this value may not be populated..</param>
        public QueryResultDto(List<ColumnInfoDto> Columns = null, bool? IsExplain = null, Dictionary<string, Object> Parameters = null, QueryDto QueryDto = null, string QueryId = null, List<QueryParameterDto> QueryParameters = null)
        {
            this.Columns = Columns;
            this.IsExplain = IsExplain;
            this.Parameters = Parameters;
            this.QueryDto = QueryDto;
            this.QueryId = QueryId;
            this.QueryParameters = QueryParameters;
        }
        
        /// <summary>
        /// The number of bytes scanned
        /// </summary>
        /// <value>The number of bytes scanned</value>
        [DataMember(Name="bytesScanned", EmitDefaultValue=false)]
        public long? BytesScanned { get; private set; }
        /// <summary>
        /// If the query has successfully completed, contains a list of columns and their associated computed types from the query.
        /// </summary>
        /// <value>If the query has successfully completed, contains a list of columns and their associated computed types from the query.</value>
        [DataMember(Name="columns", EmitDefaultValue=false)]
        public List<ColumnInfoDto> Columns { get; set; }
        /// <summary>
        /// When the entity was created
        /// </summary>
        /// <value>When the entity was created</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The duration of time it took to execute the query
        /// </summary>
        /// <value>The duration of time it took to execute the query</value>
        [DataMember(Name="duration", EmitDefaultValue=false)]
        public long? Duration { get; private set; }
        /// <summary>
        /// If an error was encountered during the query, this field will be populated with error text.
        /// </summary>
        /// <value>If an error was encountered during the query, this field will be populated with error text.</value>
        [DataMember(Name="error", EmitDefaultValue=false)]
        public string Error { get; private set; }
        /// <summary>
        /// The entity&#39;s unique identifier
        /// </summary>
        /// <value>The entity&#39;s unique identifier</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; private set; }
        /// <summary>
        /// Determines if this query is to be explained and not executed
        /// </summary>
        /// <value>Determines if this query is to be explained and not executed</value>
        [DataMember(Name="isExplain", EmitDefaultValue=false)]
        public bool? IsExplain { get; set; }
        /// <summary>
        /// The query parameter map
        /// </summary>
        /// <value>The query parameter map</value>
        [DataMember(Name="parameters", EmitDefaultValue=false)]
        public Dictionary<string, Object> Parameters { get; set; }
        /// <summary>
        /// Associated queryDto
        /// </summary>
        /// <value>Associated queryDto</value>
        [DataMember(Name="queryDto", EmitDefaultValue=false)]
        public QueryDto QueryDto { get; set; }
        /// <summary>
        /// The identifier of the original query
        /// </summary>
        /// <value>The identifier of the original query</value>
        [DataMember(Name="queryId", EmitDefaultValue=false)]
        public string QueryId { get; set; }
        /// <summary>
        /// Contains the parameters available to the query at the time it was run. This allows consumers to go back in time and view the state of the query at runtime. For older query runs, this value may not be populated.
        /// </summary>
        /// <value>Contains the parameters available to the query at the time it was run. This allows consumers to go back in time and view the state of the query at runtime. For older query runs, this value may not be populated.</value>
        [DataMember(Name="queryParameters", EmitDefaultValue=false)]
        public List<QueryParameterDto> QueryParameters { get; set; }
        /// <summary>
        /// Gets or Sets QueryText
        /// </summary>
        [DataMember(Name="queryText", EmitDefaultValue=false)]
        public string QueryText { get; private set; }
        /// <summary>
        /// Contains the number of rows returned from the query.
        /// </summary>
        /// <value>Contains the number of rows returned from the query.</value>
        [DataMember(Name="rowsReturned", EmitDefaultValue=false)]
        public long? RowsReturned { get; private set; }
        /// <summary>
        /// Contains the size of the query results in bytes. This can be used to determine how best to download the file and if it&#39;s reasonable to open it in a browser or other application. This may be 0 if there are no results or the query results were gathered before we started collecting this metric.
        /// </summary>
        /// <value>Contains the size of the query results in bytes. This can be used to determine how best to download the file and if it&#39;s reasonable to open it in a browser or other application. This may be 0 if there are no results or the query results were gathered before we started collecting this metric.</value>
        [DataMember(Name="size", EmitDefaultValue=false)]
        public long? Size { get; private set; }
        /// <summary>
        /// When the entity was last updated
        /// </summary>
        /// <value>When the entity was last updated</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The owner of the entity
        /// </summary>
        /// <value>The owner of the entity</value>
        [DataMember(Name="userId", EmitDefaultValue=false)]
        public string UserId { get; private set; }
        /// <summary>
        /// The version of the current representation of the entity
        /// </summary>
        /// <value>The version of the current representation of the entity</value>
        [DataMember(Name="version", EmitDefaultValue=false)]
        public long? Version { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class QueryResultDto {\n");
            sb.Append("  BytesScanned: ").Append(BytesScanned).Append("\n");
            sb.Append("  Columns: ").Append(Columns).Append("\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  Duration: ").Append(Duration).Append("\n");
            sb.Append("  Error: ").Append(Error).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  IsExplain: ").Append(IsExplain).Append("\n");
            sb.Append("  Parameters: ").Append(Parameters).Append("\n");
            sb.Append("  PivotStatus: ").Append(PivotStatus).Append("\n");
            sb.Append("  QueryDto: ").Append(QueryDto).Append("\n");
            sb.Append("  QueryId: ").Append(QueryId).Append("\n");
            sb.Append("  QueryParameters: ").Append(QueryParameters).Append("\n");
            sb.Append("  QueryText: ").Append(QueryText).Append("\n");
            sb.Append("  RowsReturned: ").Append(RowsReturned).Append("\n");
            sb.Append("  Size: ").Append(Size).Append("\n");
            sb.Append("  Status: ").Append(Status).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  UserId: ").Append(UserId).Append("\n");
            sb.Append("  Version: ").Append(Version).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as QueryResultDto);
        }

        /// <summary>
        /// Returns true if QueryResultDto instances are equal
        /// </summary>
        /// <param name="other">Instance of QueryResultDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(QueryResultDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.BytesScanned == other.BytesScanned ||
                    this.BytesScanned != null &&
                    this.BytesScanned.Equals(other.BytesScanned)
                ) && 
                (
                    this.Columns == other.Columns ||
                    this.Columns != null &&
                    this.Columns.SequenceEqual(other.Columns)
                ) && 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.Duration == other.Duration ||
                    this.Duration != null &&
                    this.Duration.Equals(other.Duration)
                ) && 
                (
                    this.Error == other.Error ||
                    this.Error != null &&
                    this.Error.Equals(other.Error)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.IsExplain == other.IsExplain ||
                    this.IsExplain != null &&
                    this.IsExplain.Equals(other.IsExplain)
                ) && 
                (
                    this.Parameters == other.Parameters ||
                    this.Parameters != null &&
                    this.Parameters.SequenceEqual(other.Parameters)
                ) && 
                (
                    this.PivotStatus == other.PivotStatus ||
                    this.PivotStatus != null &&
                    this.PivotStatus.Equals(other.PivotStatus)
                ) && 
                (
                    this.QueryDto == other.QueryDto ||
                    this.QueryDto != null &&
                    this.QueryDto.Equals(other.QueryDto)
                ) && 
                (
                    this.QueryId == other.QueryId ||
                    this.QueryId != null &&
                    this.QueryId.Equals(other.QueryId)
                ) && 
                (
                    this.QueryParameters == other.QueryParameters ||
                    this.QueryParameters != null &&
                    this.QueryParameters.SequenceEqual(other.QueryParameters)
                ) && 
                (
                    this.QueryText == other.QueryText ||
                    this.QueryText != null &&
                    this.QueryText.Equals(other.QueryText)
                ) && 
                (
                    this.RowsReturned == other.RowsReturned ||
                    this.RowsReturned != null &&
                    this.RowsReturned.Equals(other.RowsReturned)
                ) && 
                (
                    this.Size == other.Size ||
                    this.Size != null &&
                    this.Size.Equals(other.Size)
                ) && 
                (
                    this.Status == other.Status ||
                    this.Status != null &&
                    this.Status.Equals(other.Status)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.UserId == other.UserId ||
                    this.UserId != null &&
                    this.UserId.Equals(other.UserId)
                ) && 
                (
                    this.Version == other.Version ||
                    this.Version != null &&
                    this.Version.Equals(other.Version)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.BytesScanned != null)
                    hash = hash * 59 + this.BytesScanned.GetHashCode();
                if (this.Columns != null)
                    hash = hash * 59 + this.Columns.GetHashCode();
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.Duration != null)
                    hash = hash * 59 + this.Duration.GetHashCode();
                if (this.Error != null)
                    hash = hash * 59 + this.Error.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.IsExplain != null)
                    hash = hash * 59 + this.IsExplain.GetHashCode();
                if (this.Parameters != null)
                    hash = hash * 59 + this.Parameters.GetHashCode();
                if (this.PivotStatus != null)
                    hash = hash * 59 + this.PivotStatus.GetHashCode();
                if (this.QueryDto != null)
                    hash = hash * 59 + this.QueryDto.GetHashCode();
                if (this.QueryId != null)
                    hash = hash * 59 + this.QueryId.GetHashCode();
                if (this.QueryParameters != null)
                    hash = hash * 59 + this.QueryParameters.GetHashCode();
                if (this.QueryText != null)
                    hash = hash * 59 + this.QueryText.GetHashCode();
                if (this.RowsReturned != null)
                    hash = hash * 59 + this.RowsReturned.GetHashCode();
                if (this.Size != null)
                    hash = hash * 59 + this.Size.GetHashCode();
                if (this.Status != null)
                    hash = hash * 59 + this.Status.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.UserId != null)
                    hash = hash * 59 + this.UserId.GetHashCode();
                if (this.Version != null)
                    hash = hash * 59 + this.Version.GetHashCode();
                return hash;
            }
        }
    }

}
