/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// RefreshBatchDto
    /// </summary>
    [DataContract]
    public partial class RefreshBatchDto :  IEquatable<RefreshBatchDto>
    {
        /// <summary>
        /// The run status of the destination
        /// </summary>
        /// <value>The run status of the destination</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum DestinationStatusEnum
        {
            
            /// <summary>
            /// Enum Notstarted for "not_started"
            /// </summary>
            [EnumMember(Value = "not_started")]
            Notstarted,
            
            /// <summary>
            /// Enum Running for "running"
            /// </summary>
            [EnumMember(Value = "running")]
            Running,
            
            /// <summary>
            /// Enum Complete for "complete"
            /// </summary>
            [EnumMember(Value = "complete")]
            Complete,
            
            /// <summary>
            /// Enum Error for "error"
            /// </summary>
            [EnumMember(Value = "error")]
            Error,
            
            /// <summary>
            /// Enum Cancelled for "cancelled"
            /// </summary>
            [EnumMember(Value = "cancelled")]
            Cancelled
        }

        /// <summary>
        /// The run status of the source
        /// </summary>
        /// <value>The run status of the source</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum SourceStatusEnum
        {
            
            /// <summary>
            /// Enum Notstarted for "not_started"
            /// </summary>
            [EnumMember(Value = "not_started")]
            Notstarted,
            
            /// <summary>
            /// Enum Running for "running"
            /// </summary>
            [EnumMember(Value = "running")]
            Running,
            
            /// <summary>
            /// Enum Complete for "complete"
            /// </summary>
            [EnumMember(Value = "complete")]
            Complete,
            
            /// <summary>
            /// Enum Error for "error"
            /// </summary>
            [EnumMember(Value = "error")]
            Error,
            
            /// <summary>
            /// Enum Cancelled for "cancelled"
            /// </summary>
            [EnumMember(Value = "cancelled")]
            Cancelled
        }

        /// <summary>
        /// The run status of the destination
        /// </summary>
        /// <value>The run status of the destination</value>
        [DataMember(Name="destinationStatus", EmitDefaultValue=false)]
        public DestinationStatusEnum? DestinationStatus { get; set; }
        /// <summary>
        /// The run status of the source
        /// </summary>
        /// <value>The run status of the source</value>
        [DataMember(Name="sourceStatus", EmitDefaultValue=false)]
        public SourceStatusEnum? SourceStatus { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="RefreshBatchDto" /> class.
        /// </summary>
        /// <param name="ChildRefreshes">The list of jobs initiated by the batch.</param>
        public RefreshBatchDto(List<ConnectionRunDto> ChildRefreshes = null)
        {
            this.ChildRefreshes = ChildRefreshes;
        }
        
        /// <summary>
        /// The unique ID of the batch
        /// </summary>
        /// <value>The unique ID of the batch</value>
        [DataMember(Name="batchRefreshId", EmitDefaultValue=false)]
        public string BatchRefreshId { get; private set; }
        /// <summary>
        /// The list of jobs initiated by the batch
        /// </summary>
        /// <value>The list of jobs initiated by the batch</value>
        [DataMember(Name="childRefreshes", EmitDefaultValue=false)]
        public List<ConnectionRunDto> ChildRefreshes { get; set; }
        /// <summary>
        /// When the batch was created, as a datetime
        /// </summary>
        /// <value>When the batch was created, as a datetime</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The ID of the user that created the batch
        /// </summary>
        /// <value>The ID of the user that created the batch</value>
        [DataMember(Name="createdBy", EmitDefaultValue=false)]
        public string CreatedBy { get; private set; }
        /// <summary>
        /// Any error encountered while initiating the batch
        /// </summary>
        /// <value>Any error encountered while initiating the batch</value>
        [DataMember(Name="error", EmitDefaultValue=false)]
        public string Error { get; private set; }
        /// <summary>
        /// When the batch was updated, as a datetime
        /// </summary>
        /// <value>When the batch was updated, as a datetime</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class RefreshBatchDto {\n");
            sb.Append("  BatchRefreshId: ").Append(BatchRefreshId).Append("\n");
            sb.Append("  ChildRefreshes: ").Append(ChildRefreshes).Append("\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  CreatedBy: ").Append(CreatedBy).Append("\n");
            sb.Append("  DestinationStatus: ").Append(DestinationStatus).Append("\n");
            sb.Append("  Error: ").Append(Error).Append("\n");
            sb.Append("  SourceStatus: ").Append(SourceStatus).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as RefreshBatchDto);
        }

        /// <summary>
        /// Returns true if RefreshBatchDto instances are equal
        /// </summary>
        /// <param name="other">Instance of RefreshBatchDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(RefreshBatchDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.BatchRefreshId == other.BatchRefreshId ||
                    this.BatchRefreshId != null &&
                    this.BatchRefreshId.Equals(other.BatchRefreshId)
                ) && 
                (
                    this.ChildRefreshes == other.ChildRefreshes ||
                    this.ChildRefreshes != null &&
                    this.ChildRefreshes.SequenceEqual(other.ChildRefreshes)
                ) && 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.CreatedBy == other.CreatedBy ||
                    this.CreatedBy != null &&
                    this.CreatedBy.Equals(other.CreatedBy)
                ) && 
                (
                    this.DestinationStatus == other.DestinationStatus ||
                    this.DestinationStatus != null &&
                    this.DestinationStatus.Equals(other.DestinationStatus)
                ) && 
                (
                    this.Error == other.Error ||
                    this.Error != null &&
                    this.Error.Equals(other.Error)
                ) && 
                (
                    this.SourceStatus == other.SourceStatus ||
                    this.SourceStatus != null &&
                    this.SourceStatus.Equals(other.SourceStatus)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.BatchRefreshId != null)
                    hash = hash * 59 + this.BatchRefreshId.GetHashCode();
                if (this.ChildRefreshes != null)
                    hash = hash * 59 + this.ChildRefreshes.GetHashCode();
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.CreatedBy != null)
                    hash = hash * 59 + this.CreatedBy.GetHashCode();
                if (this.DestinationStatus != null)
                    hash = hash * 59 + this.DestinationStatus.GetHashCode();
                if (this.Error != null)
                    hash = hash * 59 + this.Error.GetHashCode();
                if (this.SourceStatus != null)
                    hash = hash * 59 + this.SourceStatus.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                return hash;
            }
        }
    }

}
