/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// RefreshConnectionDto
    /// </summary>
    [DataContract]
    public partial class RefreshConnectionDto :  IEquatable<RefreshConnectionDto>
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="RefreshConnectionDto" /> class.
        /// </summary>
        /// <param name="ConnectionId">The unique ID of the connection.</param>
        /// <param name="DestinationParameters">Parameters to send to the destination, on refresh.</param>
        /// <param name="SourceParameters">Parameters to send to the source, on refresh.</param>
        /// <param name="UsePreviousDestinationParameters">Use the destination parameters from the previous run. This overrides any specified destination parameters. Ignored by \&quot;Refresh batch of connections\&quot; endpoint.</param>
        /// <param name="UsePreviousSourceParameters">Use the source parameters from the previous run. This overrides any specified source parameters. Ignored by \&quot;Refresh batch of connections\&quot; endpoint.</param>
        /// <param name="WorkspaceId">The workspace ID of the connection.</param>
        public RefreshConnectionDto(string ConnectionId = null, Object DestinationParameters = null, Object SourceParameters = null, bool? UsePreviousDestinationParameters = null, bool? UsePreviousSourceParameters = null, string WorkspaceId = null)
        {
            this.ConnectionId = ConnectionId;
            this.DestinationParameters = DestinationParameters;
            this.SourceParameters = SourceParameters;
            this.UsePreviousDestinationParameters = UsePreviousDestinationParameters;
            this.UsePreviousSourceParameters = UsePreviousSourceParameters;
            this.WorkspaceId = WorkspaceId;
        }
        
        /// <summary>
        /// The unique ID of the connection
        /// </summary>
        /// <value>The unique ID of the connection</value>
        [DataMember(Name="connectionId", EmitDefaultValue=false)]
        public string ConnectionId { get; set; }
        /// <summary>
        /// Parameters to send to the destination, on refresh
        /// </summary>
        /// <value>Parameters to send to the destination, on refresh</value>
        [DataMember(Name="destinationParameters", EmitDefaultValue=false)]
        public Object DestinationParameters { get; set; }
        /// <summary>
        /// Parameters to send to the source, on refresh
        /// </summary>
        /// <value>Parameters to send to the source, on refresh</value>
        [DataMember(Name="sourceParameters", EmitDefaultValue=false)]
        public Object SourceParameters { get; set; }
        /// <summary>
        /// Use the destination parameters from the previous run. This overrides any specified destination parameters. Ignored by \&quot;Refresh batch of connections\&quot; endpoint
        /// </summary>
        /// <value>Use the destination parameters from the previous run. This overrides any specified destination parameters. Ignored by \&quot;Refresh batch of connections\&quot; endpoint</value>
        [DataMember(Name="usePreviousDestinationParameters", EmitDefaultValue=false)]
        public bool? UsePreviousDestinationParameters { get; set; }
        /// <summary>
        /// Use the source parameters from the previous run. This overrides any specified source parameters. Ignored by \&quot;Refresh batch of connections\&quot; endpoint
        /// </summary>
        /// <value>Use the source parameters from the previous run. This overrides any specified source parameters. Ignored by \&quot;Refresh batch of connections\&quot; endpoint</value>
        [DataMember(Name="usePreviousSourceParameters", EmitDefaultValue=false)]
        public bool? UsePreviousSourceParameters { get; set; }
        /// <summary>
        /// The workspace ID of the connection
        /// </summary>
        /// <value>The workspace ID of the connection</value>
        [DataMember(Name="workspaceId", EmitDefaultValue=false)]
        public string WorkspaceId { get; set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class RefreshConnectionDto {\n");
            sb.Append("  ConnectionId: ").Append(ConnectionId).Append("\n");
            sb.Append("  DestinationParameters: ").Append(DestinationParameters).Append("\n");
            sb.Append("  SourceParameters: ").Append(SourceParameters).Append("\n");
            sb.Append("  UsePreviousDestinationParameters: ").Append(UsePreviousDestinationParameters).Append("\n");
            sb.Append("  UsePreviousSourceParameters: ").Append(UsePreviousSourceParameters).Append("\n");
            sb.Append("  WorkspaceId: ").Append(WorkspaceId).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as RefreshConnectionDto);
        }

        /// <summary>
        /// Returns true if RefreshConnectionDto instances are equal
        /// </summary>
        /// <param name="other">Instance of RefreshConnectionDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(RefreshConnectionDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.ConnectionId == other.ConnectionId ||
                    this.ConnectionId != null &&
                    this.ConnectionId.Equals(other.ConnectionId)
                ) && 
                (
                    this.DestinationParameters == other.DestinationParameters ||
                    this.DestinationParameters != null &&
                    this.DestinationParameters.Equals(other.DestinationParameters)
                ) && 
                (
                    this.SourceParameters == other.SourceParameters ||
                    this.SourceParameters != null &&
                    this.SourceParameters.Equals(other.SourceParameters)
                ) && 
                (
                    this.UsePreviousDestinationParameters == other.UsePreviousDestinationParameters ||
                    this.UsePreviousDestinationParameters != null &&
                    this.UsePreviousDestinationParameters.Equals(other.UsePreviousDestinationParameters)
                ) && 
                (
                    this.UsePreviousSourceParameters == other.UsePreviousSourceParameters ||
                    this.UsePreviousSourceParameters != null &&
                    this.UsePreviousSourceParameters.Equals(other.UsePreviousSourceParameters)
                ) && 
                (
                    this.WorkspaceId == other.WorkspaceId ||
                    this.WorkspaceId != null &&
                    this.WorkspaceId.Equals(other.WorkspaceId)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.ConnectionId != null)
                    hash = hash * 59 + this.ConnectionId.GetHashCode();
                if (this.DestinationParameters != null)
                    hash = hash * 59 + this.DestinationParameters.GetHashCode();
                if (this.SourceParameters != null)
                    hash = hash * 59 + this.SourceParameters.GetHashCode();
                if (this.UsePreviousDestinationParameters != null)
                    hash = hash * 59 + this.UsePreviousDestinationParameters.GetHashCode();
                if (this.UsePreviousSourceParameters != null)
                    hash = hash * 59 + this.UsePreviousSourceParameters.GetHashCode();
                if (this.WorkspaceId != null)
                    hash = hash * 59 + this.WorkspaceId.GetHashCode();
                return hash;
            }
        }
    }

}
