/* 
 * Cerebral API
 *
 * The Wdata Preparation API allow users to import data sets from their source system, tag, organize, manipulate, share, export, and query against the data
 *
 * OpenAPI spec version: 1.0
 * Contact: platformsupport@workiva.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;

namespace IO.Swagger.Model
{
    /// <summary>
    /// TableDto
    /// </summary>
    [DataContract]
    public partial class TableDto :  IEquatable<TableDto>
    {
        /// <summary>
        /// The type of table
        /// </summary>
        /// <value>The type of table</value>
        [JsonConverter(typeof(StringEnumConverter))]
        public enum TypeEnum
        {
            
            /// <summary>
            /// Enum Data for "data"
            /// </summary>
            [EnumMember(Value = "data")]
            Data,
            
            /// <summary>
            /// Enum Lookup for "lookup"
            /// </summary>
            [EnumMember(Value = "lookup")]
            Lookup
        }

        /// <summary>
        /// The type of table
        /// </summary>
        /// <value>The type of table</value>
        [DataMember(Name="type", EmitDefaultValue=false)]
        public TypeEnum? Type { get; set; }
        /// <summary>
        /// Initializes a new instance of the <see cref="TableDto" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected TableDto() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="TableDto" /> class.
        /// </summary>
        /// <param name="DatasetUpdated">The last time that the data set for this table was modified..</param>
        /// <param name="Description">May be at most 255 characters in length.</param>
        /// <param name="IsShared">A property indicating if this table is shared to any destination. (required).</param>
        /// <param name="Name">May be at most 150 characters in length.</param>
        /// <param name="TableSchema">The schema to apply.</param>
        /// <param name="Type">The type of table.</param>
        /// <param name="UniqueTableConstraints">A property indicating the unique constraints on the table. (required).</param>
        public TableDto(DateTime? DatasetUpdated = null, string Description = null, bool? IsShared = null, string Name = null, TableSchema TableSchema = null, TypeEnum? Type = null, List<UniqueConstraintDto> UniqueTableConstraints = null)
        {
            // to ensure "IsShared" is required (not null)
            if (IsShared == null)
            {
                throw new InvalidDataException("IsShared is a required property for TableDto and cannot be null");
            }
            else
            {
                this.IsShared = IsShared;
            }
            // to ensure "UniqueTableConstraints" is required (not null)
            if (UniqueTableConstraints == null)
            {
                throw new InvalidDataException("UniqueTableConstraints is a required property for TableDto and cannot be null");
            }
            else
            {
                this.UniqueTableConstraints = UniqueTableConstraints;
            }
            this.DatasetUpdated = DatasetUpdated;
            this.Description = Description;
            this.Name = Name;
            this.TableSchema = TableSchema;
            this.Type = Type;
        }
        
        /// <summary>
        /// When the entity was created
        /// </summary>
        /// <value>When the entity was created</value>
        [DataMember(Name="created", EmitDefaultValue=false)]
        public DateTime? Created { get; private set; }
        /// <summary>
        /// The unique identifier of the database where the table resides.
        /// </summary>
        /// <value>The unique identifier of the database where the table resides.</value>
        [DataMember(Name="databaseId", EmitDefaultValue=false)]
        public string DatabaseId { get; private set; }
        /// <summary>
        /// The last time that the data set for this table was modified.
        /// </summary>
        /// <value>The last time that the data set for this table was modified.</value>
        [DataMember(Name="datasetUpdated", EmitDefaultValue=false)]
        public DateTime? DatasetUpdated { get; set; }
        /// <summary>
        /// This is for backwards compatibility only and will always return false.
        /// </summary>
        /// <value>This is for backwards compatibility only and will always return false.</value>
        [DataMember(Name="deleted", EmitDefaultValue=false)]
        public bool? Deleted { get; private set; }
        /// <summary>
        /// May be at most 255 characters in length
        /// </summary>
        /// <value>May be at most 255 characters in length</value>
        [DataMember(Name="description", EmitDefaultValue=false)]
        public string Description { get; set; }
        /// <summary>
        /// The entity&#39;s unique identifier
        /// </summary>
        /// <value>The entity&#39;s unique identifier</value>
        [DataMember(Name="id", EmitDefaultValue=false)]
        public string Id { get; private set; }
        /// <summary>
        /// A property indicating if this table is shared to any destination.
        /// </summary>
        /// <value>A property indicating if this table is shared to any destination.</value>
        [DataMember(Name="isShared", EmitDefaultValue=false)]
        public bool? IsShared { get; set; }
        /// <summary>
        /// Contains the date and time of the last file that was imported into the table. Valuable for determining if the data is stale.
        /// </summary>
        /// <value>Contains the date and time of the last file that was imported into the table. Valuable for determining if the data is stale.</value>
        [DataMember(Name="lastUploaded", EmitDefaultValue=false)]
        public DateTime? LastUploaded { get; private set; }
        /// <summary>
        /// May be at most 150 characters in length
        /// </summary>
        /// <value>May be at most 150 characters in length</value>
        [DataMember(Name="name", EmitDefaultValue=false)]
        public string Name { get; set; }
        /// <summary>
        /// If non-null, indicates the parent of this entity. Must be modified through the folder api.
        /// </summary>
        /// <value>If non-null, indicates the parent of this entity. Must be modified through the folder api.</value>
        [DataMember(Name="parentId", EmitDefaultValue=false)]
        public string ParentId { get; private set; }
        /// <summary>
        /// Indicates if this table is readonly in the account receiving this table. If so, any attempt to edit the table will fail.
        /// </summary>
        /// <value>Indicates if this table is readonly in the account receiving this table. If so, any attempt to edit the table will fail.</value>
        [DataMember(Name="readOnly", EmitDefaultValue=false)]
        public bool? _ReadOnly { get; private set; }
        /// <summary>
        /// The schema to apply
        /// </summary>
        /// <value>The schema to apply</value>
        [DataMember(Name="tableSchema", EmitDefaultValue=false)]
        public TableSchema TableSchema { get; set; }
        /// <summary>
        /// A property indicating the unique constraints on the table.
        /// </summary>
        /// <value>A property indicating the unique constraints on the table.</value>
        [DataMember(Name="uniqueTableConstraints", EmitDefaultValue=false)]
        public List<UniqueConstraintDto> UniqueTableConstraints { get; set; }
        /// <summary>
        /// When the entity was last updated
        /// </summary>
        /// <value>When the entity was last updated</value>
        [DataMember(Name="updated", EmitDefaultValue=false)]
        public DateTime? Updated { get; private set; }
        /// <summary>
        /// The owner of the entity
        /// </summary>
        /// <value>The owner of the entity</value>
        [DataMember(Name="userId", EmitDefaultValue=false)]
        public string UserId { get; private set; }
        /// <summary>
        /// The version of the current representation of the entity
        /// </summary>
        /// <value>The version of the current representation of the entity</value>
        [DataMember(Name="version", EmitDefaultValue=false)]
        public long? Version { get; private set; }
        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class TableDto {\n");
            sb.Append("  Created: ").Append(Created).Append("\n");
            sb.Append("  DatabaseId: ").Append(DatabaseId).Append("\n");
            sb.Append("  DatasetUpdated: ").Append(DatasetUpdated).Append("\n");
            sb.Append("  Deleted: ").Append(Deleted).Append("\n");
            sb.Append("  Description: ").Append(Description).Append("\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  IsShared: ").Append(IsShared).Append("\n");
            sb.Append("  LastUploaded: ").Append(LastUploaded).Append("\n");
            sb.Append("  Name: ").Append(Name).Append("\n");
            sb.Append("  ParentId: ").Append(ParentId).Append("\n");
            sb.Append("  _ReadOnly: ").Append(_ReadOnly).Append("\n");
            sb.Append("  TableSchema: ").Append(TableSchema).Append("\n");
            sb.Append("  Type: ").Append(Type).Append("\n");
            sb.Append("  UniqueTableConstraints: ").Append(UniqueTableConstraints).Append("\n");
            sb.Append("  Updated: ").Append(Updated).Append("\n");
            sb.Append("  UserId: ").Append(UserId).Append("\n");
            sb.Append("  Version: ").Append(Version).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="obj">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object obj)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            return this.Equals(obj as TableDto);
        }

        /// <summary>
        /// Returns true if TableDto instances are equal
        /// </summary>
        /// <param name="other">Instance of TableDto to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(TableDto other)
        {
            // credit: http://stackoverflow.com/a/10454552/677735
            if (other == null)
                return false;

            return 
                (
                    this.Created == other.Created ||
                    this.Created != null &&
                    this.Created.Equals(other.Created)
                ) && 
                (
                    this.DatabaseId == other.DatabaseId ||
                    this.DatabaseId != null &&
                    this.DatabaseId.Equals(other.DatabaseId)
                ) && 
                (
                    this.DatasetUpdated == other.DatasetUpdated ||
                    this.DatasetUpdated != null &&
                    this.DatasetUpdated.Equals(other.DatasetUpdated)
                ) && 
                (
                    this.Deleted == other.Deleted ||
                    this.Deleted != null &&
                    this.Deleted.Equals(other.Deleted)
                ) && 
                (
                    this.Description == other.Description ||
                    this.Description != null &&
                    this.Description.Equals(other.Description)
                ) && 
                (
                    this.Id == other.Id ||
                    this.Id != null &&
                    this.Id.Equals(other.Id)
                ) && 
                (
                    this.IsShared == other.IsShared ||
                    this.IsShared != null &&
                    this.IsShared.Equals(other.IsShared)
                ) && 
                (
                    this.LastUploaded == other.LastUploaded ||
                    this.LastUploaded != null &&
                    this.LastUploaded.Equals(other.LastUploaded)
                ) && 
                (
                    this.Name == other.Name ||
                    this.Name != null &&
                    this.Name.Equals(other.Name)
                ) && 
                (
                    this.ParentId == other.ParentId ||
                    this.ParentId != null &&
                    this.ParentId.Equals(other.ParentId)
                ) && 
                (
                    this._ReadOnly == other._ReadOnly ||
                    this._ReadOnly != null &&
                    this._ReadOnly.Equals(other._ReadOnly)
                ) && 
                (
                    this.TableSchema == other.TableSchema ||
                    this.TableSchema != null &&
                    this.TableSchema.Equals(other.TableSchema)
                ) && 
                (
                    this.Type == other.Type ||
                    this.Type != null &&
                    this.Type.Equals(other.Type)
                ) && 
                (
                    this.UniqueTableConstraints == other.UniqueTableConstraints ||
                    this.UniqueTableConstraints != null &&
                    this.UniqueTableConstraints.SequenceEqual(other.UniqueTableConstraints)
                ) && 
                (
                    this.Updated == other.Updated ||
                    this.Updated != null &&
                    this.Updated.Equals(other.Updated)
                ) && 
                (
                    this.UserId == other.UserId ||
                    this.UserId != null &&
                    this.UserId.Equals(other.UserId)
                ) && 
                (
                    this.Version == other.Version ||
                    this.Version != null &&
                    this.Version.Equals(other.Version)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            // credit: http://stackoverflow.com/a/263416/677735
            unchecked // Overflow is fine, just wrap
            {
                int hash = 41;
                // Suitable nullity checks etc, of course :)
                if (this.Created != null)
                    hash = hash * 59 + this.Created.GetHashCode();
                if (this.DatabaseId != null)
                    hash = hash * 59 + this.DatabaseId.GetHashCode();
                if (this.DatasetUpdated != null)
                    hash = hash * 59 + this.DatasetUpdated.GetHashCode();
                if (this.Deleted != null)
                    hash = hash * 59 + this.Deleted.GetHashCode();
                if (this.Description != null)
                    hash = hash * 59 + this.Description.GetHashCode();
                if (this.Id != null)
                    hash = hash * 59 + this.Id.GetHashCode();
                if (this.IsShared != null)
                    hash = hash * 59 + this.IsShared.GetHashCode();
                if (this.LastUploaded != null)
                    hash = hash * 59 + this.LastUploaded.GetHashCode();
                if (this.Name != null)
                    hash = hash * 59 + this.Name.GetHashCode();
                if (this.ParentId != null)
                    hash = hash * 59 + this.ParentId.GetHashCode();
                if (this._ReadOnly != null)
                    hash = hash * 59 + this._ReadOnly.GetHashCode();
                if (this.TableSchema != null)
                    hash = hash * 59 + this.TableSchema.GetHashCode();
                if (this.Type != null)
                    hash = hash * 59 + this.Type.GetHashCode();
                if (this.UniqueTableConstraints != null)
                    hash = hash * 59 + this.UniqueTableConstraints.GetHashCode();
                if (this.Updated != null)
                    hash = hash * 59 + this.Updated.GetHashCode();
                if (this.UserId != null)
                    hash = hash * 59 + this.UserId.GetHashCode();
                if (this.Version != null)
                    hash = hash * 59 + this.Version.GetHashCode();
                return hash;
            }
        }
    }

}
